@@ -58,6 +58,10 @@ static char dnames[CAL_COLS][3] = {
 
 enum {DAY, MONTH, YEAR};
 
+typedef enum {
+    BACKBACK, BACK, TODAY, FORW, FORWFORW
+} TodayCuts;
+
 static Pixel fg_pix, bg_pix;		/* used to reverse colors "today" */
 
 #define	NO_DATE	(999)			/* anything outside -31..31 */
@@ -72,6 +76,7 @@ Widget parent;
 	Widget form_w;
 	Widget rc_w;
 	Widget menu_w;
+	Widget bw, fw;
 	Widget w;
 	int n;
 	int i;
@@ -197,17 +202,61 @@ Widget parent;
 	    XtManageChild (d_w[i]);
 	}
 
-	/* add the Today button */
+	/* add the Today and surrounding buttons */
 
 	n = 0;
 	XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
 	XtSetArg (args[n], XmNtopOffset, 3); n++;
 	XtSetArg (args[n], XmNtopWidget, rc_w); n++;
 	XtSetArg (args[n], XmNleftAttachment, XmATTACH_FORM); n++;
+	w = XmCreatePushButton (form_w, "<<", args, n);
+	XtManageChild (w);
+	XtAddCallback (w, XmNactivateCallback, today_cb, (XtPointer)BACKBACK);
+	wtip (w, "Move back one week");
+
+	n = 0;
+	XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
+	XtSetArg (args[n], XmNtopOffset, 3); n++;
+	XtSetArg (args[n], XmNtopWidget, rc_w); n++;
+	XtSetArg (args[n], XmNleftAttachment, XmATTACH_WIDGET); n++;
+	XtSetArg (args[n], XmNleftWidget, w); n++;
+	bw = XmCreatePushButton (form_w, "<", args, n);
+	XtManageChild (bw);
+	XtAddCallback (bw, XmNactivateCallback, today_cb, (XtPointer)BACK);
+	wtip (bw, "Move back one day");
+
+	n = 0;
+	XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
+	XtSetArg (args[n], XmNtopOffset, 3); n++;
+	XtSetArg (args[n], XmNtopWidget, rc_w); n++;
 	XtSetArg (args[n], XmNrightAttachment, XmATTACH_FORM); n++;
+	w = XmCreatePushButton (form_w, ">>", args, n);
+	XtManageChild (w);
+	XtAddCallback (w, XmNactivateCallback, today_cb, (XtPointer)FORWFORW);
+	wtip (w, "Move forward one week");
+
+	n = 0;
+	XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
+	XtSetArg (args[n], XmNtopOffset, 3); n++;
+	XtSetArg (args[n], XmNtopWidget, rc_w); n++;
+	XtSetArg (args[n], XmNrightAttachment, XmATTACH_WIDGET); n++;
+	XtSetArg (args[n], XmNrightWidget, w); n++;
+	fw = XmCreatePushButton (form_w, ">", args, n);
+	XtManageChild (fw);
+	XtAddCallback (fw, XmNactivateCallback, today_cb, (XtPointer)FORW);
+	wtip (fw, "Move forward one day");
+
+	n = 0;
+	XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
+	XtSetArg (args[n], XmNtopOffset, 3); n++;
+	XtSetArg (args[n], XmNtopWidget, rc_w); n++;
+	XtSetArg (args[n], XmNleftAttachment, XmATTACH_WIDGET); n++;
+	XtSetArg (args[n], XmNleftWidget, bw); n++;
+	XtSetArg (args[n], XmNrightAttachment, XmATTACH_WIDGET); n++;
+	XtSetArg (args[n], XmNrightWidget, fw); n++;
 	w = XmCreatePushButton (form_w, "Today", args, n);
 	XtManageChild (w);
-	XtAddCallback (w, XmNactivateCallback, today_cb, NULL);
+	XtAddCallback (w, XmNactivateCallback, today_cb, (XtPointer)TODAY);
 	wtip (w, "Set calendar to today's date");
 
 	get_something (d_w[0], XmNforeground, (XtArgVal)&fg_pix);
@@ -329,7 +378,8 @@ Now *np;
 	mm_nfmoon (jd0+30, tz, m, f);
 }
 
-/* called when Today is pressed.
+/* called when Today or its helpers are pressed.
+ * client is one of TodayCuts.
  * set m/d/y but retain any partion day.
  */
 /* ARGSUSED */
@@ -339,6 +389,7 @@ Widget w;
 XtPointer client;
 XtPointer call;
 {
+	TodayCuts c = (TodayCuts)client;
 	Now *np = mm_get_now();
 	int localtz;
 	double newmjd;
@@ -346,17 +397,42 @@ XtPointer call;
 	int m, y;
 	double d;
 
-	localtz = pref_get(PREF_ZONE) == PREF_LOCALTZ;
-	jd = localtz ? mjd - tz/24.0 : mjd;
+	switch (c) {
+	case BACKBACK:
+	    newmjd = mjd - 7;
+	    break;
 
-	mjd_cal (jd, &m, &d, &y);
-	time_fromsys (np);
-	jd = localtz ? mjd - tz/24.0 : mjd;
-	newmjd = mjd_day(jd) + (d - floor(d));
+	case BACK:
+	    newmjd = mjd - 1;
+	    break;
+
+	case TODAY:
+	    localtz = pref_get(PREF_ZONE) == PREF_LOCALTZ;
+	    jd = localtz ? mjd - tz/24.0 : mjd;
+
+	    mjd_cal (jd, &m, &d, &y);
+	    time_fromsys (np);
+	    jd = localtz ? mjd - tz/24.0 : mjd;
+	    newmjd = mjd_day(jd) + (d - floor(d));
+
+	    if (localtz)
+		newmjd += tz/24.0;
+	    break;
+
+	case FORW:
+	    newmjd = mjd + 1;
+	    break;
+
+	case FORWFORW:
+	    newmjd = mjd + 7;
+	    break;
+
+	default:
+	    newmjd = mjd;
+	    break;
+	}
 
 	/* this always wants UTC */
-	if (localtz)
-	    newmjd += tz/24.0;
 	mm_newcaldate (newmjd);
 }
 
@@ -459,4 +535,4 @@ int m, f;
 }
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: calmenu.c,v $ $Date: 1999/02/23 22:09:18 $ $Revision: 1.4 $ $Name:  $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: calmenu.c,v $ $Date: 1999/10/06 21:34:24 $ $Revision: 1.5 $ $Name:  $"};
