@@ -1119,7 +1119,7 @@ c_create_flist_w()
 	Arg args[20];
 	int n;
 
-	(void) sprintf (fname,"%s/closelist.txt", getXRes ("UserDir", "work"));
+	(void) sprintf (fname,"%s/closelist.txt", getXRes("PrivateDir","work"));
 
 	n = 0;
 	XtSetArg(args[n], XmNdefaultPosition, False);  n++;
@@ -1247,3 +1247,6 @@ FILE *fp;
 
 	watch_cursor(0);
 }
+
+/* For RCS Only -- Do Not Edit */
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: closemenu.c,v $ $Date: 1998/04/27 21:51:49 $ $Revision: 1.1 $ $Name:  $"};
