@@ -156,10 +156,10 @@ typedef enum {
 /* identifiers for each entry in col[]. these must match the order therein.
  */
 enum {
-    CONSTEL_ID, RA_ID, HA_ID, DEC_ID, AZ_ID, ALT_ID, Z_ID, HLONG_ID, HLAT_ID,
-    GLONG_ID, GLAT_ID, EDST_ID, ELGHT_ID, SDST_ID, SLGHT_ID, ELONG_ID, SIZE_ID,
-    VMAG_ID, PHS_ID, RSTIME_ID, RSAZ_ID, TRTIME_ID, TRALT_ID, SETTIME_ID,
-    SETAZ_ID, HRSUP_ID
+    CONSTEL_ID, RA_ID, HA_ID, DEC_ID, AZ_ID, ALT_ID, ZEN_ID, Z_ID, HLONG_ID,
+    HLAT_ID, GLONG_ID, GLAT_ID, EDST_ID, ELGHT_ID, SDST_ID, SLGHT_ID,
+    ELONG_ID, SIZE_ID, VMAG_ID, PHS_ID, RSTIME_ID, RSAZ_ID, TRTIME_ID,
+    TRALT_ID, SETTIME_ID, SETAZ_ID, HRSUP_ID
 };
 
 static ColHdr col[] = {
@@ -169,14 +169,15 @@ static ColHdr col[] = {
     {MISC_COL,	"Dec",	  0, "Declination (to Main's settings)"},
     {MISC_COL,	"Az",	  0, "Azimuth, E of N"},
     {MISC_COL,	"Alt",	  0, "Angle above horizon"},
+    {MISC_COL,	"Zenith", 0, "Angle down from zenith"},
     {MISC_COL,	"Air",	  0, "Air mass"},
     {MISC_COL,	"HeLong", 0, "Heliocentric longitude"},
     {MISC_COL,	"HeLat",  0, "Heliocentric latitude"},
     {MISC_COL,	"GLong",  0, "Galactic longitude"},
     {MISC_COL,	"GLat",	  0, "Galactic latitude"},
-    {MISC_COL,	"EaDst",  0, "Distance from Earth"},
+    {MISC_COL,	"EaDst",  0, "Distance from Earth, AU (moon is km)"},
     {MISC_COL,	"EaLght", 0, "Light travel time from Earth"},
-    {MISC_COL,	"SnDst",  0, "Distance from Sun"},
+    {MISC_COL,	"SnDst",  0, "Distance from Sun, AU"},
     {MISC_COL,	"SnLght", 0, "Light travel time from Sun"},
     {MISC_COL,	"Elong",  0, "Elongation: angular degrees from Sun, +E"},
     {MISC_COL,	"Size",	  0, "Angular diameter, arc seconds"},
@@ -368,6 +369,19 @@ int whether;	/* whether setting up for plotting or for not plotting */
 		dm_set_buttons (whether);
 }
 
+/* return the user's horizon displacement, in rads.
+ * + means less sky.
+ */
+double
+dm_hzndep()
+{
+	char *str = XmTextFieldGetString (adprefr_w);
+	double dis = degrad(atod(str));
+
+	XtFree (str);
+	return (dis);
+}
+
 /* given the Now and Obj, fill in the RiseSet.
  * this takes into account the options currently in effect with the Data menu.
  */
@@ -378,20 +392,17 @@ Obj *op;
 RiseSet *rsp;
 {
 	double dis;	/* rads apparent horizon is above true */
-	char *str;
 
 	/* might get called before we have been managed the first time */
 	if (!dataform_w)
 	    dm_create_form();
 
 	/* user's displacement correction */
-	str = XmTextFieldGetString (adprefr_w);
-	dis = -degrad(atod(str));	/* user's + means less sky */
-	XtFree (str);
+	dis = -dm_hzndep();
 
 	/* add semi-diameter if want wrt limb */
         if (limb == LIMB)
-	    dis += degrad((double)op->s_size/3600./2.0);
+	    dis += degrad(op->s_size/3600./2.0);
 
 	riset_cir (np, op, dis, rsp);
 }
@@ -889,6 +900,7 @@ int c;
 Widget w;
 {
 	static char me[] = "dm_format()";
+	double tmp;
 
 	switch (c) {
 	case CONSTEL_ID:
@@ -897,35 +909,13 @@ Widget w;
 	case RA_ID:
 	    f_ra (w, op->s_ra);
 	    break;
-	case HA_ID: {
-	    double raeod = op->s_ra;
-	    double deceod = op->s_dec;
-	    double tmp;
-
-	    if (epoch != EOD) {
-		/* need apparent */
-		Obj o;
-		Now n;
-
-		(void) memcpy ((void *)&o, (void *)op, sizeof(Obj));
-		(void) memcpy ((void *)&n, (void *)np, sizeof(Now));
-		n.n_epoch = EOD;
-		(void) obj_cir (&n, &o);
-		raeod = o.s_ra;
-		deceod = o.s_dec;
-	    }
-
-	    now_lst (np, &tmp);
-	    tmp = tmp - radhr(raeod);	/* HA = LST - RA */
-	    if (tmp > 12)
-		tmp -= 24;
-	    if (tmp < -12)
-		tmp += 24;
+	case HA_ID:
+	    radec2ha (np, op->s_ra, op->s_dec, &tmp);
+	    tmp = radhr (tmp);
 	    if (pref_get(PREF_DPYPREC) == PREF_LOPREC)
 		f_sexa (w, tmp, 3, 600);
 	    else
-		f_sexa (w, tmp, 3, 36000);
-	    }
+		f_sexa (w, tmp, 3, 360000);
 	    break;
 	case DEC_ID:
 	    f_prdec (w, op->s_dec);
@@ -936,6 +926,9 @@ Widget w;
 	case ALT_ID:
 	    f_pangle (w, op->s_alt);
 	    break;
+	case ZEN_ID:
+	    f_pangle (w, PI/2 - op->s_alt);
+	    break;
 	case Z_ID: /* airmass */
 	    if (op->s_alt > 0.1)
 		f_double (w, "%4.2f", 1./sin(op->s_alt));
@@ -978,7 +971,7 @@ Widget w;
 	    break;
 	case EDST_ID:
 	    if (is_planet(op, MOON)) {
-		double tmp = op->s_edist;
+		tmp = op->s_edist;
 		if (pref_get(PREF_UNITS) == PREF_ENGLISH) {
 		    /* s_edist is stored in au, want miles */
 		    tmp *= MAU*FTPM/5280.0;
@@ -1042,9 +1035,12 @@ Widget w;
 		f_string (w, "      ");
 	    break;
 	case SIZE_ID:
-	    if (op->o_type != EARTHSAT)
-		f_double (w, "%5.0f", (double)(op->s_size));
-	    else
+	    if (op->o_type != EARTHSAT) {
+		if (op->s_size < 999.5)
+		    f_double (w, "%5.1f", op->s_size);
+		else
+		    f_double (w, "%5.0f", op->s_size);
+	    } else
 		f_string (w, "     ");
 	    break;
 	case VMAG_ID:
@@ -1303,7 +1299,7 @@ Widget parent;
 	};
 	Arg args[20];
 	XmString str;
-	Widget rl_w, cl_w;
+	Widget rl_w, cl_w, arc_w;
 	Widget rf_w, mf_w, rsf_w, sf_w, ctlf_w, rowrc_w, mrc_w, rsrc_w, src_w;
 	Widget sep_w, w;
 	Widget rb_w;
@@ -1394,6 +1390,12 @@ Widget parent;
 	rowrc_w = XmCreateRowColumn (rf_w, "DataSelRows", args, n);
 	XtManageChild (rowrc_w);
 
+	    n = 0;
+	    XtSetArg (args[n], XmNalignment, XmALIGNMENT_CENTER); n++;
+	    w = XmCreateLabel (rowrc_w, "L", args, n);
+	    set_xmstring (w, XmNlabelString, "Objects");
+	    XtManageChild (w);
+
 	    /* fill up with buttons for each possible row.
 	     * fill in name if it's a planet since that won't change.
 	     */
@@ -1456,6 +1458,7 @@ Widget parent;
 	XtSetArg (args[n], XmNtopWidget, sep_w); n++;
 	XtSetArg (args[n], XmNleftAttachment, XmATTACH_WIDGET); n++;
 	XtSetArg (args[n], XmNleftWidget, rf_w); n++;
+	XtSetArg (args[n], XmNleftOffset, 10); n++;
 	XtSetArg (args[n], XmNalignment, XmALIGNMENT_BEGINNING); n++;
 	cl_w = XmCreateLabel (sel_w, "Columns:", args, n);
 	XtManageChild (cl_w);
@@ -1469,6 +1472,7 @@ Widget parent;
 	XtSetArg (args[n], XmNbottomWidget, ctlf_w); n++;
 	XtSetArg (args[n], XmNleftAttachment, XmATTACH_WIDGET); n++;
 	XtSetArg (args[n], XmNleftWidget, rf_w); n++;
+	XtSetArg (args[n], XmNleftOffset, 10); n++;
 	mf_w = XmCreateFrame (sel_w, "DSMCFrame", args, n);
 	XtManageChild (mf_w);
 
@@ -1477,8 +1481,14 @@ Widget parent;
 	XtSetArg (args[n], XmNadjustMargin, False); n++;
 	XtSetArg (args[n], XmNisAligned, False); n++;
 	XtSetArg (args[n], XmNpacking, XmPACK_TIGHT); n++;
-	mrc_w = XmCreateRowColumn (mf_w, "DataSelMiscCols", args, n);
-	XtManageChild (mrc_w);
+	arc_w = XmCreateRowColumn (mf_w, "DataSelMiscCols", args, n);
+	XtManageChild (arc_w);
+
+	    n = 0;
+	    XtSetArg (args[n], XmNalignment, XmALIGNMENT_CENTER); n++;
+	    w = XmCreateLabel (arc_w, "L", args, n);
+	    set_xmstring (w, XmNlabelString, "Miscellaneous");
+	    XtManageChild (w);
 
 	    /* fill up with buttons for each possible col in misc range.
 	     * set those columns names that are stable.
@@ -1488,7 +1498,7 @@ Widget parent;
 
 	    n = 0;
 	    XtSetArg (args[n], XmNalignment, XmALIGNMENT_CENTER); n++;
-	    w = XmCreatePushButton (mrc_w, "Toggle", args, n);
+	    w = XmCreatePushButton (arc_w, "Toggle", args, n);
 	    XtAddCallback (w, XmNactivateCallback, ds_col_toggle_cb,
 							(XtPointer)MISC_COL);
 	    wtip (w, "Exchange on and off items in this column");
@@ -1498,7 +1508,7 @@ Widget parent;
 
 	    n = 0;
 	    XtSetArg (args[n], XmNalignment, XmALIGNMENT_CENTER); n++;
-	    w = XmCreatePushButton (mrc_w, "All", args, n);
+	    w = XmCreatePushButton (arc_w, "All", args, n);
 	    XtAddCallback (w, XmNactivateCallback, ds_col_all_cb,
 							(XtPointer)MISC_COL);
 	    wtip (w, "Turn all items in this row on");
@@ -1508,12 +1518,21 @@ Widget parent;
 
 	    n = 0;
 	    XtSetArg (args[n], XmNalignment, XmALIGNMENT_CENTER); n++;
-	    w = XmCreatePushButton (mrc_w, "Reset", args, n);
+	    w = XmCreatePushButton (arc_w, "Reset", args, n);
 	    XtAddCallback (w, XmNactivateCallback, ds_col_reset_cb,
 							(XtPointer)MISC_COL);
 	    wtip (w, "Return each item in this column to its original state");
 	    XtManageChild (w);
 
+	    n = 0;
+	    XtSetArg (args[n], XmNorientation, XmVERTICAL); n++;
+	    XtSetArg (args[n], XmNadjustMargin, False); n++;
+	    XtSetArg (args[n], XmNisAligned, False); n++;
+	    XtSetArg (args[n], XmNpacking, XmPACK_COLUMN); n++;
+	    XtSetArg (args[n], XmNnumColumns, 2); n++;
+	    mrc_w = XmCreateRowColumn (arc_w, "DataSelMiscCols", args, n);
+	    XtManageChild (mrc_w);
+
 	/* make the rise/set col selection rc in a frame */
 
 	n = 0;
@@ -1534,6 +1553,12 @@ Widget parent;
 	rsrc_w = XmCreateRowColumn (rsf_w, "DataSelRisetCols", args, n);
 	XtManageChild (rsrc_w);
 
+	    n = 0;
+	    XtSetArg (args[n], XmNalignment, XmALIGNMENT_CENTER); n++;
+	    w = XmCreateLabel (rsrc_w, "L", args, n);
+	    set_xmstring (w, XmNlabelString, "Rise/Set");
+	    XtManageChild (w);
+
 	    /* fill up with buttons for each possible col in rise/set range.
 	     * set those columns names that are stable.
 	     */
@@ -1616,6 +1641,12 @@ Widget parent;
 	src_w = XmCreateRowColumn (sf_w, "DataSelSepCols", args, n);
 	XtManageChild (src_w);
 
+	    n = 0;
+	    XtSetArg (args[n], XmNalignment, XmALIGNMENT_CENTER); n++;
+	    w = XmCreateLabel (src_w, "L", args, n);
+	    set_xmstring (w, XmNlabelString, "Separations");
+	    XtManageChild (w);
+
 	    /* fill up with buttons for each possible col in sep range.
 	     * set those columns names that are stable.
 	     */
@@ -1951,7 +1982,7 @@ dm_create_flist_w()
 	Arg args[20];
 	int n;
 
-	(void) sprintf (fname, "%s/datatbl.txt", getXRes ("UserDir", "work"));
+	(void) sprintf (fname, "%s/datatbl.txt", getXRes("PrivateDir","work"));
 
 	n = 0;
 	XtSetArg(args[n], XmNdefaultPosition, False);  n++;
@@ -2158,3 +2189,6 @@ char buf[];
 	}
 	sprintf (buf+strlen(buf), "\n");
 }
+
+/* For RCS Only -- Do Not Edit */
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: datamenu.c,v $ $Date: 1999/02/15 23:21:12 $ $Revision: 1.2 $ $Name:  $"};
