@@ -41,7 +41,7 @@ extern XtAppContext xe_app;
 
 extern FILE *fopenh P_((char *name, char *how));
 extern Now *mm_get_now P_((void));
-extern char *getBaseDir P_((void));
+extern char *getShareDir P_((void));
 extern char *getXRes P_((char *name, char *def));
 extern char *syserrstr P_((void));
 extern int db_read P_((FILE *fp, int nodups));
@@ -93,6 +93,15 @@ static DBMem db[NOBJTYPES];	/* this is the head for each object */
 #define	OBJP(t,n)	\
 		((Obj *)(db[t].dblist[(n)/DBCHUNK] + ((n)%DBCHUNK)*db[t].size))
 
+/* Size quantizer to keep objects allocated in the heap worst-case-aligned.
+ * This assumes that double will be the largest primitive data type
+ * on all systems.  Not elegant but gets it done for the moment.
+ * make it a no-op if you are sure your architecture won't benefit.
+ * Credit to: Monty Brandenberg, mcbinc@world.std.com.
+ */
+#define DB_SIZE_ROUND(s)        \
+			  (((s) + sizeof(double) - 1) & ~(sizeof(double) - 1))
+
 /* db fifo fd and XtAddInput id.
  */
 static int db_fifofd = -1;
@@ -167,7 +176,7 @@ db_loadinitial()
 {
 	static char dbi[] = "DBinitialFiles";	/* init files resource name */
 	char *fns;		/* value of DBinitialFiles */
-	char *dir;		/* value of BaseDir */
+	char *dir;		/* value of ShareDir */
 	char dbicpy[2048];	/* local copy of dir */
 	char *fnf[128];		/* ptrs into dbicpy[] at each ' ' */
 	char fn[1024];		/* each dir/filename */
@@ -177,7 +186,7 @@ db_loadinitial()
 	int i;
 
 	/* get the base directory name */
-	dir = getBaseDir();
+	dir = getShareDir();
 
 	/* get the initial list of files */
 	fns = getXRes (dbi, "YBS.edb Messier.edb");
@@ -339,8 +348,9 @@ Obj *op;
 		    op == OBJP(PLANET,OBJX) || op == OBJP(PLANET,OBJY ||
 					       op == OBJP(PLANET,OBJZ))) {
 	    if (obj_cir (mm_get_now(), op) < 0) {
-		printf ("%s: bad object\n", me);
-		exit(1);
+		char buf[64];
+		(void) sprintf (buf, "%s: no longer valid", op->o_name);
+		xe_msg (buf, 0);
 	    }
 	    op->o_age = db_age;
 	}
@@ -502,11 +512,21 @@ int nodups;
 
 	/* read each line from the file and add good ones to the db */
 	while (fgets (buf, sizeof(buf), fp)) {
+	    char whynot[128];
 	    Obj o;
 
 	    pm_set ((int)(ftell(fp)*100/len)); /* update progress meter */
 
-	    if (db_crack_line (buf, &o) < 0 || o.o_type == PLANET)
+	    if (db_crack_line (buf, &o, whynot) < 0) {
+		if (whynot[0] != '\0') {
+		    char wholemsg[1024];
+		    (void) sprintf (wholemsg, "Bad edb: %s: %s", buf, whynot);
+		    xe_msg (wholemsg, 0);
+		}
+		continue;
+	    }
+
+	    if (o.o_type == PLANET)
 		continue;
 
 	    if (nodups) {
@@ -552,7 +572,7 @@ db_connect_fifo()
 	 * processes using it come and go as they please.
 	 */
 	if (fn[0] == '\0')
-	    (void) sprintf(fn,"%s/fifos/xephem_db_fifo", getBaseDir());
+	    (void) sprintf(fn,"%s/fifos/xephem_db_fifo", getShareDir());
 	db_fifofd = openh (fn, 2);
 	if (db_fifofd < 0) {
 	    char msg[256];
@@ -627,12 +647,12 @@ db_init()
 	 * N.B. must do this before using the OBJP macro
 	 */
 	db[UNDEFOBJ].size	= 0;
-	db[FIXED].size		= sizeof(ObjF);
-	db[ELLIPTICAL].size	= sizeof(ObjE);
-	db[HYPERBOLIC].size	= sizeof(ObjH);
-	db[PARABOLIC].size	= sizeof(ObjP);
-	db[EARTHSAT].size	= sizeof(ObjES);
-	db[PLANET].size		= sizeof(Obj); /* *NOT* ObjPl */
+	db[FIXED].size		= DB_SIZE_ROUND(sizeof(ObjF));
+	db[ELLIPTICAL].size	= DB_SIZE_ROUND(sizeof(ObjE));
+	db[HYPERBOLIC].size	= DB_SIZE_ROUND(sizeof(ObjH));
+	db[PARABOLIC].size	= DB_SIZE_ROUND(sizeof(ObjP));
+	db[EARTHSAT].size	= DB_SIZE_ROUND(sizeof(ObjES));
+	db[PLANET].size		= DB_SIZE_ROUND(sizeof(Obj)); /* *NOT* ObjPl */
 
 	/* init the planets.
 	 * because the number is fixed, we use static storage for the NOBJ
@@ -716,7 +736,7 @@ XtInputId *idp;         /* pointer to input id */
 			xe_msg (msg, 0);
 		    } else {
 			Obj o;
-			if (db_crack_line (lp, &o) < 0) {
+			if (db_crack_line (lp, &o, NULL) < 0) {
 			    (void) sprintf (msg, "Bad DBFIFO line: %s", lp);
 			    xe_msg (msg, 0);
 			} else {
@@ -766,3 +786,6 @@ XtInputId *idp;         /* pointer to input id */
 	    watch_cursor (0);
 	}
 }
+
+/* For RCS Only -- Do Not Edit */
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: db.c,v $ $Date: 1998/12/22 06:19:07 $ $Revision: 1.4 $ $Name:  $"};
