@@ -190,13 +190,22 @@ static int LoadGIF(pinfo)
   
   /* Read in global colormap. */
   
-  if (HasColormap)
+  if (HasColormap) {
     for (i=0; i<ColorMapSize; i++) {
       pinfo->r[i] = NEXTBYTE;
       pinfo->g[i] = NEXTBYTE;
       pinfo->b[i] = NEXTBYTE;
     }
-  else {  /* no colormap in GIF file */
+
+    /* fill out with last color to avoid garbage clobbering xephem colormap.
+     * from Jean-Etienne.LAMIAUD@tcc.thomson-csf.com
+     */
+    for( ; i < 256; i++ ) {
+	pinfo->r[i] = pinfo->r[ColorMapSize-1];
+	pinfo->g[i] = pinfo->g[ColorMapSize-1];
+	pinfo->b[i] = pinfo->b[ColorMapSize-1];
+    }
+  } else {  /* no colormap in GIF file */
     /* put std EGA palette (repeated 16 times) into colormap, for lack of
        anything better to do */
 
