@@ -235,7 +235,6 @@ String fallbacks[] = {
     "XEphem*SkyFITS*UseGzip.set: True",
     "XEphem*SkyFITS.x: 600",
     "XEphem*SkyFITS.y: 10",
-    "XEphem*SkyFilter*AutoMag.set: True",
     "XEphem*SkyFilter*Binary.set: True",
     "XEphem*SkyFilter*BrightNeb.set: True",
     "XEphem*SkyFilter*ClInNeb.set: True",
@@ -250,7 +249,6 @@ String fallbacks[] = {
     "XEphem*SkyFilter*Hyperbolic.set: True",
     "XEphem*SkyFilter*MagStep.value: 1",
     "XEphem*SkyFilter*Multiple.set: True",
-    "XEphem*SkyFilter*NearSkyMag.value: 5",
     "XEphem*SkyFilter*OpenCl.set: True",
     "XEphem*SkyFilter*Parabolic.set: True",
     "XEphem*SkyFilter*PlanetaryNeb.set: True",
@@ -259,8 +257,10 @@ String fallbacks[] = {
     "XEphem*SkyFilter*Quasars.set: True",
     "XEphem*SkyFilter*Radio.set: True",
     "XEphem*SkyFilter*SNRemnants.set: True",
+    "XEphem*SkyFilter*SolSysMag.value: 5",
     "XEphem*SkyFilter*SphericalGal.set: True",
     "XEphem*SkyFilter*SpiralGal.set: True",
+    "XEphem*SkyFilter*StarMag.value: 5",
     "XEphem*SkyFilter*Stars.set: True",
     "XEphem*SkyFilter*Stellar.set: True",
     "XEphem*SkyFilter*SymbolDA.background: #222",
@@ -271,7 +271,10 @@ String fallbacks[] = {
     "XEphem*SkyFilter.x: 400",
     "XEphem*SkyFilter.y: 10",
     "XEphem*SkyList*background: #fd6",
+    "XEphem*SkyList*TextFilename.value: ~/XEphem/skylist.txt",
+    "XEphem*SkyList*EdbFilename.value: ~/XEphem/skylist.edb",
     "XEphem*SkyOps*AltAzMode.set: True",
+    "XEphem*SkyOps*AutoMag.set: True",
     "XEphem*SkyOps*CnsBoundaries.set: False",
     "XEphem*SkyOps*CnsFigures.set: True",
     "XEphem*SkyOps*CnsNames.set: False",
@@ -287,12 +290,15 @@ String fallbacks[] = {
     "XEphem*SkyOps*Grid*Grid.set: False",
     "XEphem*SkyOps*HznMap.set: False",
     "XEphem*SkyOps*JustDots.set: True",
-    "XEphem*SkyOps*LblAll.set: False",
-    "XEphem*SkyOps*LblBrightDeep.set: False",
-    "XEphem*SkyOps*LblBrightNear.set: True",
-    "XEphem*SkyOps*LblFldStars.set: True",
-    "XEphem*SkyOps*LblMags.set: False",
-    "XEphem*SkyOps*LblNames.set: True",
+    "XEphem*SkyOps*LblDSMag.set: False",
+    "XEphem*SkyOps*LblDSName.set: True",
+    "XEphem*SkyOps*LblNDeepSky.value: 10",
+    "XEphem*SkyOps*LblNSolSys.value: 10",
+    "XEphem*SkyOps*LblNStars.value: 10",
+    "XEphem*SkyOps*LblSSMag.set: False",
+    "XEphem*SkyOps*LblSSName.set: True",
+    "XEphem*SkyOps*LblStMag.set: False",
+    "XEphem*SkyOps*LblStName.set: True",
     "XEphem*SkyOps*LiveDrag.set: True",
     "XEphem*SkyOps*LiveReport.set: False",
     "XEphem*SkyOps*MagScale.set: True",
@@ -384,10 +390,10 @@ String fallbacks[] = {
     "XEphem*marginLeft: 1",
     "XEphem*marginRight: 1",
     "XEphem*spacing: 1",
-    "XEphem.AutoMag: .35 18 16 1, .7 17 15 1, .9 16 14 1, 1.4 15 13 1, 2.8 14 12 1, 5.6 13 11 1, 11 12 10 1, 22 11 9 1, 45 10 8 1, 90 9 7 1, 180 7 5 1",
+    "XEphem.AutoMag: .35 16 16 18 1, .7 15 15 17 1, .9 14 14 16 1, 1.4 13 13 15 1, 2.8 12 12 14 1, 5.6 11 11 13 1, 11 10 10 12 1, 22 9 9 11 1, 45 8 8 10 1, 90 7 7 9 1, 180 5 5 7 1",
     "XEphem.CalOtherMonthColor: gray50",
     "XEphem.CnsFont: -*-times-medium-i-*-*-14-*-*-*-*-*-*-*",
-    "XEphem.DBinitialFiles: Messier.edb NGC.edb SAC.edb YBS.edb minorpl.edb comets.edb ISS.edb",
+    "XEphem.DBinitialFiles: Messier.edb NGC.edb SAC.edb YBS.edb asteroids.edb comets.edb ISS.edb",
     "XEphem.DeltaT: Turn Auto on",
     "XEphem.EarthBorderColor: #77a",
     "XEphem.EarthEclipseColor: #333",
@@ -417,7 +423,6 @@ String fallbacks[] = {
     "XEphem.SkyEqColor: #f30",
     "XEphem.SkyEyePColor: #b33",
     "XEphem.SkyGridColor: #595",
-    "XEphem.SkyNBright: 20",
     "XEphem.SkyTrackFont: -*-lucidatypewriter-medium-r-*-*-12-*-*-*-m-*-*-*",
     "XEphem.StepSize: RT Clock",
     "XEphem.Temp: 10",
@@ -459,4 +464,4 @@ String fallbacks[] = {
     NULL
 };
 
-/* $Id: fallbacks.c,v 1.20 1999/03/16 16:39:07 ecdowney Exp $ */
+/* $Id: fallbacks.c,v 1.26 1999/10/15 20:11:46 ecdowney Exp $ */
