@@ -49,7 +49,7 @@ ObjF **opp;	/* *opp is malloced with stars found */
 int nop;	/* number already at *opp */
 char msg[];	/* return diagnostic message here, if returning -1 */
 {
-static char ofmt[] = "%s?VERSION=3&FMT=EDB&CENTRIC=GEO&PRECES=ASTRO&GS=on&DATE=Now&TIME=&RA=%s&DEC=%s&FOV=%g&MAG=%g&LAT=0+0+0&LONG=0+0+0&ELEV=0 HTTP/1.0\nUser-Agent: xephem/%s\n\n";
+static char ofmt[] = "%s?VERSION=3&FMT=EDB&CENTRIC=GEO&PRECES=ASTRO&GS=on&DATE=Now&TIME=&RA=%s&DEC=%s&FOV=%g&MAG=%g&LAT=0+0+0&LONG=0+0+0&ELEV=0 HTTP/1.0\r\nUser-Agent: xephem/%s\r\n\r\n";
 	char *h0p, *h1p, host[1024];
 	char rbuf[32], *rbp, dbuf[32], *dbp;
 	char buf[2048];
@@ -128,7 +128,7 @@ char msg[];	/* return diagnostic message here, if returning -1 */
 {
 	static char eso_host[] = "archive.eso.org";
 static char ifmt[] = "%s %lf %lf %lf %lf %lf %lf %*s %lf %*s %*s %d";
-static char ofmt[] = "/skycat/servers/gsc-server?%.6f%c%.6f&r=0,%.1f&m=0,%g&s=R&f=1&* HTTP/1.0\nUser-Agent: xephem/%s\n\n";
+static char ofmt[] = "/skycat/servers/gsc-server?%.6f%c%.6f&r=0,%.1f&m=0,%g&s=R&f=1&* HTTP/1.0\r\nUser-Agent: xephem/%s\r\n\r\n";
 	static char eofcode[] = "[EOD]";
 	char buf[1024];
 	int sockfd;
@@ -216,4 +216,4 @@ int nnew;
 }
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: gscnet.c,v $ $Date: 1998/10/16 05:02:33 $ $Revision: 1.2 $ $Name:  $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: gscnet.c,v $ $Date: 1999/03/17 21:57:05 $ $Revision: 1.3 $ $Name:  $"};
