@@ -2162,7 +2162,7 @@ MoonData md[NM];	/* fill in md[1..NM-1].x/y/z for each moon.
 	M = (358.47583 + 0.98560003*d);
 	N = (225.32833 + 0.0830853*d) + 0.33 * dsin (V);
 
-	J = 221.647 + 0.9025179*d - 0.33 * dsin(V);;
+	J = 221.647 + 0.9025179*d - 0.33 * dsin(V);
 
 	A = 1.916*dsin(M) + 0.02*dsin(2*M);
 	B = 5.552*dsin(N) + 0.167*dsin(2*N);
@@ -2296,4 +2296,4 @@ MoonData md[NM];        /* fill md[1..NM-1].x/y/z for each moon */
 }
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: jupmenu.c,v $ $Date: 1999/03/03 19:06:34 $ $Revision: 1.8 $ $Name:  $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: jupmenu.c,v $ $Date: 1999/10/25 21:01:55 $ $Revision: 1.9 $ $Name:  $"};
