@@ -531,7 +531,7 @@ int update;
 
 	/* new timezone if desired */
 	if (autotz) {
-	    char buf[64];
+	    static char buf[64]; /* putenv() wants stable string */
 
 	    if (sp && sp->si_tzdefn[0] != '\0')
 		(void) sprintf (buf, "TZ=%s", sp->si_tzdefn);
@@ -2405,4 +2405,4 @@ static char *hlp[] = {
 }
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: mainmenu.c,v $ $Date: 1999/02/23 22:09:18 $ $Revision: 1.8 $ $Name:  $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: mainmenu.c,v $ $Date: 1999/08/24 15:19:21 $ $Revision: 1.9 $ $Name:  $"};
