@@ -49,7 +49,7 @@ extern FILE *fopenh P_((char *name, char *how));
 extern Now *mm_get_now P_((void));
 extern Obj *db_basic P_((int id));
 extern Obj *db_scan P_((DBScan *sp));
-extern char *getBaseDir P_((void));
+extern char *getShareDir P_((void));
 extern char *mm_getsite P_((void));
 extern double atod P_((char *buf));
 extern double delra P_((double dra));
@@ -70,6 +70,7 @@ extern void f_mtime P_((Widget w, double t));
 extern void f_pangle P_((Widget w, double a));
 extern void f_showit P_((Widget w, char *s));
 extern void f_dm_angle P_((Widget w, double a));
+extern void f_sexa P_((Widget wid, double a, int w, int fracbase));
 extern void fs_date P_((char out[], double jd));
 extern void fs_dm_angle P_((char out[], double a));
 extern void fs_manage P_((void));
@@ -78,6 +79,7 @@ extern void get_something P_((Widget w, char *resource, XtArgVal value));
 extern void get_xmstring P_((Widget w, char *resource, char **txtp));
 extern void get_views_font P_((Display *dsp, XFontStruct **fspp));
 extern void hlp_dialog P_((char *tag, char *deflt[], int ndeflt));
+extern void marsm_manage P_((void));
 extern void obj_pickgc P_((Obj *op, Widget w, GC *gcp));
 extern void pm_set P_((int percentage));
 extern void range P_((double *v, double r));
@@ -96,25 +98,15 @@ extern void zero_mem P_((void *loc, unsigned len));
 #define	POLE_RA		degrad(317.61)
 #define	POLE_DEC	degrad(52.85)
 
-typedef struct {
-    Obj o;			/* copy of sky object info */
-    int x, y;			/* X location on mda_w */
-} SkyObj;
-
-static SkyObj *skyobjs;		/* malloced list of objects in sky background */
-static int nskyobjs;		/* number of objects in skyobjs[] list */
-
-static void resetSkyObj P_((void));
-static void addSkyObj P_((Obj *op, int x, int y));
-static Obj *closeSkyObj P_((int x, int y));
 static void m_popup P_((XEvent *ep));
-static void m_create_skypopup P_((void));
+static void m_create_popup P_((void));
 
 static void m_create_form P_((void));
 static void m_create_msform P_((void));
 static void m_set_buttons P_((int whether));
 static void m_set_a_button P_((Widget pbw, int whether));
 static void m_mstats_cb P_((Widget w, XtPointer client, XtPointer call));
+static void m_moons_cb P_((Widget w, XtPointer client, XtPointer call));
 static void m_selection_cb P_((Widget w, XtPointer client, XtPointer call));
 static void m_cml_cb P_((Widget w, XtPointer client, XtPointer call));
 static void m_slt_cb P_((Widget w, XtPointer client, XtPointer call));
@@ -149,7 +141,6 @@ static void mBWdither P_((void));
 static void m_orientation P_((void));
 static void m_sizecal P_((void));
 static int m_labels P_((void));
-static void m_sky P_((void));
 static void m_grid P_((void));
 static void m_reportloc P_((int x, int y));
 static void m_eqproject P_((Now *np, double ra, double dec, int *xp, int *yp));
@@ -165,7 +156,7 @@ static void mars_cml P_((Now *np, double *cmlp, double *sltp, double *pap));
 #define	MAXCOLORS	40	/* max colors to use for image */
 #define	BORD		80	/* extra drawing area border for labels/stars */
 #define	LGAP		20	/* gap between NSEW labels and image edge */
-#define	FMAG		12	/* faintest mag of sky background object */
+#define	FMAG		16	/* faintest mag of sky background object */
 #define	MAXR		10	/* max gap when picking sky objects, pixels */	
 #define	GSP	degrad(15.0)	/* grid spacing */
 #define	FSP	(GSP/5.)	/* fine spacing */
@@ -175,7 +166,7 @@ static void mars_cml P_((Now *np, double *cmlp, double *sltp, double *pap));
 
 static FImage marsfits;		/* the Mars FITS images */
 static unsigned char *mimage;	/* malloced array of raw mars image */
-static Pixel mcolors[MAXCOLORS]; /* color-scale ramp for drawing image */
+static Pixel mcolors[MAXCOLORS];/* color-scale ramp for drawing image */
 static int nmcolors;		/* number of pixels usable in mcolors[] */
 static Pixel mbg;		/* background color for image */
 static int mdepth;		/* depth of image, in bits */
@@ -211,30 +202,21 @@ static int mswasman;            /* whether "More info" form was managed */
 static int fakepos;		/* set when cml/slt/pa etc are not true */
 
 /* sky background object's widgets */
-static Widget skypu_w;		/* sky popup */
-static Widget skypu_name_w;	/* popup name label */
-static Widget skypu_mag_w;	/* popup mag label */
-static Widget skypu_aim_w;	/* popup aim PB */
+static Widget skypu_w;		/* popup */
+static Widget skypu_l_w;	/* popup lat label */
+static Widget skypu_L_w;	/* popup Long label */
+static Widget skypu_aim_w;	/* popup Point PB */
 static double skypu_l;		/* latitude if Point PB is activated */
 static double skypu_L;		/* longitude if Point PB is activated */
 
-/* field star support */
-static ObjF *fstars;            /* malloced list of field stars, or NULL */
-static int nfstars;             /* number of entries in fstars[] */
-static double fsdec, fsra;      /* location when field stars were loaded */
-#define FSFOV   degrad(0.5)     /* size of FOV to fetch, rads */
-#define FSMAG	((double)FMAG)	/* limiting mag for fetch */
-#define FSMOVE  degrad(.1)      /* reload when mars has moved this far, rads */
-static void m_loadfs P_((Now *np, double ra, double dec));
-
 static GC m_fgc, m_bgc, m_agc;	/* various GCs */
-static XFontStruct *m_fsp;	/*label font */
+static XFontStruct *m_fsp;	/* label font */
 
 static int m_selecting;		/* set while our fields are being selected */
 
 /* options list */
 typedef enum {
-    GRID_OPT, LABELS_OPT, FLIPLR_OPT, FLIPTB_OPT, SKY_OPT, COARSE_OPT,
+    GRID_OPT, LABELS_OPT, FLIPLR_OPT, FLIPTB_OPT, COARSE_OPT,
     N_OPT
 } Option;
 static int option[N_OPT];
@@ -262,7 +244,7 @@ mars_manage ()
 	    /* build dialogs */
 	    m_create_form();
 	    m_create_msform();
-	    m_create_skypopup();
+	    m_create_popup();
 
 	    /* establish depth, colors and bits per pixel */
 	    get_something (mda_w, XmNdepth, (XtArgVal)&mdepth);
@@ -357,17 +339,6 @@ Cursor c;
 	}
 }
 
-/* called when the database has changed.
- * if we are drawing background, we'd best redraw everything.
- */
-void
-mars_newdb (appended)
-int appended;
-{
-	if (option[SKY_OPT] && mars_ison())
-	    m_redraw();
-}
-
 static void
 m_create_form()
 {
@@ -380,8 +351,6 @@ m_create_form()
 	static OpSetup ops[] = {
 	    {LABELS_OPT,	"Labels",	"Feature labels",
 	    	"When on, major surface features will be labeled"},
-	    {SKY_OPT,		"SkyBkg",	"Sky background",
-		"When on, sky will include database objects and Field Stars"},
 	    {FLIPTB_OPT,	"FlipTB",	"Flip T/B",
 	    	"Flip the map top-to-bottom"},
 	    {FLIPLR_OPT,	"FlipLR",	"Flip L/R",
@@ -459,15 +428,6 @@ m_create_form()
 	    wtip (w, "Print the current Mars map");
 	    XtManageChild (w);
 
-	    /* the "Field stars" push button */
-
-	    n = 0;
-	    w = XmCreatePushButton (pd_w, "FS", args, n);
-	    set_xmstring (w, XmNlabelString, "Setup Field Stars...");
-	    XtAddCallback (w, XmNactivateCallback, (XtCallbackProc)fs_manage,0);
-	    wtip (w, "Define where GSC and PPM catalogs are to be found");
-	    XtManageChild (w);
-
 	    /* add a separator */
 	    n = 0;
 	    w = XmCreateSeparator (pd_w, "CtS", args, n);
@@ -528,6 +488,15 @@ m_create_form()
 	    wtip (w, "Display additional information and controls");
 	    XtManageChild (w);
 
+	    /* add the Moons control */
+
+	    n = 0;
+	    w = XmCreatePushButton (pd_w, "Moons", args, n);
+	    set_xmstring (w, XmNlabelString, "Moon info...");
+	    XtAddCallback (w, XmNactivateCallback, m_moons_cb, NULL);
+	    wtip (w, "Display schematic view of Mars and its moons");
+	    XtManageChild (w);
+
 	/* make the help pulldown */
 
 	n = 0;
@@ -987,6 +956,17 @@ int whether;
 	XtSetValues (pbw, ap, na);
 }
 
+/* callback from the Moons button */
+/* ARGSUSED */
+static void
+m_moons_cb (w, client, call)
+Widget w;
+XtPointer client;
+XtPointer call;
+{
+	marsm_manage();
+}
+
 /* callback from the Close button on the stats menu or when
  * the More Info button is activated. they each do the same thing.
  */
@@ -1034,8 +1014,6 @@ XtPointer call;
 static void
 m_print ()
 {
-	XFontStruct *fsp;
-
 	/* must be up */
 	if (!mars_ison()) {
 	    xe_msg ("Mars must be open to print.", 1);
@@ -1049,9 +1027,8 @@ m_print ()
 	XPSXBegin (m_pm, 0, 0, IMSZ+2*BORD, IMSZ+2*BORD, 1*72, 10*72,
 								(int)(6.5*72));
 
-        /* get and register the font to use for all gcs from obj_pickgc() */
-	get_views_font (XtD, &fsp);
-	XPSRegisterFont (fsp->fid, "Helvetica");
+        /* register the font to use for all gcs from obj_pickgc() */
+	XPSRegisterFont (m_fsp->fid, "Helvetica");
 
 	/* redraw everything now */
 	m_redraw();
@@ -1090,17 +1067,21 @@ m_imps ()
 	    return;
 	}
 
-	/* init colormap to gray ramp */
+	/* init colormap to inverse gray ramp. 
+	 * then print inverse again, to get black text.
+	 * set background to black (er, white) to avoid wasting ink.
+	 */
 	for (i = 0; i < nmcolors; i++)
-	    cmap[i] = i;
+	    cmap[i] = nmcolors - 1 - i;
+	cmap[0] = 0;
 
 	/* render image into pix[] */
 	image_setup (array_pixel, (void *)pix);
 
 	/* render in postscript -- it's already flipped */
-	XPSImage (m_pm, pix, cmap, nmcolors-1, 0, BORD, BORD, IMSZ, IMSZ, 0, 0);
+	XPSImage (m_pm, pix, cmap, nmcolors-1, 1, BORD, BORD, IMSZ, IMSZ, 0, 0);
 
-	/* ok */
+	/* ok */
 	free ((void *)cmap);
 	free ((void *)pix);
 }
@@ -1117,12 +1098,7 @@ m_ps_annotate ()
 
 	/* caption */
 	y = AROWY(13);
-	if (option[SKY_OPT])
-	    (void) sprintf (buf, "XEphem %s Mars View",
-			pref_get(PREF_EQUATORIAL)==PREF_GEO ? "Geocentric"
-							    : "Topocentric");
-	else
-	    (void) strcpy (buf, "XEphem Mars View");
+	(void) strcpy (buf, "XEphem Mars View");
 	(void) sprintf (dir, "(%s) %d %d cstr", buf, ctr, y);
 	XPSDirect (dir);
 
@@ -1148,8 +1124,8 @@ m_ps_annotate ()
 			fakepos ? "Center" : "Sub Earth", rx, y, buf, rx+10, y);
 	XPSDirect (dir);
 
-	/* add site/lat/long if just real stars and topocentric */
-	if (option[SKY_OPT] && pref_get(PREF_EQUATORIAL) == PREF_TOPO) {
+	/* add site/lat/long if topocentric */
+	if (pref_get(PREF_EQUATORIAL) == PREF_TOPO) {
 	    char *site;
 
 	    /* put site name under caption */
@@ -1345,12 +1321,6 @@ XtPointer call;
 	    XFreePixmap (XtD, m_pm);
 	    m_pm = 0;
 	}
-
-	if (fstars) {
-	    free ((void *)fstars);
-	    fstars = NULL;
-	    nfstars = 0;
-	}
 }
 
 /* called from Close button */
@@ -1393,14 +1363,6 @@ XtPointer call;
 		m_redraw();
 	    break;
 
-	case SKY_OPT:
-	    if (set) {
-		m_sky();
-		m_refresh (NULL);
-	    } else
-		m_redraw();
-	    break;
-
 	case LABELS_OPT:
 	    if (set) {
 		if (m_labels() < 0) {
@@ -1481,7 +1443,7 @@ XtPointer call;
 	switch (c->reason) {
 	case XmCR_EXPOSE: {
 	    /* turn off backing store */
-	    static before;
+	    static int before;
 
 	    if (!before) {
 		XSetWindowAttributes swa;
@@ -1554,7 +1516,7 @@ m_fits()
 	int v;
 
 	/* open mars map */
-	(void) sprintf (fn, "%s/auxil/marsmap.fts",  getBaseDir());
+	(void) sprintf (fn, "%s/auxil/marsmap.fts",  getShareDir());
 	fd = openh (fn, 0);
 	if (fd < 0) {
 	    (void) sprintf (msg, "%s: %s\n", fn, syserrstr());
@@ -1826,7 +1788,7 @@ m_draw ()
 	mxim_setup ();
 
 	/* clear m_pm */
-	XPSFillRectangle (XtD, m_pm, m_bgc, 0, 0, IMSZ+2*BORD, IMSZ+2*BORD);
+	XFillRectangle (XtD, m_pm, m_bgc, 0, 0, IMSZ+2*BORD, IMSZ+2*BORD);
 
 	/* copy m_xim to p_pm */
 	XPutImage (XtD, m_pm, m_fgc, m_xim, 0, 0, BORD, BORD, IMSZ, IMSZ);
@@ -1846,11 +1808,6 @@ m_draw ()
 		option[LABELS_OPT] = 0;
 	    }
 
-	/* add sky background objects, if enabled */
-	resetSkyObj();
-	if (option[SKY_OPT])
-	    m_sky();
-
 	/* always add orientation markings */
 	m_orientation();
 
@@ -1869,7 +1826,7 @@ m_labels()
 	FILE *fp;
 
 	/* open the file */
-	(void) sprintf (fn, "%s/auxil/mars_db",  getBaseDir());
+	(void) sprintf (fn, "%s/auxil/mars_db",  getShareDir());
 	fp = fopenh (fn, "r");
 	if (!fp) {
 	    (void) sprintf (buf, "%s: %s", fn, syserrstr());
@@ -1915,109 +1872,6 @@ m_labels()
 	return (0);
 }
 
-/* add background sky objects to m_pm and to skyobjs[] list */
-static void
-m_sky()
-{
-	static before;
-	Now *np = mm_get_now();
-	DBScan dbs;
-	double scale;		/* rads per pixel */
-	double mrad;		/* mars radius, rads */
-	double maxr;		/* max rad to show objects, rads */
-	Obj *op;
-
-	if (!before && pref_get(PREF_EQUATORIAL) == PREF_GEO) {
-	    xe_msg ("Equatorial preference should probably be set to Topocentric", 1);
-	    before = 1;
-	}
-
-	/* find size and scale */
-	mrad = degrad((double)(marsop->s_size)/3600.0/2.0);
-	scale = mrad/IMR;
-	maxr = 2*(IMR+BORD)*scale;
-
-	/* load field stars */
-	m_loadfs (np, marsop->s_gaera, marsop->s_gaedec);
-
-	/* scan the database and draw whatever is near */
-	for (db_scaninit(&dbs, ALLM, fstars, nfstars);
-					    (op = db_scan (&dbs)) != NULL; ) {
-	    int diam;
-	    int x, y;
-	    GC gc;
-
-	    /* get fresh circumstances */
-	    if (is_planet (op, MARS)) {
-		/* we draw it elsewhere :-) */
-		continue;
-	    }
-	    db_update (op);
-
-	    /* reject if too faint or obviously too far away */
-	    if (get_mag(op) > FMAG)
-		continue;
-	    if (fabs(op->s_gaedec - marsop->s_gaedec) > maxr ||
-			    cm_dec*delra(op->s_gaera - marsop->s_gaera) > maxr)
-		continue;
-
-	    /* find location relative to image center */
-	    m_eqproject (np, op->s_gaera, op->s_gaedec, &x, &y);
-
-	    /* reject if within mars circle */
-	    if (x*x + y*y <= IMR*IMR)
-		continue;
-
-	    /* allow for flipping and shift to find window coords */
-	    x = IX2XX(x);
-	    y = IY2XY(y);
-
-	    /* pick a gc */
-	    obj_pickgc(op, toplevel_w, &gc);
-
-	    /* draw it -- beware of huge sizes at this scale */
-	    diam = magdiam (FMAG, 2, scale, get_mag(op),
-					    degrad((double)op->s_size/3600.0));
-	    if (diam > MAXOBJR)
-		diam = MAXOBJR;
-	    sv_draw_obj (XtD, m_pm, gc, op, x, y, diam, 1);
-
-	    /* add to skyobjs[] list */
-	    addSkyObj (op, x, y);
-	}
-
-        sv_draw_obj (XtD, m_pm, (GC)0, NULL, 0, 0, 0, 0);        /* flush */
-}
-
-/* load field stars around the given location, unless current set is
- * already close enough.
- */
-static void
-m_loadfs (np, ra, dec)
-Now *np;
-double ra, dec;
-{
-
-	if (fstars && fabs(dec-fsdec)<FSMOVE && cm_dec*delra(ra-fsra)<FSMOVE)
-	    return;
-
-	if (fstars) {
-	    free ((void *)fstars);
-	    fstars = NULL;
-	    nfstars = 0;
-	}
-
-        nfstars = fs_fetch (np, ra, dec, FSFOV, FSMAG, &fstars);
-
-	if (nfstars > 0) {
-	    char msg[128];
-            (void) sprintf (msg, "Mars View added %d field stars", nfstars);
-            xe_msg (msg, 0);
-	    fsdec = dec;
-	    fsra = ra;
-	}
-}
-
 /* draw the N/S E/W labels on m_pm */
 static void
 m_orientation()
@@ -2027,7 +1881,7 @@ m_orientation()
 	double ra, dec;
 	int x, y;
 
-	mr = degrad((double)marsop->s_size/3600.0)/2 * 1.1;
+	mr = degrad(marsop->s_size/3600.0)/2 * 1.1;
 	mra = marsop->s_gaera;
 	mdec = marsop->s_gaedec;
 
@@ -2068,7 +1922,7 @@ m_sizecal()
 	char buf[64];
 	int l;
 
-	(void) sprintf (buf, "%d\"", marsop->s_size);
+	(void) sprintf (buf, "%.1f\"", marsop->s_size);
 	l = strlen (buf);
 	XQueryTextExtents (XtD, fid, buf, l, &dir, &asc, &des, &xcs);
 
@@ -2189,7 +2043,7 @@ void *arg;      /* where to store pixels */
 	int lr = option[FLIPLR_OPT];
 	unsigned char pict[IMSZ/SMPLSZ][IMSZ/SMPLSZ];	/* sqsz copy */
 	unsigned char see[IMSZ/SMPLSZ];			/* sqsz seeing map */
-	int pixseeing = IMSZ*m_seeing/(double)marsop->s_size;
+	int pixseeing = IMSZ*m_seeing/marsop->s_size;
 	int sqsz = option[COARSE_OPT] ? 5*SMPLSZ : SMPLSZ;
 	double csh;
 	int lsh;
@@ -2437,67 +2291,6 @@ int x, y;
 	}
 }
 
-/* free the list of sky objects, if any */
-static void
-resetSkyObj ()
-{
-	if (skyobjs) {
-	    free ((void *) skyobjs);
-	    skyobjs = NULL;
-	}
-	nskyobjs = 0;
-}
-
-/* add op at [x,y] to the list of background sky objects */
-static void
-addSkyObj (op, x, y)
-Obj *op;
-int x, y;
-{
-	char *newmem;
-
-	if (skyobjs)
-	    newmem = realloc ((void *)skyobjs, (nskyobjs+1) * sizeof(SkyObj));
-	else
-	    newmem = malloc (sizeof(SkyObj));
-	if (!newmem) {
-	    xe_msg ("No mem for more sky objects", 1);
-	    return;
-	}
-
-	skyobjs = (SkyObj *) newmem;
-	skyobjs[nskyobjs].o = *op;
-	skyobjs[nskyobjs].x = x;
-	skyobjs[nskyobjs].y = y;
-	nskyobjs++;
-}
-
-/* find the object in skyobjs[] that is closest to [x,y].
- * return NULL if none within MAXR.
- */
-static Obj *
-closeSkyObj (x, y)
-int x, y;
-{
-	SkyObj *closesp = NULL;
-	int mind = 0;
-	int i;
-
-	for (i = 0; i < nskyobjs; i++) {
-	    SkyObj *sp = &skyobjs[i];
-	    int d = abs(sp->x - x) + abs(sp->y - y);
-
-	    if (!closesp || d < mind) {
-		mind = d;
-		closesp = sp;
-	    }
-	}
-
-	if (closesp && mind <= MAXR)
-	    return (&closesp->o);
-	return (NULL);
-}
-
 /* called when hit button 3 over image */
 static void
 m_popup (ep)
@@ -2506,44 +2299,24 @@ XEvent *ep;
 	XButtonEvent *bep;
 	int overmars;
 	int x, y;
-	Obj *op;
 
 	bep = &ep->xbutton;
 	x = bep->x;
 	y = bep->y;
 
-	op = closeSkyObj (x, y);
 	overmars = xy2ll (XX2IX(x), XY2IY(y), &skypu_l, &skypu_L) == 0;
 
-	if (op) {
-	    char buf[32];
-
-	    f_showit (skypu_name_w, op->o_name);
-	    XtManageChild (skypu_name_w);
-
-	    (void) sprintf (buf, "Mag: %.2f", get_mag(op));
-	    f_showit (skypu_mag_w, buf);
-	    XtManageChild (skypu_mag_w);
-	} else {
-	    XtUnmanageChild (skypu_name_w);
-	    XtUnmanageChild (skypu_mag_w);
-	}
-
 	if (overmars) {
-	    XtManageChild (skypu_aim_w);
-	} else {
-	    XtUnmanageChild (skypu_aim_w);
-	}
-
-	if (op || overmars) {
+	    f_sexa (skypu_l_w, raddeg(skypu_l), 3, 3600);
+	    f_sexa (skypu_L_w, raddeg(skypu_L), 3, 3600);
 	    XmMenuPosition (skypu_w, (XButtonPressedEvent *)ep);
 	    XtManageChild (skypu_w);
 	}
 }
 
-/* create the sky background object popup menu */
+/* create the surface popup menu */
 static void
-m_create_skypopup()
+m_create_popup()
 {
 	Widget w;
 	Arg args[20];
@@ -2555,14 +2328,14 @@ m_create_skypopup()
 	skypu_w = XmCreatePopupMenu (mda_w, "MSKYPU", args, n);
 
 	n = 0;
-	skypu_name_w = XmCreateLabel (skypu_w, "MSKYPN", args, n);
-	wtip (skypu_name_w, "Object name");
-	XtManageChild (skypu_name_w);
+	skypu_l_w = XmCreateLabel (skypu_w, "MLat", args, n);
+	wtip (skypu_l_w, "Latitude");
+	XtManageChild (skypu_l_w);
 
 	n = 0;
-	skypu_mag_w = XmCreateLabel (skypu_w, "MSKYPM", args, n);
-	wtip (skypu_mag_w, "Nominal magnitude");
-	XtManageChild (skypu_mag_w);
+	skypu_L_w = XmCreateLabel (skypu_w, "MLong", args, n);
+	wtip (skypu_L_w, "Longitude");
+	XtManageChild (skypu_L_w);
 
 	n = 0;
 	w = XmCreateSeparator (skypu_w, "MSKYPS", args, n);
@@ -2578,7 +2351,7 @@ m_create_skypopup()
 /* given geocentric ra and dec find image [xy] on martian equitorial projection.
  * [0,0] is center, +x martian right/west (celestial east) +y down/north.
  * this matches the raw albedo image coordinates without any flipping.
- * N.B. we do *not* allow for flipping.
+ * N.B. we do *not* allow for flipping here.
  * N.B. this only works when ra and dec are near mars.
  */
 static void
@@ -2587,7 +2360,7 @@ Now *np;
 double ra, dec;
 int *xp, *yp;
 {
-	double scale = IMSZ/degrad((double)marsop->s_size/3600.0); /* pix/rad */
+	double scale = IMSZ/degrad(marsop->s_size/3600.0); /* pix/rad */
 	double xr, yr;
 	double x, y;
 
@@ -2650,3 +2423,6 @@ double *pap;
 					cos(POLE_DEC)*cos(marsop->s_gaedec)
 						* cos(marsop->s_gaera-POLE_RA));
 }
+
+/* For RCS Only -- Do Not Edit */
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: marsmenu.c,v $ $Date: 1999/02/25 06:55:37 $ $Revision: 1.8 $ $Name:  $"};
