@@ -49,7 +49,7 @@ extern FILE *fopenh P_((char *name, char *how));
 extern Now *mm_get_now P_((void));
 extern Obj *db_basic P_((int id));
 extern Obj *db_scan P_((DBScan *sp));
-extern char *getBaseDir P_((void));
+extern char *getShareDir P_((void));
 extern char *mm_getsite P_((void));
 extern double atod P_((char *buf));
 extern double delra P_((double dra));
@@ -1327,17 +1327,21 @@ m_imps ()
 	    return;
 	}
 
-	/* init colormap to gray ramp */
+	/* init colormap to inverse gray ramp. 
+	 * then print inverse again, to get black text.
+	 * set background to black (er, white) to avoid wasting ink.
+	 */
 	for (i = 0; i < nmgray; i++)
-	    cmap[i] = i;
+	    cmap[i] = nmgray - 1 - i;
+	cmap[0] = 0;
 
 	/* render image into pix[] */
 	image_setup (array_pixel, (void *)pix);
 
 	/* render in postscript -- it's already flipped */
-	XPSImage (m_pm, pix, cmap, nmgray-1, 0, BORD, BORD, mnrows, mncols,0,0);
+	XPSImage (m_pm, pix, cmap, nmgray-1, 1, BORD, BORD, mnrows, mncols,0,0);
 
-	/* ok */
+	/* ok */
 	free ((void *)cmap);
 	free ((void *)pix);
 }
@@ -1780,7 +1784,7 @@ XtPointer call;
 	     * expand.
 	     * also center the scroll bars initially.
 	     */
-	    static before;
+	    static int before;
 
 	    if (!before) {
 		XSetWindowAttributes swa;
@@ -2008,7 +2012,8 @@ mi_draw ()
 	if (option[IMAGE_OPT]) {
 
 	    /* clear m_pm */
-	    XPSFillRectangle (XtD, m_pm, m_bgc,0,0,mncols+2*BORD,mnrows+2*BORD);
+	    XFillRectangle (XtD,  m_pm,  m_bgc, 0, 0, mncols+2*BORD,
+								mnrows+2*BORD);
 	
 	    /* copy m_xim to p_pm */
 	    XPutImage (XtD, m_pm, m_fgc, m_xim, 0, 0, BORD, BORD,mncols,mnrows);
@@ -2109,7 +2114,7 @@ m_labels()
 static void
 m_sky()
 {
-	static before;
+	static int before;
 	Now *np = mm_get_now();
 	double scale;		/* image scale, rads per pixel */
 	double mra, mdec;	/* moon's ra and dec */
@@ -2134,7 +2139,7 @@ m_sky()
 	cmdec = cos(mdec);
 	eq_ecl (mjd, mra, mdec, &mlat, &mlng);
 	cmlat = cos(mlat);
-	scale = (degrad((double)(moonop->s_size)/3600.0)/2.0) / moonrad;
+	scale = (degrad(moonop->s_size/3600.0)/2.0) / moonrad;
 	maxr = ((mnrows > mncols ? mnrows : mncols)/2 + BORD)*scale;
 
 	/* load field stars */
@@ -2163,7 +2168,7 @@ m_sky()
 
 	    /* find size, in pixels. */
 	    diam = magdiam (FMAG, 2, scale, get_mag(op),
-					    degrad((double)op->s_size/3600.0));
+					    degrad(op->s_size/3600.0));
 	    /* reject if too faint */
 	    if (diam <= 0)
 		continue;
@@ -2640,7 +2645,7 @@ int f;
 	int fd;
 
 	/* open moon image */
-	(void) sprintf (fn, "%s/auxil/moon.fts",  getBaseDir());
+	(void) sprintf (fn, "%s/auxil/moon.fts",  getShareDir());
 	fd = openh (fn, 0);
 	if (fd < 0) {
 	    (void) sprintf (msg, "%s: %s\n", fn, syserrstr());
@@ -2870,7 +2875,7 @@ m_eclipse()
 	/* get basic info */
 	db_update (mop);
 	db_update (sop);
-	mrad = degrad((double)(mop->s_size)/3600.0)/2.0;
+	mrad = degrad(mop->s_size/3600.0)/2.0;
 	maxr = 10 * mrad;
 	cmdec = cos (mop->s_gaedec);
 	scale = mrad / moonrad;
@@ -3238,7 +3243,7 @@ m_readdb()
 	FILE *fp;
 
 	/* open file */
-	(void) sprintf (fn, "%s/auxil/moon_db",  getBaseDir());
+	(void) sprintf (fn, "%s/auxil/moon_db",  getShareDir());
 	fp = fopenh (fn, "r");
 	if (!fp) {
 	    (void) sprintf (msg, "%s: %s", fn , syserrstr());
@@ -3742,3 +3747,6 @@ Obj *op;
 	(void) sprintf (buf, "%.2f", get_mag(op));
 	f_showit (skypu_mag_w, buf);
 }
+
+/* For RCS Only -- Do Not Edit */
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: moonmenu.c,v $ $Date: 1999/02/19 04:16:02 $ $Revision: 1.5 $ $Name:  $"};
