@@ -808,7 +808,7 @@ int w;
 {
 	int i;
 	    
-	for (i = 0; i < maxt && stopd_check() == 0; i++) {
+	for (i = 0; stopd_check() == 0 && i < maxt; i++) {
 	    fd_set rset, wset;
 	    struct timeval tv;
 	    int ret;
@@ -927,7 +927,7 @@ XtPointer call;
 	stopd_stopped = 1;
 }
 
-/* poll whether the user wants to stop.
+/* poll whether the user wants to stop, then reset flag if do.
  * return -1 to stop, else 0.
  */
 static int
@@ -936,8 +936,12 @@ stopd_check()
 	/* check for user button presses */
 	XCheck (xe_app);
 
-	return (stopd_stopped ? -1 : 0);
+	if (stopd_stopped) {
+	    stopd_stopped = 0;
+	    return (-1);
+	}
+	return (0);
 }
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: netmenu.c,v $ $Date: 1998/12/29 02:01:35 $ $Revision: 1.2 $ $Name:  $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: netmenu.c,v $ $Date: 1999/10/25 21:09:17 $ $Revision: 1.3 $ $Name:  $"};
