@@ -35,6 +35,7 @@ extern char *obj_description P_((Obj *op));
 extern int db_n P_((void));
 extern int db_set_field P_((char bp[], int id, PrefDateFormat pref, Obj *op));
 extern int obj_cir P_((Now *np, Obj *op));
+extern int skyloc_fifo P_((Obj *op));
 extern void all_newobj P_((int dbidx));
 extern void db_scaninit P_((DBScan *sp, int mask, ObjF *op, int nop));
 extern void db_setuserobj P_((int id, Obj *op));
@@ -284,7 +285,7 @@ static Widget namepb_w[NBTNS];	/* each name selection button */
 
 /* bottom control panel buttons */
 enum {
-    OK, APPLY, RESET, POINT, IDENT, CANCEL, HELP
+    OK, APPLY, RESET, POINT, IDENT, SETTEL, CANCEL, HELP
 };
 
 static int newdb;		/* set when db is updated while we are down */
@@ -518,9 +519,11 @@ obj_create_form ()
 	};
 	static struct Btns skybtns[] = {
 	    {POINT, "Sky Point",
-	    	"Center Sky View on current working Object and mark"},
+	    	"Center Sky View on this Object and mark"},
 	    {IDENT, "Sky Mark",
-		"Mark current working Object on Sky View, but only if visible"},
+		"Mark this Object on Sky View, if already in view"},
+	    {SETTEL, "Set Tel",
+		"Send coordinates of this Object to the telescope, if up"},
 	};
 	Widget typrbf_w, typrb_w;
 	Widget fldrcf_w;
@@ -780,7 +783,7 @@ obj_create_form ()
 	XtManageChild (skyfr_w);
 
 	n = 0;
-	XtSetArg (args[n], XmNfractionBase, 14); n++;
+	XtSetArg (args[n], XmNfractionBase, 1+10*XtNumber(skybtns)); n++;
 	skyf_w = XmCreateForm (skyfr_w, "SkyF", args, n);
 	XtManageChild (skyf_w);
 
@@ -791,9 +794,9 @@ obj_create_form ()
 		XtSetArg (args[n], XmNbottomAttachment, XmATTACH_FORM); n++;
 		XtSetArg (args[n], XmNbottomOffset, 10); n++;
 		XtSetArg (args[n], XmNleftAttachment, XmATTACH_POSITION); n++;
-		XtSetArg (args[n], XmNleftPosition, 2 + i*6); n++;
+		XtSetArg (args[n], XmNleftPosition, 1 + i*10); n++;
 		XtSetArg (args[n], XmNrightAttachment, XmATTACH_POSITION); n++;
-		XtSetArg (args[n], XmNrightPosition, 6 + i*6); n++;
+		XtSetArg (args[n], XmNrightPosition, 10 + i*10); n++;
 		w = XmCreatePushButton (skyf_w, skybtns[i].name, args, n);
 		XtAddCallback (w, XmNactivateCallback, obj_ctl_cb,
 						    (XtPointer)skybtns[i].id);
@@ -912,7 +915,8 @@ XtPointer call;
 		    exit (1);
 		}
 		sv_point (objp);
-	    }
+	    } else
+		xe_msg ("No current object", 1);
 	    break;
 	case IDENT:
 	    if (objp->o_type != UNDEFOBJ) {
@@ -921,7 +925,18 @@ XtPointer call;
 		    exit (1);
 		}
 		sv_id (objp);
-	    }
+	    } else
+		xe_msg ("No current object", 1);
+	    break;
+	case SETTEL:
+	    if (objp->o_type != UNDEFOBJ) {
+		if (obj_cir (mm_get_now(), objp) < 0) {
+		    printf ("obj_ctl_cb: can't get obj_cir for IDENT\n");
+		    exit (1);
+		}
+		(void) skyloc_fifo (objp);
+	    } else
+		xe_msg ("No current object", 1);
 	    break;
 	case CANCEL:
 	    XtUnmanageChild (objform_w);
@@ -1492,7 +1507,7 @@ int id;
 	    epoch_as_decimal (w, objp->f_epoch);
 	    break;
 	case F_SIZE:
-	    f_double (w, "%g", (double)objp->f_size);
+	    f_double (w, "%g", objp->f_size);
 	    break;
 
 	case E_INC:
@@ -1656,3 +1671,6 @@ double e;
 	fs_date (buf, e);
 	f_string (w, buf);
 }
+
+/* For RCS Only -- Do Not Edit */
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: objmenu.c,v $ $Date: 1999/02/15 23:21:12 $ $Revision: 1.3 $ $Name:  $"};
