@@ -326,7 +326,7 @@ plot_create_form()
 	XmStringFree (str);
 	XtManageChild (w);
 
-	(void) sprintf (fname, "%s/ephem.plt", getXRes ("UserDir", "work"));
+	(void) sprintf (fname, "%s/ephem.plt", getXRes ("PrivateDir", "work"));
 	n = 0;
 	XtSetArg (args[n], XmNvalue, fname); n++;
 	filename_w = XmCreateText (rc_w, "Filename", args, n);
@@ -1189,3 +1189,6 @@ Widget da_w;
 
 	watch_cursor (0);
 }
+
+/* For RCS Only -- Do Not Edit */
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: plotmenu.c,v $ $Date: 1998/04/27 21:53:04 $ $Revision: 1.1 $ $Name:  $"};
