@@ -119,6 +119,13 @@ static void call_go P_((void));
 static void x_fill_circle P_((Display *dsp, Drawable win, GC gc, int x, int y,
     int diam));
 
+#define MYMIN(a,b)      ((a) < (b) ? (a) : (b))
+#define MYMAX(a,b)      ((a) > (b) ? (a) : (b))
+static void toHSV (double r, double g, double b, double *hp, double *sp,
+    double *vp);
+static void toRGB (double h, double s, double v, double *rp, double *gp,
+    double *bp);
+
 /* ask user to save or print. if ok, call his go() after we've called XPSOpen()
  */
 void
@@ -261,7 +268,7 @@ int Pw;		/* width of Page rectangle */
 	xpsc.win = win;
 
 	/* Postscript */
-	fprintf (FP, "%%!\n\n");
+	fprintf (FP, "%%!PS-ADOBE\n\n");
 
 	/* define function to set solid or nominal dashed line.
 	 * By: C. P. Price <price@sedona.uafcns.alaska.edu>
@@ -597,10 +604,9 @@ XPSClose()
 	fprintf (FP,"(Created by XEphem Version %s %s) 306 %d cstr\n",
 					    PATCHLEVEL, PATCHDATE, AROWY(3));
 	fprintf (FP, "(%s) 306 %d cstr\n",
-			    "(C) 1996-1997 Elwood Charles Downey", AROWY(2));
+			    "(c) 1996-1999 Elwood Charles Downey", AROWY(2));
 	fprintf (FP, "(%s) 306 %d cstr\n",
-	     "XEphem WWW home page: http://iraf.noao.edu/~ecdowney/xephem.html",
-								    AROWY(1));
+			    "http://www.ClearSkyInstitute.com", AROWY(1));
 	printTime (306, AROWY(0));
 
 	/* file is complete */
@@ -697,6 +703,7 @@ int a1, a2;	/* initial angle, additional extent */
 
 	/* ellipse can't handle the thin cases */
 	setColor (dsp, gc, 0);
+	setLineStyle (dsp, gc);
 	if ((int)w == 0 || (int)h == 0)
 	    doSegment (x, y, x+(int)w, y+(int)h);
 	else {
@@ -730,6 +737,7 @@ int a1, a2;
 	xa.angle1 = a1;
 	xa.angle2 = a2;
 	setColor (dsp, gc, 0);
+	setLineStyle (dsp, gc);
 	doArc (&xa, 0);
 }
 
@@ -748,6 +756,7 @@ int nxa;
 	    return;
 
 	setColor (dsp, gc, 0);
+	setLineStyle (dsp, gc);
 	for (i = 0; i < nxa; i++)
 	    doArc (&xa[i], 0);
 }
@@ -809,6 +818,7 @@ int x, y;
 	xa.angle2 = 360*64;
 
 	setColor (dsp, gc, 0);
+	setLineStyle (dsp, gc);
 	doArc (&xa, 1);
 }
 
@@ -828,6 +838,7 @@ int mode;
 	    return;
 
 	setColor (dsp, gc, 0);
+	setLineStyle (dsp, gc);
 	for (i = 0; i < nxp; i++) {
 	    XArc xa;
 
@@ -944,6 +955,7 @@ int l;
 	/* load desired font and take care not to scale the text */
 	fprintf (FP, "newpath %d %d moveto gsave\n", x, y);
 	setColor (dsp, gc, 0);
+	setLineStyle (dsp, gc);
 	fprintf (FP, "  %g %g scale /%s findfont %g scalefont setfont\n",
 		1.0/xpsc.scale, -1.0/xpsc.scale, fi->name, fi->h*xpsc.scale);
 
@@ -993,6 +1005,7 @@ int align;
 
 	fprintf (FP, "newpath %d %d moveto gsave\n", x, y);
 	setColor (dsp, gc, 0);
+	setLineStyle (dsp, gc);
 	fprintf (FP, "  %g %g scale /%s findfont %g scalefont setfont\n",
 	    1.0/xpsc.scale, -1.0/xpsc.scale, fi->name, fi->h*xpsc.scale*mag);
 
@@ -1057,6 +1070,7 @@ int a1, a2;
 	xa.angle1 = a1;
 	xa.angle2 = a2;
 	setColor (dsp, gc, 0);
+	setLineStyle (dsp, gc);
 	doArc (&xa, 1);
 }
 
@@ -1083,6 +1097,7 @@ int na;
 	    return;
 
 	setColor (dsp, gc, 0);
+	setLineStyle (dsp, gc);
 	for (ap = xap, lastap = ap+na; ap < lastap; ap++)
 	    doArc (ap, 1);
 }
@@ -1103,6 +1118,7 @@ int mode;
 
 	fprintf (FP, "gsave ");
 	setColor (dsp, gc, 1);
+	setLineStyle (dsp, gc);
 	doPoly (xp, nxp, mode, 1);
 	fprintf (FP, "grestore\n");
 }
@@ -1121,6 +1137,7 @@ unsigned w, h;
 	    return;
 
 	setColor (dsp, gc, 0);
+	setLineStyle (dsp, gc);
 	doRect (x, y, w, h, 1);
 }
 
@@ -1139,6 +1156,7 @@ int nxr;
 	    return;
 
 	setColor (dsp, gc, 0);
+	setLineStyle (dsp, gc);
 	for (lastxra = xra+nxr; xra < lastxra; xra++)
 	    doRect (xra->x, xra->y, xra->width, xra->height, 1);
 }
@@ -1230,6 +1248,7 @@ GC gc;
 
 /* if we are currently doing color
  *   dig the rgb out of the gc and put in postscript.
+ *   print darker to improve look on white paper.
  * else if we are currently writing over an image
  *   set color to white
  * else if dogray is set
@@ -1248,11 +1267,28 @@ int dogray;
 	XColor xc;
 
 	if (xpsc.wantcolor) {
+	    double r, g, b, h, s, v;
+
 	    XGetGCValues (dsp, gc, (unsigned long) GCForeground, &gcv);
 	    xc.pixel = gcv.foreground;
 	    XQueryColor (dsp, xe_cm, &xc);
-	    fprintf (FP, "%g %g %g setrgbcolor\n", (double)xc.red/65535.0,
-			    (double)xc.green/65535.0, (double)xc.blue/65535.0);
+
+	    /* tweak colors assuming white paper background */
+	    r = (double)xc.red/65535.0;
+	    g = (double)xc.green/65535.0;
+	    b = (double)xc.blue/65535.0;
+	    toHSV (r, g, b, &h, &s, &v);
+	    if (s < .2) {
+		/* not much color, so go for mid-grey */
+		v = .5;
+	    } else {
+		/* rich color, not too bright */
+		s = 1.0;
+		if (v > .75)
+		    v = 0.75;
+	    }
+	    toRGB (h, s, v, &r, &g, &b);
+	    fprintf (FP, "%g %g %g setrgbcolor\n", r, g, b);
 	} else if (xpsc.overimg == 1) {
 	    fprintf (FP, "1 setgray\n");
 	} else if (xpsc.overimg == 2) {
@@ -1516,7 +1552,7 @@ create_print_w()
 	    wtip(filetb_w,"When on, plot will be saved to file named at right");
 	    XtManageChild (filetb_w);
 
-	    (void) sprintf (fname,"%s/xephem.ps", getXRes ("UserDir", "work"));
+	    (void) sprintf (fname,"%s/xephem.ps", getXRes("PrivateDir","work"));
 	    n = 0;
 	    XtSetArg (args[n], XmNtopAttachment, XmATTACH_FORM); n++;
 	    XtSetArg (args[n], XmNleftAttachment, XmATTACH_POSITION); n++;
@@ -1872,3 +1908,72 @@ int diam;
 	XFillRectangle (dsp, win, gc, x, y, diam, diam);
 	XSetClipMask (dsp, gc, None); /* TODO: probably should put back old */
 }
+
+static void
+toHSV (double r, double g, double b, double *hp, double *sp, double *vp)
+{
+	double min, max, diff;
+	double h, s, v;
+
+	max = MYMAX (MYMAX (r, g), b);
+	min = MYMIN (MYMIN (r, g), b);
+	diff = max - min;
+	v = max;
+	s = max != 0 ? diff/max : 0;
+	if (s == 0)
+	    h = 0;
+	else {
+	    if (r == max)
+		h = (g - b)/diff;
+	    else if (g == max)
+		h = 2 + (b - r)/diff;
+	    else
+		h = 4 + (r - g)/diff;
+	    h /= 6;
+	    if (h < 0)
+		h += 1;
+	}
+
+	*hp = h;
+	*sp = s;
+	*vp = v;
+}
+
+static void
+toRGB (double h, double s, double v, double *rp, double *gp, double *bp)
+{
+	double r, g, b;
+	double f, p, q, t;
+	int i;
+
+	if (v == 0) 
+	    r = g = b = 0.0;
+	else if (s == 0)
+	    r = g = b = v;
+	else {
+	    if (h >= 1)
+		h = 0;
+	    i = (int)floor(h * 6);
+	    f = h * 6.0 - i;
+	    p = v * (1.0 - s);
+	    q = v * (1.0 - s * f);
+	    t = v * (1.0 - s * (1.0 - f));
+
+	    switch (i) {
+	    case 0: r = v; g = t; b = p; break;
+	    case 1: r = q; g = v; b = p; break;
+	    case 2: r = p; g = v; b = t; break;
+	    case 3: r = p; g = q; b = v; break;
+	    case 4: r = t; g = p; b = v; break;
+	    case 5: r = v; g = p; b = q; break;
+	    default: r = g = b = 1; break;
+	    }
+	}
+
+	*rp = r;
+	*gp = g;
+	*bp = b;
+}
+
+/* For RCS Only -- Do Not Edit */
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: ps.c,v $ $Date: 1999/02/24 08:33:14 $ $Revision: 1.8 $ $Name:  $"};
