@@ -7,6 +7,7 @@
 #if defined(__STDC__)
 #include <stdlib.h>
 #endif
+
 #include <X11/Xlib.h>
 #include <Xm/Xm.h>
 #include <Xm/Form.h>
@@ -31,15 +32,19 @@ extern Widget	toplevel_w;
 #define	XtD	XtDisplay(toplevel_w)
 extern Colormap xe_cm;
 
+extern FILE *fopenh P_((char *name, char *how));
 extern Now *mm_get_now P_((void));
 extern Obj *db_basic P_((int id));
 extern Obj *db_scan P_((DBScan *sp));
+extern char *getShareDir P_((void));
 extern double delra P_((double dra));
 extern int any_ison P_((void));
 extern int fs_fetch P_((Now *np, double ra, double dec, double fov,
     double mag, ObjF **opp));
 extern int magdiam P_((int fmag, int magstp, double scale, double mag,
     double size));
+extern int read_bdl P_((FILE *fp, double jd, double *xp, double *yp,
+    double *zp, char ynot[]));
 extern int skyloc_fifo P_((Obj *op));
 extern void db_scaninit P_((DBScan *sp, int mask, ObjF *op, int nop));
 extern void db_update P_((Obj *op));
@@ -66,12 +71,6 @@ extern void xe_msg P_((char *buf, int app_modal));
 
 #define	MINR	10	/* min distance for picking, pixels */
 
-/* These values are from the Explanatory Supplement.
- * Precession degrades them gradually over time.
- */
-#define	POLE_RA		degrad(40.27)	/* RA of saturn's north pole */
-#define	POLE_DEC	degrad(83.51)	/* Dec of saturn's north pole */
-
 /* local record of what is now on screen for easy id from mouse picking.
  */
 typedef struct {
@@ -82,8 +81,15 @@ typedef struct {
     int x, y;		/* screen coord */
 } ScreenObj;
 
+/* malloced arrays for each view */
+typedef enum {
+    SO_MAIN, SO_TOP, SO_N
+} SOIdx;
+static ScreenObj *screenobj[SO_N];
+static int nscreenobj[SO_N];
 
 static void sm_create_form_w P_((void));
+static void sm_create_tvform_w P_((void));
 static void sm_create_ssform_w P_((void));
 static void sm_set_buttons P_((int whether));
 static void sm_set_a_button P_((Widget pbw, int whether));
@@ -92,6 +98,10 @@ static void sm_option_cb P_((Widget w, XtPointer client, XtPointer call));
 static void sm_scale_cb P_((Widget w, XtPointer client, XtPointer call));
 static void sm_activate_cb P_((Widget w, XtPointer client, XtPointer call));
 static void sm_unmap_cb P_((Widget w, XtPointer client, XtPointer call));
+static void st_unmap_cb P_((Widget w, XtPointer client, XtPointer call));
+static void st_map_cb P_((Widget w, XtPointer client, XtPointer call));
+static void st_track_size P_((void));
+static void st_da_exp_cb P_((Widget w, XtPointer client, XtPointer call));
 static void sm_close_cb P_((Widget w, XtPointer client, XtPointer call));
 static void sm_movie_cb P_((Widget w, XtPointer client, XtPointer call));
 static void sm_da_exp_cb P_((Widget w, XtPointer client, XtPointer call));
@@ -104,24 +114,29 @@ static void sm_locfifo_cb P_((Widget w, XtPointer client, XtPointer call));
 static void sm_calibline P_((Display *dsp, Drawable win, GC gc, int xc, int yc,
     char *tag, int tw, int th, int l));
 
-static void add_screenobj P_((Obj *op, int x, int y));
-static void reset_screenobj P_((void));
-static ScreenObj *close_screenobj P_((int x, int y));
+static void add_screenobj P_((SOIdx, Obj *op, int x, int y));
+static void reset_screenobj P_((SOIdx));
+static ScreenObj *close_screenobj P_((SOIdx, int x, int y));
 
 static void sky_background P_((Drawable win, unsigned w, unsigned h, int fmag,
-    double ra0, double dec0, double salpha, double calpha, double scale, double
-    rad, int fliptb, int fliplr));
+    double ra0, double dec0, double scale, double rad, int fliptb, int fliplr));
 
 static Widget satform_w;	/* main form */
 static Widget ssform_w;		/* statistics form */
-static Widget sda_w;		/* drawing area */
+static Widget smframe_w;	/* main frame */
+static Widget stform_w;		/* top-view form */
+static Widget stframe_w;	/* top-view frame */
+static Widget sda_w;		/* main drawing area */
+static Widget stda_w;		/* top-view drawing area */
 static Widget ringet_w, ringst_w;/* labels for displaying ring tilts */
 static Widget scale_w;		/* size scale */
 static Widget limmag_w;		/* limiting magnitude scale */
 static Widget dt_w;		/* main date/time stamp widget */
 static Widget sdt_w;		/* statistics date/time stamp widget */
 static Widget skybkg_w;		/* toggle for controlling sky background */
+static Widget topview_w;	/* toggle for controlling top view */
 static Pixmap sm_pm;		/* main pixmap */
+static Pixmap st_pm;		/* top-view pixmap */
 static GC s_fgc, s_bgc, s_xgc;  /* various colors and operators */
 static XFontStruct *s_fs;       /* font for labels */
 static int s_cw, s_ch;          /* size of label font */
@@ -131,6 +146,7 @@ static int tags;		/* whether we want tags on the drawing */
 static int flip_tb;		/* whether we want to flip top/bottom */
 static int flip_lr;		/* whether we want to flip left/right */
 static int skybkg;		/* whether we want sky background */
+static int topview;		/* whether we want the top view */
 static int sswasman;		/* whether statistics form was managed */
 
 static Widget smpu_w;		/* main popup */
@@ -148,7 +164,7 @@ static int nfstars;             /* number of entries in fstars[] */
 static double fsdec, fsra;      /* location when field stars were loaded */
 #define FSFOV   degrad(1.0)     /* size of FOV to fetch, rads */
 #define FSMAG   20.0            /* limiting mag for fetch */
-#define FSMOVE  degrad(.2)      /* reload when jup has moved this far, rads */
+#define FSMOVE  degrad(.2)      /* reload when sat has moved this far, rads */
 static void sm_loadfs P_((double ra, double dec));
 
 /* arrays that use NM use [0] for the planet itself, and [1..NM-1] for moons.
@@ -169,13 +185,9 @@ static struct MoonNames {
     {"Iapetus",	"VIII"},
 };
 
-enum {CX, CY, CZ, CRA, CDEC, CMAG, CNum};	/* s_w column index */
+enum {CEV, CSV, CX, CY, CZ, CRA, CDEC, CMAG, CNum};	/* s_w column index */
 static Widget	s_w[NM][CNum];			/* the data display widgets */
 
-/* malloced array for each item on screen. used for picking. */
-static ScreenObj *screenobj;
-static int nscreenobj;
-
 
 /* called when the saturn menu is activated via the main menu pulldown.
  * if never called before, create and manage all the widgets as a child of a
@@ -273,6 +285,8 @@ sm_create_form_w()
 	    char *tip;          /* widget tip */
 	} Option;
 	static Option options[] = {
+	    {"TopView",	   "Top view",		&topview, &topview_w,
+	    	"When on, show view looking from high above N pole"},
 	    {"SkyBkg",	   "Sky background",	&skybkg,  &skybkg_w,
 	    	"When on, sky will include database objects and Field Stars"},
 	    {"BrightMoons","Bright moons",	&brmoons, NULL,
@@ -295,7 +309,6 @@ sm_create_form_w()
 	    {"on View...",	"Saturn - view"},
 	};
 	Widget w;
-	Widget frame_w;
 	Widget mb_w, pd_w, cb_w;
 	XmString str;
 	Arg args[20];
@@ -522,15 +535,16 @@ sm_create_form_w()
 	XtSetArg (args[n], XmNrightAttachment, XmATTACH_WIDGET); n++;
 	XtSetArg (args[n], XmNrightWidget, limmag_w); n++;
 	XtSetArg (args[n], XmNshadowType, XmSHADOW_ETCHED_OUT); n++;
-	frame_w = XmCreateFrame (satform_w, "SatFrame", args, n);
-	XtManageChild (frame_w);
+	smframe_w = XmCreateFrame (satform_w, "SatFrame", args, n);
+	XtManageChild (smframe_w);
 
 	    /* make a drawing area for drawing the little map */
 
 	    n = 0;
-	    sda_w = XmCreateDrawingArea (frame_w, "Map", args, n);
+	    sda_w = XmCreateDrawingArea (smframe_w, "Map", args, n);
 	    XtAddCallback (sda_w, XmNexposeCallback, sm_da_exp_cb, 0);
-	    XtAddCallback (sda_w, XmNinputCallback, sm_da_input_cb, 0);
+	    XtAddCallback (sda_w, XmNinputCallback, sm_da_input_cb, 
+							(XtPointer)SO_MAIN);
 	    XtManageChild (sda_w);
 }
 
@@ -546,6 +560,10 @@ sm_create_ssform_w()
 	    char *tip;          /* widget tip */
 	} MoonColumn;
 	static MoonColumn mc[] = {
+	    {CEV,   "UEV",   "E",     "EVis",
+		"Whether geometrically visible from Earth"},
+	    {CSV,   "USV",   "S",     "SVis",
+		"Whether in Sun light"},
 	    {CX,   "SatX",   "X (+E)",     "X",
 	    	"Apparent displacement east of planetary center"},
 	    {CY,   "SatY",   "Y (+S)",     "Y",
@@ -792,6 +810,48 @@ sm_create_ssform_w()
 	XtManageChild (w);
 }
 
+/* create stform_w, the top view dialog */
+static void
+sm_create_tvform_w()
+{
+	Arg args[20];
+	int n;
+
+	/* create form */
+	n = 0;
+	XtSetArg (args[n], XmNautoUnmanage, False); n++;
+	XtSetArg (args[n], XmNdefaultPosition, False); n++;
+	XtSetArg (args[n], XmNcolormap, xe_cm); n++;
+	stform_w = XmCreateFormDialog (toplevel_w, "SaturnTV", args, n);
+	set_something (stform_w, XmNcolormap, (XtArgVal)xe_cm);
+	XtAddCallback (stform_w, XmNunmapCallback, st_unmap_cb, 0);
+	XtAddCallback (stform_w, XmNmapCallback, st_map_cb, NULL);
+
+	/* set some stuff in the parent DialogShell.
+	 * setting XmNdialogTitle in the Form didn't work..
+	 */
+	n = 0;
+	XtSetArg (args[n], XmNtitle, "xephem Saturn top view"); n++;
+	XtSetValues (XtParent(stform_w), args, n);
+
+	/* fill with a drawing area in a frame */
+
+	n = 0;
+	XtSetArg (args[n], XmNtopAttachment, XmATTACH_FORM); n++;
+	XtSetArg (args[n], XmNbottomAttachment, XmATTACH_FORM); n++;
+	XtSetArg (args[n], XmNleftAttachment, XmATTACH_FORM); n++;
+	XtSetArg (args[n], XmNrightAttachment, XmATTACH_FORM); n++;
+	stframe_w = XmCreateFrame (stform_w, "STVF", args, n);
+	XtManageChild (stframe_w);
+
+	    n = 0;
+	    stda_w = XmCreateDrawingArea (stframe_w, "Map", args, n);
+	    XtAddCallback (stda_w, XmNexposeCallback, st_da_exp_cb, NULL);
+	    XtAddCallback (stda_w, XmNinputCallback, sm_da_input_cb, 
+							(XtPointer)SO_TOP);
+	    XtManageChild (stda_w);
+}
+
 /* go through all the buttons pickable for plotting and set whether they
  * should appear to look like buttons or just flat labels.
  */
@@ -910,8 +970,18 @@ Widget w;
 XtPointer client;
 XtPointer call;
 {
-	if (client)
-	    *((int *)client) = XmToggleButtonGetState(w);
+	if (client) {
+	    int *flagp = (int *)client;
+	    *flagp = XmToggleButtonGetState(w);
+	    if (flagp == &topview) {
+		if (topview) {
+		    if (!stform_w)
+			sm_create_tvform_w();
+		    XtManageChild (stform_w);
+		} else
+		    XtUnmanageChild (stform_w);
+	    }
+	}
 
 	sm_update (mm_get_now(), 1);
 }
@@ -945,6 +1015,131 @@ XtPointer call;
 	}
 }
 
+/* callback from either expose or resize of the topview.
+ */
+/* ARGSUSED */
+static void
+st_da_exp_cb (w, client, call)
+Widget w;
+XtPointer client;
+XtPointer call;
+{
+	static int last_nx, last_ny;
+	XmDrawingAreaCallbackStruct *c = (XmDrawingAreaCallbackStruct *)call;
+        Window win = XtWindow(w);
+	Display *dsp = XtDisplay(w);
+	unsigned int nx, ny, bw, d;
+	Window root;
+	int x, y;
+
+	/* filter out a few oddball cases */
+	switch (c->reason) {
+	case XmCR_EXPOSE: {
+	    /* turn off gravity so we get expose events for either shrink or
+	     * expand.
+	     */
+	    static int before;
+	    XExposeEvent *e = &c->event->xexpose;
+
+	    if (!before) {
+		XSetWindowAttributes swa;
+                unsigned long mask = CWBitGravity | CWBackingStore;
+
+		swa.bit_gravity = ForgetGravity;
+		swa.backing_store = NotUseful; /* we use a pixmap */
+		XChangeWindowAttributes (dsp, win, mask, &swa);
+		before = 1;
+	    }
+
+	    /* wait for the last in the series */
+	    if (e->count != 0)
+		return;
+	    break;
+	    }
+	default:
+	    printf ("Unexpected satform_w event. type=%d\n", c->reason);
+	    exit(1);
+	}
+
+        XGetGeometry(dsp, win, &root, &x, &y, &nx, &ny, &bw, &d);
+	if (!st_pm || nx != last_nx || ny != last_ny) {
+	    if (st_pm)
+		XFreePixmap (dsp, st_pm);
+	    st_pm = XCreatePixmap (dsp, win, nx, ny, d);
+	    last_nx = nx;
+	    last_ny = ny;
+	    st_track_size();
+	    sm_update (mm_get_now(), 1);
+	} else
+	    XCopyArea (dsp, st_pm, win, s_fgc, 0, 0, nx, ny, 0, 0);
+}
+
+/* called whenever the topview scene is mapped. */
+/* ARGSUSED */
+static void
+st_map_cb (wid, client, call)
+Widget wid;
+XtPointer client;
+XtPointer call;
+{
+	st_track_size();
+}
+
+/* set the width of the topview DrawingArea the same as the main window's.
+ * we also try to center it just above, but it doesn't always work.
+ */
+static void
+st_track_size()
+{
+	Dimension w, h;
+	Position mfx, mfy, mdx, mdy;
+	Position sdy;
+	Arg args[20];
+	int n;
+
+	/* set widths equal */
+	n = 0;
+	XtSetArg (args[n], XmNwidth, &w); n++;
+	XtGetValues (sda_w, args, n);
+
+	n = 0;
+	XtSetArg (args[n], XmNwidth, w); n++;
+	XtSetValues (stda_w, args, n);
+
+	n = 0;
+	XtSetArg (args[n], XmNheight, &h); n++;
+	XtGetValues (stda_w, args, n);
+
+	/* set locations -- allow for different stuff on top of drawingareas */
+	n = 0;
+	XtSetArg (args[n], XmNx, &mfx); n++;
+	XtSetArg (args[n], XmNy, &mfy); n++;
+	XtGetValues (satform_w, args, n);
+	n = 0;
+	XtSetArg (args[n], XmNx, &mdx); n++;
+	XtSetArg (args[n], XmNy, &mdy); n++;
+	XtGetValues (smframe_w, args, n);
+	n = 0;
+	XtSetArg (args[n], XmNy, &sdy); n++;
+	XtGetValues (stframe_w, args, n);
+
+	n = 0;
+	XtSetArg (args[n], XmNx, mfx+mdx); n++;
+	XtSetArg (args[n], XmNy, mfy - h - sdy - mdy - 20); n++;
+	XtSetValues (stform_w, args, n);
+}
+
+/* callback when topview dialog is unmapped */
+/* ARGSUSED */
+static void
+st_unmap_cb (w, client, call)
+Widget w;
+XtPointer client;
+XtPointer call;
+{
+	XmToggleButtonSetState (topview_w, False, True);
+}
+
 /* callback when main dialog is unmapped */
 /* ARGSUSED */
 static void
@@ -960,6 +1155,10 @@ XtPointer call;
 	    sm_pm = (Pixmap) NULL;
 	}
 
+	/* close top view */
+	if (stform_w && XtIsManaged(stform_w))
+	    XtUnmanageChild (stform_w);
+
 	/* free any field stars */
 	if (fstars) {
 	    free ((void *)fstars);
@@ -1008,7 +1207,7 @@ Widget w;
 XtPointer client;
 XtPointer call;
 {
-	static last_nx, last_ny;
+	static int last_nx, last_ny;
 	XmDrawingAreaCallbackStruct *c = (XmDrawingAreaCallbackStruct *)call;
         Window win = XtWindow(w);
 	Display *dsp = XtDisplay(w);
@@ -1022,7 +1221,7 @@ XtPointer call;
 	    /* turn off gravity so we get expose events for either shrink or
 	     * expand.
 	     */
-	    static before;
+	    static int before;
 	    XExposeEvent *e = &c->event->xexpose;
 
 	    if (!before) {
@@ -1047,15 +1246,21 @@ XtPointer call;
 
         XGetGeometry(dsp, win, &root, &x, &y, &nx, &ny, &bw, &d);
 	if (!sm_pm || nx != last_nx || ny != last_ny) {
+	    if (sm_pm)
+		XFreePixmap (dsp, sm_pm);
 	    sm_pm = XCreatePixmap (dsp, win, nx, ny, d);
 	    last_nx = nx;
 	    last_ny = ny;
+	    if (topview)
+		st_track_size();
 	    sm_update (mm_get_now(), 1);
 	} else
 	    XCopyArea (dsp, sm_pm, win, s_fgc, 0, 0, nx, ny, 0, 0);
 }
 
-/* callback from mouse or keyboard input over drawing area */
+/* callback from mouse or keyboard input over either drawing area
+ * client is one of SOIdx.
+ */
 /* ARGSUSED */
 static void
 sm_da_input_cb (w, client, call)
@@ -1064,8 +1269,9 @@ XtPointer client;
 XtPointer call;
 {
 	XmDrawingAreaCallbackStruct *c = (XmDrawingAreaCallbackStruct *)call;
-	XEvent *ev;
 	ScreenObj *sop;
+	SOIdx soidx;
+	XEvent *ev;
 	int x, y;
 
 	/* get x and y value iff it was from mouse button 3 */
@@ -1078,11 +1284,12 @@ XtPointer call;
 	y = ev->xbutton.y;
 
 	/* find something close on the screen */
-	sop = close_screenobj (x, y);
+	soidx = (SOIdx) client;
+	sop = close_screenobj (soidx, x, y);
 	if (!sop)
 	    return;
 
-	/* put info in popup, smpu_w, creating it first is necessary  */
+	/* put info in popup, smpu_w, creating it first if necessary  */
 	if (!smpu_w)
 	    sm_create_popup();
 	sm_fill_popup (sop);
@@ -1192,22 +1399,23 @@ XtPointer call;
 	(void) skyloc_fifo (op);
 }
 
-/* add one entry to the global screenobj array.
+/* add one entry to the given global screenobj array.
  */
 static void
-add_screenobj (op, x, y)
+add_screenobj (soidx, op, x, y)
+SOIdx soidx;
 Obj *op;
 int x, y;
 {
-	ScreenObj *mem;
+	char *mem = (char *) screenobj[soidx];
+	int nmem = nscreenobj[soidx];
 	ScreenObj *sop;
 
 	/* grow screenobj by one */
-	if (screenobj)
-	    mem = (ScreenObj *) realloc ((char *)screenobj,
-					    (nscreenobj+1)*sizeof (ScreenObj));
+	if (mem)
+	    mem = realloc ((char *)mem, (nmem+1)*sizeof(ScreenObj));
 	else
-	    mem = (ScreenObj *) malloc (sizeof (ScreenObj));
+	    mem = malloc (sizeof(ScreenObj));
 	if (!mem) {
 	    char msg[256];
 	    (void) sprintf (msg, "Out of memory -- %s will not be pickable",
@@ -1215,9 +1423,9 @@ int x, y;
 	    xe_msg (msg, 0);
 	    return;
 	}
-	screenobj = mem;
+	screenobj[soidx] = (ScreenObj *) mem;
 
-	sop = &screenobj[nscreenobj++];
+	sop = &screenobj[soidx][nscreenobj[soidx]++];
 
 	/* fill new entry */
 	sop->o = *op;
@@ -1225,29 +1433,34 @@ int x, y;
 	sop->y = y;
 }
 
-/* reclaim any existing screenobj entries */
+/* reclaim any existing screenobj entries from the given collection */
 static void
-reset_screenobj()
+reset_screenobj(soidx)
+SOIdx soidx;
 {
-	if (screenobj) {
-	    free ((char *)screenobj);
-	    screenobj = NULL;
+	if (screenobj[soidx]) {
+	    free ((char *)screenobj[soidx]);
+	    screenobj[soidx] = NULL;
 	}
-	nscreenobj = 0;
+	nscreenobj[soidx] = 0;
 }
 
-/* find the entry in screenobj closest to [x,y] within MINR.
+/* find the entry in the given screenobj closest to [x,y] within MINR.
  * if found return the ScreenObj *, else NULL.
  */
 static ScreenObj *
-close_screenobj (x, y)
+close_screenobj (soidx, x, y)
+SOIdx soidx;
 int x, y;
 {
-	int minr;
-	ScreenObj *sop, *minsop = NULL;
+	ScreenObj *scop = screenobj[soidx];
+	ScreenObj *minsop = NULL;
+	int nobj = nscreenobj[soidx];
+	int minr = 2*MINR;
+	int i;
 
-	minr = 2*MINR;
-	for (sop = &screenobj[nscreenobj]; --sop >= screenobj; ) {
+	for (i = 0; i < nobj; i++) {
+	    ScreenObj *sop = &scop[i];
 	    int r = abs(x - sop->x) + abs(y - sop->y);
 	    if (r < minr) {
 		minr = r;
@@ -1264,6 +1477,8 @@ typedef struct {
     double x, y, z;	/* radii: +x:east +y:south +z:front */
     double ra, dec;
     double mag;
+    int evis;		/* geometrically visible from earth */
+    int svis;		/* in sun light */
 } MoonData;
 
 /* functions */
@@ -1272,6 +1487,53 @@ static void moonradec();
 static void sm_draw_map ();
 static void make_gcs ();
 
+/* set svis according to whether moon is in sun light */
+static void
+moonSVis(op, mdp)
+Obj *op;
+MoonData *mdp;
+{
+	Obj *eop = db_basic (SUN);
+	double esd = eop->s_edist;
+	double eod = op->s_edist;
+	double sod = op->s_sdist;
+	double soa = degrad(op->s_elong);
+	double esa = asin(esd*sin(soa)/sod);
+	double   h = sod*op->s_hlat;
+	double nod = h*(1./eod - 1./sod);
+	double xp, yp, zp;
+	double xpp, ypp, zpp;
+	double ca, sa;
+	int outside;
+	int infront;
+
+	ca = cos(esa);
+	sa = sin(esa);
+	xp =  ca*mdp->x + sa*mdp->z;
+	yp =  mdp->y;
+	zp = -sa*mdp->x + ca*mdp->z;
+
+	ca = cos(nod);
+	sa = sin(nod);
+	xpp = xp;
+	ypp = ca*yp - sa*zp;
+	zpp = sa*yp + ca*zp;
+
+	outside = xpp*xpp + ypp*ypp > 1.0;
+	infront = zpp > 0.0;
+	mdp->svis = outside || infront;
+}
+
+/* set evis according to whether moon is geometrically visible from earth */
+static void
+moonEVis (mdp)
+MoonData *mdp;
+{
+	int outside = mdp->x*mdp->x + mdp->y*mdp->y > 1.0;
+	int infront = mdp->z > 0.0;
+	mdp->evis = outside || infront;
+}
+
 /* called to recompute and fill in values for the saturn menu.
  * don't bother if it doesn't exist or is unmanaged now or no one is logging.
  */
@@ -1281,13 +1543,11 @@ Now *np;
 int how_much;
 {
 	static char fmt[] = "%7.3f";
+	Obj *sop = db_basic (SATURN);
 	MoonData md[NM];
 	int wantstats;
 	double etilt, stilt;
 	double satsize;
-	double theta, phi;
-	double tvc, pvc;
-	double salpha, calpha;
 	int i;
 
 	/* see if we should bother */
@@ -1300,21 +1560,25 @@ int how_much;
 	watch_cursor (1);
 
 	/* compute md[0].x/y/z/mag/ra/dec and md[1..NM-1].x/y/z/mag info */
-        saturn_data(mjd + MJD0, &satsize, &etilt, &stilt, md);
+        saturn_data(mjd + MJD0, sop, &satsize, &etilt, &stilt, md);
 
-	/* compute sky transformation angle as triple vector product */
-	tvc = PI/2.0 - md[0].dec;
-	pvc = md[0].ra;
-	theta = PI/2 - POLE_DEC;
-	phi = POLE_RA;
-	salpha = sin(tvc)*sin(theta)*(cos(pvc)*sin(phi) - sin(pvc)*cos(phi));
-	calpha = sqrt (1.0 - salpha*salpha);
+	/* set md[0..NM-1].evis */
+	md[0].evis = 1;
+	for (i = 1; i < NM; i++)
+	    moonEVis (&md[i]);
+
+	/* set md[0..NM-1].svis */
+	md[0].svis = 1;
+	for (i = 1; i < NM; i++)
+	    moonSVis (sop, &md[i]);
 
 	/* find md[1..NM-1].ra/dec from md[0].ra/dec and md[1..NM-1].x/y */
-	moonradec (satsize, salpha, calpha, md);
+	moonradec (satsize, md);
 
 	if (wantstats) {
 	    for (i = 0; i < NM; i++) {
+		f_double (s_w[i][CEV], "%1.0f", (double)md[i].evis);
+		f_double (s_w[i][CSV], "%1.0f", (double)md[i].svis);
 		f_double (s_w[i][CX], fmt, md[i].x);
 		f_double (s_w[i][CY], fmt, md[i].y);
 		f_double (s_w[i][CZ], fmt, md[i].z);
@@ -1329,7 +1593,7 @@ int how_much;
 	}
 
 	if (XtIsManaged(satform_w)) {
-	    sm_draw_map (sda_w, etilt, satsize, salpha, calpha, md);
+	    sm_draw_map (sop, etilt, satsize, md);
 	    timestamp (np, dt_w);
 	}
 
@@ -1347,15 +1611,23 @@ int how_much;
  *     +md[].z: in front, sat radii
  */
 static void
-sm_draw_map (w, etilt, satsize, salpha, calpha, md)
-Widget w;
+sm_draw_map (sop, etilt, satsize, md)
+Obj *sop;
 double etilt;
 double satsize;
-double salpha, calpha;
 MoonData md[NM];
 {
-	Display *dsp = XtDisplay(w);
-	Window win = XtWindow(w);
+#define RLW     3       /* ring line width, pixels */
+#define NORM    60.0    /* max Iapetus orbit radius; used to normalize */
+#define	IRR	1.528	/* inner edge of ring system */
+#define	ORR	2.267	/* outter edge of A ring */
+#define MAPSCALE(r)     ((r)*((int)nx)/NORM/2*scale)
+#define	XCORD(x)	((int)(((int)nx)/2.0 + ew*MAPSCALE(x) + 0.5))
+#define	YCORD(y)	((int)(((int)ny)/2.0 - ns*MAPSCALE(y) + 0.5))
+#define	ZCORD(z)	((int)(((int)ny)/2.0 +    MAPSCALE(z) + 0.5))
+
+	Display *dsp = XtDisplay(sda_w);
+	Window win;
 	Window root;
 	double scale;
 	int sv;
@@ -1366,32 +1638,31 @@ MoonData md[NM];
 	unsigned int nx, ny, bw, d;
 	int ns = flip_tb ? -1 : 1;
 	int ew = flip_lr ? -1 : 1;
-	int i;
+	int scale1;
+	int i, b;
 
-#define RLW     3       /* ring line width, pixels */
-#define NORM    60.0    /* max Iapetus orbit radius; used to normalize */
-#define MAPSCALE(r)     ((r)*((int)nx)/NORM/2*scale)
-#define	XCORD(x)	((int)(((int)nx)/2.0 + ew*MAPSCALE(x) + 0.5))
-#define	YCORD(y)	((int)(((int)ny)/2.0 - ns*MAPSCALE(y) + 0.5))
+	/* first the main graphic */
+	win = XtWindow (sda_w);
 
 	if (!s_fgc) 
-	    make_gcs(w);
+	    make_gcs(sda_w);
 
 	XmScaleGetValue (limmag_w, &fmag);
 	XmScaleGetValue (scale_w, &sv);
 	scale = pow(MAXSCALE, sv/100.0);
 
+	/* get size and erase */
 	XGetGeometry(dsp, win, &root, &x, &y, &nx, &ny, &bw, &d);
-
 	XFillRectangle (dsp, sm_pm, s_bgc, 0, 0, nx, ny);
+	scale1 = (int)floor(MAPSCALE(1)+0.5);
 
 	/* prepare for a new list of things on the screen */
-	reset_screenobj();
+	reset_screenobj(SO_MAIN);
 
 	/* draw background objects, if desired */
 	if (skybkg)
-	    sky_background(sm_pm, nx, ny, fmag, md[0].ra, md[0].dec, salpha,
-		calpha, satsize/MAPSCALE(2), satsize*NORM, flip_tb, flip_lr);
+	    sky_background(sm_pm, nx, ny, fmag, md[0].ra, md[0].dec,
+			satsize/MAPSCALE(2), satsize*NORM, flip_tb, flip_lr);
 
 	/* draw labels */
 	c = flip_lr ? 'W' : 'E';
@@ -1400,18 +1671,15 @@ MoonData md[NM];
 	XDrawString(dsp, sm_pm, s_fgc, (nx-s_cw)/2-1, s_fs->ascent, &c, 1);
 
 	/* draw saturn in center with unit radius */
-	XPSFillArc(dsp,sm_pm, s_fgc, nx/2-(int)MAPSCALE(1),
-					ny/2-(int)MAPSCALE(1), (int)MAPSCALE(2),
-					(int)MAPSCALE(2), 0, 360*64);
-	add_screenobj (db_basic(SATURN), nx/2, ny/2);
+	XPSFillArc(dsp, sm_pm, s_fgc, nx/2-scale1, ny/2-scale1, 2*scale1-1,
+						    2*scale1-1, 0, 360*64);
+	add_screenobj (SO_MAIN, sop, nx/2, ny/2);
 
 	/* rings of radius IRR and ORR.
 	 * draw rings in front of planet using xor.
 	 * positive tilt means the front rings are tilted southward.
 	 * always draw the solid s_fgc last in case we are near the ring plane.
 	 */
-#define	IRR	1.528	/* inner edge of ring system */
-#define	ORR	2.267	/* outter edge of A ring */
 	irh = MAPSCALE(2*IRR*fabs(sin(etilt)));
 	irw = (int)MAPSCALE(2*IRR);
 	orh = MAPSCALE(2*ORR*fabs(sin(etilt)));
@@ -1449,16 +1717,13 @@ MoonData md[NM];
 	for (i = 1; i < NM; i++) {
 	    double mx = md[i].x;
 	    double my = md[i].y;
-	    double mz = md[i].z;
 	    double mag = md[i].mag;
-	    int outside = mx*mx + my*my > 1.0;
-	    int infront = mz > 0.0;
 	    int diam;
 	    Obj o;
 
-	    if (!outside && !infront)
+	    if (!md[i].evis)
 		continue;	/* behind saturn */
-	    diam = magdiam (fmag, 1, satsize/MAPSCALE(2), mag, 0.0);
+	    diam = magdiam (fmag, 1, satsize/(2*scale1), mag, 0.0);
 	    if (brmoons)
 		diam += 3;
 	    if (diam <= 0)
@@ -1477,7 +1742,7 @@ MoonData md[NM];
 	    set_smag (&o, mag);
 	    o.s_ra = md[i].ra;
 	    o.s_dec = md[i].dec;
-	    add_screenobj (&o, x, y);
+	    add_screenobj (SO_MAIN, &o, x, y);
 
 	    if (tags && mnames[i].tag)
 		XDrawString(dsp, sm_pm, s_xgc, x-s_cw/2, y+2*s_ch,
@@ -1485,6 +1750,88 @@ MoonData md[NM];
 	}
 
 	XCopyArea (dsp, sm_pm, win, s_fgc, 0, 0, nx, ny, 0, 0);
+
+	/* then the top view, if desired */
+
+	if (!topview || !st_pm)	/* let expose make new pixmap */
+	    return;
+
+	/* get size and erase */
+	win = XtWindow (stda_w);
+	XGetGeometry(dsp, win, &root, &x, &y, &nx, &ny, &bw, &d);
+	XFillRectangle (dsp, st_pm, s_bgc, 0, 0, nx, ny);
+
+	/* draw saturn in center with unit radius */
+	i = ew*64*raddeg(asin(sin(degrad(sop->s_elong))/sop->s_sdist));
+	XPSFillArc(dsp, st_pm, s_fgc, nx/2-scale1, ny/2-scale1, 2*scale1-1,
+						    2*scale1-1, -i, -180*64);
+	reset_screenobj(SO_TOP);
+	add_screenobj (SO_TOP, sop, nx/2, ny/2);
+
+	/* rings of radius IRR and ORR... simple arcs from up here */
+	irw = (int)MAPSCALE(2*IRR);
+	orw = (int)MAPSCALE(2*ORR);
+	irx = nx/2 - MAPSCALE(IRR);
+	iry = ny/2 - MAPSCALE(IRR);
+	orx = nx/2 - MAPSCALE(ORR);
+	ory = ny/2 - MAPSCALE(ORR);
+	b = 64*raddeg(acos(1./IRR));
+	XDrawArc (dsp, st_pm, s_xgc, irx, iry, irw, irw, b-i, -(180*64+2*b));
+	b = 64*raddeg(acos(1./ORR));
+	XDrawArc (dsp, st_pm, s_xgc, orx, ory, orw, orw, b-i, -(180*64+2*b));
+
+	/* draw each moon
+	 */
+	for (i = 1; i < NM; i++) {
+	    double mx = md[i].x;
+	    double mz = md[i].z;
+	    double mag = md[i].mag;
+	    int diam;
+	    Obj o;
+
+	    if (!md[i].svis)
+		continue;
+
+	    diam = magdiam (fmag, 1, satsize/(2*scale1), mag, 0.0);
+	    if (brmoons)
+		diam += 3;
+	    if (diam <= 0)
+		continue;	/* too faint */
+
+	    x = XCORD(mx);
+	    y = ZCORD(mz);
+	    if (diam == 1)
+		XDrawPoint (dsp, st_pm, s_xgc, x, y);
+	    else
+		XPSFillArc (dsp, st_pm, s_xgc, x-diam/2, y-diam/2, diam, diam,
+								    0, 360*64);
+
+	    /* add object to list of screen objects drawn */
+	    (void) strcpy (o.o_name, mnames[i].full);
+	    set_smag (&o, mag);
+	    o.s_ra = md[i].ra;
+	    o.s_dec = md[i].dec;
+	    add_screenobj (SO_TOP, &o, x, y);
+
+	    if (tags && mnames[i].tag)
+		XDrawString(dsp, st_pm, s_xgc, x-s_cw/2, y+2*s_ch,
+					mnames[i].tag, strlen(mnames[i].tag));
+	}
+
+	/* draw label towards earth */
+	if (tags) {
+	    XPoint xp[5];
+
+	    XDrawString(dsp, st_pm, s_fgc, nx/2, ny-s_ch, "Earth", 5);
+	    xp[0].x = nx/2 - 15; xp[0].y = ny - 2*s_ch;
+	    xp[1].x = 0;         xp[1].y = 3*s_ch/2;
+	    xp[2].x = -5;        xp[2].y = -3*s_ch/4;
+	    xp[3].x = 10;        xp[3].y = 0;
+	    xp[4].x = -5;        xp[4].y = 3*s_ch/4;
+	    XDrawLines (dsp, st_pm, s_fgc, xp, 5, CoordModePrevious);
+	}
+
+	XCopyArea (dsp, st_pm, win, s_fgc, 0, 0, nx, ny, 0, 0);
 }
 
 static void
@@ -1538,24 +1885,23 @@ int l;
 	XDrawString (dsp, win, gc, xc-tw/2, yc+th, tag, strlen(tag));
 }
 
-/* draw all database objects in a small sky patch with the given orientation.
+/* draw all database objects in a small sky patch about the given center.
  * get field stars too if enabled and we have moved enough.
  * save objects and screen locs in the global screenobj array for picking.
  * this is used to draw the backgrounds for the planet closeups.
  * Based on work by: Dan Bruton <WDB3926@acs.tamu.edu>
  */
 static void
-sky_background (win, w, h, fmag, ra0,dec0,salpha,calpha,scale,rad,fliptb,fliplr)
+sky_background (win, w, h, fmag, ra0,dec0,scale,rad,fliptb,fliplr)
 Drawable win;		/* window to draw on */
 unsigned w, h;		/* window size */
 int fmag;		/* faintest magnitude to display */
 double ra0, dec0;	/* center of patch, rads */
-double salpha, calpha;	/* transformation parameters */
 double scale;		/* rads per pixel */
 double rad;		/* maximum radius to draw away from ra0/dec0, rads */
 int fliptb, fliplr;	/* flip direction; default is S up E right */
 {
-	static before;
+	static int before;
 	double cdec0 = cos(dec0);
 	DBScan dbs;
 	Obj *op;
@@ -1585,7 +1931,7 @@ int fliptb, fliplr;	/* flip direction; default is S up E right */
 
 	    /* find size, in pixels. */
 	    diam = magdiam (fmag, 1, scale, get_mag(op),
-					    degrad((double)op->s_size/3600.0));
+						    degrad(op->s_size/3600.0));
 	    if (diam <= 0)
 		continue;
 
@@ -1594,8 +1940,8 @@ int fliptb, fliplr;	/* flip direction; default is S up E right */
 	    ddec = dec0 - op->s_dec;	/* + S */
 	    if (fabs(ddec) > rad || delra(dra)*cdec0 > rad)
 		continue;
-	    dx = (dra*calpha - ddec*salpha)/scale;
-	    dy = (dra*salpha + ddec*calpha)/scale;
+	    dx = dra/scale;
+	    dy = ddec/scale;
 	    x = fliplr ? (int)w/2-dx : (int)w/2+dx;
 	    y = fliptb ? (int)h/2+dy : (int)h/2-dy;
 
@@ -1606,7 +1952,7 @@ int fliptb, fliplr;	/* flip direction; default is S up E right */
 	    sv_draw_obj (XtD, win, gc, op, x, y, diam, 0);
 
 	    /* save 'er */
-	    add_screenobj (op, x, y);
+	    add_screenobj (SO_MAIN, op, x, y);
 	}
 
 	sv_draw_obj (XtD, win, (GC)0, NULL, 0, 0, 0, 0);	/* flush */
@@ -1645,9 +1991,8 @@ double ra, dec;
  * md[1..NM-1].x/y in sat radii, find ra/dec of each moon in md[1..NM-1].ra/dec.
  */
 static void
-moonradec (satsize, salpha, calpha, md)
+moonradec (satsize, md)
 double satsize;		/* sat diameter, rads */
-double salpha, calpha;	/* transormation parameters */
 MoonData md[NM];	/* fill in RA and Dec */
 {
 	double satrad = satsize/2;
@@ -1656,13 +2001,118 @@ MoonData md[NM];	/* fill in RA and Dec */
 	int i;
 
 	for (i = 1; i < NM; i++) {
-	    double dra  = satrad * ( md[i].x*calpha + md[i].y*salpha);
-	    double ddec = satrad * (-md[i].x*salpha + md[i].y*calpha);
+	    double dra  = satrad * md[i].x;
+	    double ddec = satrad * md[i].y;
 	    md[i].ra  = satra + dra;
 	    md[i].dec = satdec - ddec;
 	}
 }
 
+static void ring_tilt P_((Obj *sop, double JD, double *etiltp, double *stiltp));
+static void bruton_saturn P_((Obj *sop, double JD, MoonData md[NM]));
+static int use_bdl P_((double JD, MoonData md[NM]));
+
+/* get saturn info in md[0].x/y/z/ra/dec/mag.
+ * get moon info in md[1..NM-1].x/y/z/mag (not ra, dec)
+ */
+static void
+saturn_data (JD, sop, sizep, etiltp, stiltp, md)
+double JD;
+Obj *sop;
+double *sizep;			/* saturn's angular diam, rads */
+double *etiltp, *stiltp;	/* earth and sun tilts -- +S */
+MoonData md[NM];        /* fill in md[0].ra/dec/mag/x/y/z for satmenu,
+                         * md[1..NM-1].x/y/z/mag for each moon
+			 */
+{
+	static int using_bdl = -1; /* log which model, but only when changes */
+
+	md[0].ra = sop->s_ra;
+	md[0].dec = sop->s_dec;
+	md[0].mag = get_mag(sop);
+
+	md[0].x = 0;
+	md[0].y = 0;
+	md[0].z = 0;
+
+	*sizep = degrad(sop->s_size/3600.0);
+
+	/*  Visual Magnitude of the Satellites */
+
+	md[1].mag = 13; md[2].mag = 11.8; md[3].mag = 10.3; md[4].mag = 10.2;
+	md[5].mag = 9.8; md[6].mag = 8.4; md[7].mag = 14.3; md[8].mag = 11.2;
+
+	/* get tilts from sky and tel code */
+
+	ring_tilt (sop, JD, etiltp, stiltp);
+
+	/* get moon data from BDL if possible, else Bruton's model */
+
+	if (use_bdl (JD, md) == 0) {
+	    if (using_bdl != 1) {
+		xe_msg ("Using BDL model for Saturn's moons", 0);
+		using_bdl = 1;
+	    }
+	} else {
+	    if (using_bdl != 0) {
+		xe_msg ("Using Bruton model for Saturn's moons", 0);
+		using_bdl = 0;
+	    }
+	    bruton_saturn (sop, JD, md);
+	}
+}
+
+/* hunt for BDL file. return 0 if ok, else -1 */
+static int
+use_bdl (JD, md)
+double JD;		/* julian date */
+MoonData md[NM];        /* fill md[1..NM-1].x/y/z for each moon */
+{
+#define	SATRAU	.0004014253	/* saturn radius, AU */
+	static FILE *fp;	/* keep open once find */
+	double x[NM], y[NM], z[NM];
+	char buf[1024];
+	int i;
+
+	/* only valid 1999 through 2010 */
+	if (JD < 2451179.50000 || JD >= 2455562.5)
+	    return (-1);
+
+	/* open first time */
+	if (!fp) {
+	    (void) sprintf (buf, "%s/auxil/saturne.9910", getShareDir());
+	    fp = fopenh (buf, "r");
+	    if (!fp)
+		return (-1);
+	}
+
+	/* use it */
+	rewind (fp);
+	if ((i = read_bdl (fp, JD, x, y, z, buf)) < 0) {
+	    xe_msg (buf, 1);
+	    fclose (fp);
+	    fp = NULL;
+	    return (-1);
+	}
+	if (i != NM-1) {
+	    sprintf (buf, "BDL says %d moons, code expects %d", i, NM-1);
+	    xe_msg (buf, 1);
+	    fclose (fp);
+	    fp = NULL;
+	    return (-1);
+	}
+
+	/* copy into md[1..NM-1] with our scale and sign conventions */
+	for (i = 1; i < NM; i++) {
+	    md[i].x =  x[i-1]/SATRAU;	/* we want sat radii +E */
+	    md[i].y = -y[i-1]/SATRAU;	/* we want sat radii +S */
+	    md[i].z = -z[i-1]/SATRAU;	/* we want sat radii +front */
+	}
+
+	/* ok */
+	return (0);
+}
+
 /*  */
 /*     SS2TXT.BAS                     Dan Bruton, astro@tamu.edu */
 /*  */
@@ -1692,27 +2142,22 @@ MoonData md[NM];	/* fill in RA and Dec */
 #define ABS	fabs
 #define SQR	sqrt
 
-static void ring_tilt P_((double JD, double *etiltp, double *stiltp));
-
-/* ECD: this originally computed +X:East +Y:North +Z:behind in [1..8] indeces.
- * ECD: and +tilt:front south, rads
- * ECD: then we adjust things in md[].x/y/z/mag to fit into our MoonData format.
- * ECD: we also add saturn info in md[0].x/y/z/ra/dec/mag.
+/* find saturn moon data from Bruton's model */
+/* this originally computed +X:East +Y:North +Z:behind in [1..8] indeces.
+ * and +tilt:front south, rads
+ * then we adjust things in md[].x/y/z/mag to fit into our MoonData format.
  */
 static void
-saturn_data (JD, sizep, etiltp, stiltp, md)
-double JD;
-double *sizep;			/* saturn's angular diam, rads */
-double *etiltp, *stiltp;	/* earth and sun tilts -- +S */
-MoonData md[NM];        /* fill in md[0].ra/dec/mag/x/y/z for jupiter,
-                         * md[1..NM-1].x/y/z/mag for each moon
-			 */
+bruton_saturn (sop, JD, md)
+Obj *sop;		/* saturn */
+double JD;		/* julian date */
+MoonData md[NM];        /* fill md[1..NM-1].x/y/z for each moon */
 {
      /* ECD: code does not use [0].
       * ECD and why 11 here? seems like 9 would do
       */
      double SMA[11], U[11], U0[11], PD[11];
-     double X[NM], Y[NM], Z[NM], MAG[NM];
+     double X[NM], Y[NM], Z[NM];
 
      double P,TP,TE,EP,EE,RE0,RP0,RS;
      double JDE,LPE,LPP,LEE,LEP;
@@ -1723,6 +2168,10 @@ MoonData md[NM];        /* fill in md[0].ra/dec/mag/x/y/z for jupiter,
      double TRIP,GAM,TEMPX,TEMPY,TEMPZ;
      int I;
 
+     /* saturn */
+     RA = sop->s_ra;
+     DECL = sop->s_dec;
+
      /*  ******************************************************************** */
      /*  *                                                                  * */
      /*  *                        Constants                                 * */
@@ -1739,9 +2188,6 @@ MoonData md[NM];        /* fill in md[0].ra/dec/mag/x/y/z for jupiter,
      EE = .016718;
      /*  Semimajor axis of Earth's and Saturn's orbit in Astronomical Units */
      RE0 = 1; RP0 = 9.554747;
-     /*  Visual Magnitude of the Satellites */
-     MAG[1] = 13; MAG[2] = 11.8; MAG[3] = 10.3; MAG[4] = 10.2;
-     MAG[5] = 9.8; MAG[6] = 8.4; MAG[7] = 14.3; MAG[8] = 11.2;
      /*  Semimajor Axis of the Satellites' Orbit in Kilometers */
      SMA[1] = 185600; SMA[2] = 238100; SMA[3] = 294700; SMA[4] = 377500;
      SMA[5] = 527200; SMA[6] = 1221600; SMA[7] = 1483000; SMA[8] = 3560100;
@@ -1817,23 +2263,6 @@ MoonData md[NM];        /* fill in md[0].ra/dec/mag/x/y/z for jupiter,
 
      }
 
-     /*  ******************** FIND SATURN'S COORDINATES ********************* */
-     /* ECD: and mag and x/y/z */
-     {
-	Obj *op = db_basic(SATURN);
-	db_update (op);
-
-	md[0].ra = RA = op->s_ra;
-	md[0].dec = DECL = op->s_dec;
-	md[0].mag = get_mag(op);
-
-	md[0].x = 0;
-	md[0].y = 0;
-	md[0].z = 0;
-
-	*sizep = degrad((double)op->s_size/3600.0);
-     }
-
      /*  **************** FIND INCLINATION OF RINGS ************************* */
      /*  Use dot product of Earth-Saturn vector and Saturn's rotation axis */
      TVA = (90 - 83.51) * P; /*  Theta coordinate of Saturn's axis */
@@ -1907,15 +2336,11 @@ MoonData md[NM];        /* fill in md[0].ra/dec/mag/x/y/z for jupiter,
      printf ("  Minor Angular Size of Saturn's Rings : %g arcsec\n", ABS(RS4 * TEMP * SIN(INC) / RS));
 #endif
 
-     /* ECD: get tilts from sky and tel code */
-     ring_tilt (JD, etiltp, stiltp);
-
      /* copy into md[1..NM-1] with our sign conventions */
      for (I = 1; I < NM; I++) {
 	md[I].x =  X[I];	/* we want +E */
 	md[I].y = -Y[I];	/* we want +S */
 	md[I].z = -Z[I];	/* we want +front */
-	md[I].mag = MAG[I];	/* */
      }
 }
 
@@ -1926,10 +2351,12 @@ MoonData md[NM];        /* fill in md[0].ra/dec/mag/x/y/z for jupiter,
  */
 
 static void
-ring_tilt (JD, etiltp, stiltp)
+ring_tilt (sop, JD, etiltp, stiltp)
+Obj *sop;			/* saturn */
 double JD;			/* Julian date */
 double *etiltp, *stiltp;	/* tilt from earth and sun, rads southward */
 {
+	Obj *eop = db_basic(SUN);	/* for earth */
 	double t, i, om;
 	double x, y, z;
 	double la, be;
@@ -1940,19 +2367,13 @@ double *etiltp, *stiltp;	/* tilt from earth and sun, rads southward */
 	i = degrad(28.04922-.13*t+.0004*t*t);
 	om = degrad(169.53+13.826*t+.04*t*t);
 
-	{
-	    Obj *op;
+	sb = sop->s_hlat;
+	sl = sop->s_hlong;
+	sr = sop->s_sdist;
 
-	    op = db_basic(SATURN);
-	    sb = op->s_hlat;
-	    sl = op->s_hlong;
-	    sr = op->s_sdist;
-
-	    op = db_basic(SUN);	/* for earth */
-	    eb = 0.0;
-	    el = op->s_hlong;
-	    er = op->s_edist;
-	}
+	eb = 0.0;
+	el = eop->s_hlong;
+	er = eop->s_edist;
 
 	x = sr*cos(sb)*cos(sl)-er*cos(el);
 	y = sr*cos(sb)*sin(sl)-er*sin(el);
@@ -1970,3 +2391,6 @@ double *etiltp, *stiltp;	/* tilt from earth and sun, rads southward */
 	*etiltp = b;
 	*stiltp = bp;
 }
+
+/* For RCS Only -- Do Not Edit */
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: satmenu.c,v $ $Date: 1999/03/03 19:06:34 $ $Revision: 1.9 $ $Name:  $"};
