@@ -42,6 +42,7 @@ extern void hlp_dialog P_((char *tag, char *deflt[], int ndeflt));
 extern void set_something P_((Widget w, char *resource, XtArgVal value));
 extern void set_xmstring P_((Widget w, char *resource, char *txt));
 extern void sv_all P_((Now *np));
+extern void sv_amagoff P_((void));
 extern void sv_draw_obj P_((Display *dsp, Drawable win, GC gc, Obj *op, int x,
     int y, int diam, int dotsonly));
 extern void sv_getcenter P_((int *aamode, double *fov,
@@ -73,8 +74,9 @@ typedef struct {
 /* struct to hold automag settings */
 typedef struct {
     double r;		/* max FOV radius for this mag, rads */
+    int st;		/* star faintest mag */
+    int ss;		/* sol sys faintest mag */
     int ds;		/* deep-sky faintest mag */
-    int ns;		/* other-objects faintest mag */
     int s;		/* mag step per dot size */
 } AutoMag;
 
@@ -85,7 +87,6 @@ static int svf_bright_ok P_((Obj *op));
 static void svf_da_cb P_((Widget w, XtPointer client, XtPointer call));
 static void svf_draw_symbol P_((FilterTB *ftbp, Widget daw));
 static void svf_magdrag_cb P_((Widget w, XtPointer client, XtPointer call));
-static void svf_automag_cb P_((Widget w, XtPointer client, XtPointer call));
 static void svf_apply_cb P_((Widget w, XtPointer client, XtPointer call));
 static void svf_ok_cb P_((Widget w, XtPointer client, XtPointer call));
 static void svf_close_cb P_((Widget w, XtPointer client, XtPointer call));
@@ -172,12 +173,11 @@ static char fclass_table[NCLASSES];
 #define BMAGLIMIT       (-28)   /* brightest setting for the Mag scale */
 #define FMAGLIMIT       30      /* faintest setting for the Mag scale */
 #define MAXMAGSTP       30      /* mag mag step */
-static int dsmag, nsmag;	/* current values of deep/near-sky mag limits */
+static int stmag, ssmag, dsmag;	/* current values of the mag limits */
 static int magstp;		/* current value of mag step */
-static Widget dsmag_w, nsmag_w;	/* deep/near-sky mag scales */
+static Widget stmag_w, ssmag_w, dsmag_w;	/* mag scales */
 static Widget magst_w;		/* mag steps scale */
 static Widget filter_w;		/* main filter dialog */
-static Widget automag_w;	/* automag TB */
 
 /* create, but do not manage, the filter dialog.
  * we also apply its state info immediately to the initial resource
@@ -288,13 +288,13 @@ svf_create()
 	for (i = 0; i < XtNumber(filters)/2; i++)
 	    svf_create_filter (lrc_w, &filters[i]);
 
-	/* add near-sky limit scale in a frame */
+	/* add sol sys limit scale in a frame */
 
 	n = 0;
-	f_w = XmCreateFrame (lrc_w, "NSF", args, n);
+	f_w = XmCreateFrame (lrc_w, "SSF", args, n);
 	XtManageChild (f_w);
 
-	    str = XmStringCreate ("Stars+SolSys Mag", XmSTRING_DEFAULT_CHARSET);
+	    str = XmStringCreate ("Sol Sys Lim Mag", XmSTRING_DEFAULT_CHARSET);
 	    n = 0;
 	    XtSetArg (args[n], XmNorientation, XmHORIZONTAL); n++;
 	    XtSetArg (args[n], XmNminimum, BMAGLIMIT); n++;
@@ -303,11 +303,11 @@ svf_create()
 	    XtSetArg (args[n], XmNscaleMultiple, 1); n++;
 	    XtSetArg (args[n], XmNshowValue, True); n++;
 	    XtSetArg (args[n], XmNtitleString, str); n++;
-	    nsmag_w = XmCreateScale (f_w, "NearSkyMag", args, n);
-	    XtAddCallback (nsmag_w, XmNdragCallback, svf_magdrag_cb, 0);
-	    XtAddCallback (nsmag_w, XmNvalueChangedCallback, svf_magdrag_cb, 0);
-	    wtip (nsmag_w, "Faint limit for stars and solar system objects");
-	    XtManageChild (nsmag_w);
+	    ssmag_w = XmCreateScale (f_w, "SolSysMag", args, n);
+	    XtAddCallback (ssmag_w, XmNdragCallback, svf_magdrag_cb, 0);
+	    XtAddCallback (ssmag_w, XmNvalueChangedCallback, svf_magdrag_cb, 0);
+	    wtip (ssmag_w, "Faint limit for solar system objects");
+	    XtManageChild (ssmag_w);
 	    XmStringFree (str);
 
 	/* add mag step scale in a frame */
@@ -341,13 +341,33 @@ svf_create()
 	for (i = XtNumber(filters)/2; i < XtNumber(filters); i++)
 	    svf_create_filter (rrc_w, &filters[i]);
 
-	/* add mag-scale in a frame */
+	/* add stars mag-scale in a frame */
+
+	n = 0;
+	f_w = XmCreateFrame (rrc_w, "STF", args, n);
+	XtManageChild (f_w);
+
+	    str = XmStringCreate ("Stars Lim Mag", XmSTRING_DEFAULT_CHARSET);
+	    n = 0;
+	    XtSetArg (args[n], XmNorientation, XmHORIZONTAL); n++;
+	    XtSetArg (args[n], XmNminimum, BMAGLIMIT); n++;
+	    XtSetArg (args[n], XmNmaximum, FMAGLIMIT); n++;
+	    XtSetArg (args[n], XmNprocessingDirection, XmMAX_ON_LEFT); n++;
+	    XtSetArg (args[n], XmNscaleMultiple, 1); n++;
+	    XtSetArg (args[n], XmNshowValue, True); n++;
+	    XtSetArg (args[n], XmNtitleString, str); n++;
+	    stmag_w = XmCreateScale (f_w, "StarMag", args, n);
+	    XtAddCallback (stmag_w, XmNdragCallback, svf_magdrag_cb, 0);
+	    XtAddCallback (stmag_w, XmNvalueChangedCallback, svf_magdrag_cb, 0);
+	    wtip (stmag_w, "Faint limit for stars.");
+	    XtManageChild (stmag_w);
+	    XmStringFree (str);
 
 	n = 0;
 	f_w = XmCreateFrame (rrc_w, "DSF", args, n);
 	XtManageChild (f_w);
 
-	    str = XmStringCreate ("Deep Sky Mag", XmSTRING_DEFAULT_CHARSET);
+	    str = XmStringCreate ("Deep Sky Lim Mag", XmSTRING_DEFAULT_CHARSET);
 	    n = 0;
 	    XtSetArg (args[n], XmNorientation, XmHORIZONTAL); n++;
 	    XtSetArg (args[n], XmNminimum, BMAGLIMIT); n++;
@@ -359,28 +379,10 @@ svf_create()
 	    dsmag_w = XmCreateScale (f_w, "DeepSkyMag", args, n);
 	    XtAddCallback (dsmag_w, XmNdragCallback, svf_magdrag_cb, 0);
 	    XtAddCallback (dsmag_w, XmNvalueChangedCallback, svf_magdrag_cb, 0);
-	    wtip (dsmag_w, "Faint limit for deep sky objects");
+	    wtip (dsmag_w, "Faint limit for deep sky objects.");
 	    XtManageChild (dsmag_w);
 	    XmStringFree (str);
 
-	/* add auto-mag TB in a form to give it a gap */
-
-	n = 0;
-	f_w = XmCreateForm (rrc_w, "AMF", args, n);
-	XtManageChild (f_w);
-
-	    n = 0;
-	    XtSetArg (args[n], XmNtopAttachment, XmATTACH_FORM); n++;
-	    XtSetArg (args[n], XmNtopOffset, 20); n++;
-	    XtSetArg (args[n], XmNleftAttachment, XmATTACH_FORM); n++;
-	    XtSetArg (args[n], XmNleftOffset, 20); n++;
-	    automag_w = XmCreateToggleButton (f_w, "AutoMag", args, n);
-	    XtAddCallback (automag_w, XmNvalueChangedCallback,svf_automag_cb,0);
-	    XtManageChild (automag_w);
-	    wtip (automag_w,
-	    	"Maintain a reasonable faint magnitude based on Field of View");
-	    set_xmstring (automag_w, XmNlabelString, "Auto Mag");
-
 	/* set the real filter according to the state of the toggle buttons */
 	svf_apply();
 }
@@ -442,24 +444,30 @@ char ct[NCLASSES];
 
 /* return the current mag limits and mag step */
 void
-svf_getmaglimits (dsmagp, nsmagp, magstpp)
-int *dsmagp, *nsmagp, *magstpp;
+svf_getmaglimits (stmagp, ssmagp, dsmagp, magstpp)
+int *stmagp;
+int *ssmagp;
+int *dsmagp;
+int *magstpp;
 {
+	*stmagp = stmag;
+	*ssmagp = ssmag;
 	*dsmagp = dsmag;
-	*nsmagp = nsmag;
 	*magstpp = magstp;
 }
 
 /* set the current deep- and near-sky limit and mag step */
 void
-svf_setmaglimits (ds, ns, s)
-int ds, ns, s;
+svf_setmaglimits (st, ss, ds, s)
+int st, ss, ds, s;
 {
+	stmag = st;
+	ssmag = ss;
 	dsmag = ds;
-	nsmag = ns;
 	magstp = s;
+	XmScaleSetValue (stmag_w, stmag);
+	XmScaleSetValue (ssmag_w, ssmag);
 	XmScaleSetValue (dsmag_w, dsmag);
-	XmScaleSetValue (nsmag_w, nsmag);
 	XmScaleSetValue (magst_w, s);
 }
 
@@ -505,15 +513,11 @@ void
 svf_automag(fov)
 double fov;
 {
-	static AutoMag amdef = {degrad(360.0), 8, 6, 1};
+	static AutoMag amdef = {degrad(360.0), 6, 6, 8, 1};
 	static AutoMag *amp;
 	static int namp;
 	int i;
 
-	/* ignore if not on */
-	if (!XmToggleButtonGetState (automag_w))
-	    return;
-
 	/* establish table sorted in ascending order by r if first time */
 	if (namp == 0) {
 	    namp = svf_initautomag (&amp);
@@ -527,7 +531,7 @@ double fov;
 	for (i = 0; i < namp && fov > amp[i].r; i++)
 	    continue;
 	i %= namp;
-	svf_setmaglimits (amp[i].ds, amp[i].ns, amp[i].s);
+	svf_setmaglimits (amp[i].st, amp[i].ss, amp[i].ds, amp[i].s);
 }
 
 /* create one FilterCat filter category in the given RowColumn */
@@ -637,7 +641,7 @@ svf_reset()
 	    }
 	}
 
-	svf_setmaglimits (dsmag, nsmag, magstp);
+	svf_setmaglimits (stmag, ssmag, dsmag, magstp);
 }
 
 /* set the real filter and rapid-access tables according to the present state
@@ -671,12 +675,15 @@ svf_apply()
 	    }
 	}
 
+	XmScaleGetValue (stmag_w, &stmag);
+	XmScaleGetValue (ssmag_w, &ssmag);
 	XmScaleGetValue (dsmag_w, &dsmag);
-	XmScaleGetValue (nsmag_w, &nsmag);
 	XmScaleGetValue (magst_w, &magstp);
 }
 
 /* return 1 if db object is ever possibly brighter than allowed range; else 0.
+ * don't worry too much, this is just a first-stage culling. real mag cutoff
+ * is done later.
  */
 static int
 svf_bright_ok(op)
@@ -684,13 +691,11 @@ Obj *op;
 {
 	switch (op->o_type) {
 	case PLANET:
-	    /* always go for the planets for now but ..
-	     * TODO: work up a table of extreme planet magnitudes.
-	     */
+	    /* always just go for the planets */
 	    return (1);
 	    /* break; */
 	case HYPERBOLIC: return (1);	/* and interlopers */
-	case PARABOLIC: return (1);
+	case PARABOLIC:	 return (1);
 	case ELLIPTICAL: {
 	    double mag;		/* magnitude */
 	    double per, aph;	/* perihelion and aphelion distance */
@@ -704,11 +709,11 @@ Obj *op;
 	    else
 		 gk_mag(op->e_mag.m1, op->e_mag.m2,
 						per, fabs(per-1.0), &mag);
-	    return (mag <= nsmag);
+	    return (mag <= ssmag);
 	    /* break; */
 	    }
 	case FIXED:
-	    return (get_mag(op) <= (is_deepsky(op) ? dsmag : nsmag));
+	    return (get_mag(op) <= (is_deepsky(op) ? dsmag : stmag));
 	    /* break; */
 	case EARTHSAT:
 	    /* TODO: work on satellite magnitudes someday */
@@ -810,25 +815,7 @@ Widget w;
 XtPointer client;
 XtPointer call;
 {
-	XmToggleButtonSetState(automag_w, False, True);
-}
-
-/* called when Automag is toggled */
-/* ARGSUSED */
-static void
-svf_automag_cb (w, client, call)
-Widget w;
-XtPointer client;
-XtPointer call;
-{
-	if (XmToggleButtonGetState(w)) {
-	    int aa;
-	    double fov;
-	    double tmp;
-
-	    sv_getcenter (&aa, &fov, &tmp, &tmp, &tmp, &tmp);
-	    svf_automag (fov);
-	}
+	sv_amagoff();
 }
 
 /* called when Apply is pushed on the filter dialog */
@@ -973,8 +960,8 @@ qsort_arg v2;
 }
 
 /* digest the AutoMag resource.
- * the format is four value in groups separated by commas.
- * each group is max fov, deep-sky mag, other-sky mag, step-size.
+ * the format is five values in each group, groups separated by commas.
+ * each group is max fov, star mag, sol sys mag, deep sky mag, step-size.
  * return number of entries and put into *ampp.
  * array will be sorted into ascending order of fov radius.
  * N.B. don't set *ampp unless we return > 0.
@@ -986,7 +973,7 @@ AutoMag **ampp;
 	static char AMResource[] = "AutoMag";
 	char buf[128];
 	double r;
-	int ds, ns, s;
+	int st, ss, ds, s;
 	AutoMag *amp;
 	int sam;
 	int namp;
@@ -1007,7 +994,7 @@ AutoMag **ampp;
 	sam = sizeof(AutoMag);
 	amp = (AutoMag *)0;
 	namp = 0;
-	while (sscanf (am, "%lf %d %d %d", &r, &ds, &ns, &s) == 4) {
+	while (sscanf (am, "%lf %d %d %d %d", &r, &st, &ss, &ds, &s) == 5) {
 	    char *new = amp ? realloc ((void *)amp, (namp+1)*sam) : malloc(sam);
 	    AutoMag *tamp;
 
@@ -1018,8 +1005,9 @@ AutoMag **ampp;
 	    amp = (AutoMag *)new;
 	    tamp = &amp[namp++];
 	    tamp->r = degrad(r);
+	    tamp->st = st;
+	    tamp->ss = ss;
 	    tamp->ds = ds;
-	    tamp->ns = ns;
 	    tamp->s = s;
 
 	    /* skip past next comma */
@@ -1042,10 +1030,10 @@ AutoMag **ampp;
 	(void)sprintf(buf,"Sky View found %d AutoMag table entries as follows:",
 									namp);
 	xe_msg (buf, 0);
-	xe_msg ("     FOV  DeepMag  NearMag  DotSz", 0);
+	xe_msg ("     FOV  Stars    SolSys   DeepSky   DotSiz", 0);
 	for (i = 0; i < namp; i++) {
-	    (void) sprintf (buf, "  %6.2f    %3d      %3d    %3d", raddeg(amp[i].r),
-						amp[i].ds, amp[i].ns, amp[i].s);
+	    (void) sprintf (buf, "  %6.2f    %3d      %3d    %3d       %3d",
+		raddeg(amp[i].r), amp[i].st, amp[i].ss, amp[i].ds, amp[i].s);
 	    xe_msg (buf, 0);
 	}
 
@@ -1054,4 +1042,4 @@ AutoMag **ampp;
 }
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: skyfiltmenu.c,v $ $Date: 1998/07/12 02:33:52 $ $Revision: 1.2 $ $Name:  $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: skyfiltmenu.c,v $ $Date: 1999/10/06 16:18:53 $ $Revision: 1.3 $ $Name:  $"};
