@@ -392,13 +392,13 @@ int lr, tb;
 	    if (lr) {
 		for (x = ncols-1; x >= 0; --x) {
 		    int fp = (int)(*ip++);
-		    Pixel xp = gray_pixel (fp);;
+		    Pixel xp = gray_pixel (fp);
 		    XPutPixel (f_xim, x, flipy, xp);
 		}
 	    } else {
 		for (x = 0; x < ncols; x++) {
 		    int fp = (int)(*ip++);
-		    Pixel xp = gray_pixel (fp);;
+		    Pixel xp = gray_pixel (fp);
 		    XPutPixel (f_xim, x, flipy, xp);
 		}
 	    }
@@ -2066,7 +2066,7 @@ eso_fits()
 	fs_sexa (decstr, dec, 3, 3600);
 	for (decp = decstr; *decp == ' '; decp++)
 	    continue;
-	(void) sprintf (buf, "/dss/dss?ra=%s&dec=%s&mime-type=%s&x=%.0f&y=%.0f HTTP/1.0\nUser-Agent: xephem/%s\n\n",
+	(void) sprintf (buf, "/dss/dss?ra=%s&dec=%s&mime-type=%s&x=%.0f&y=%.0f HTTP/1.0\r\nUser-Agent: xephem/%s\r\n\r\n",
 						rap, decp,
 			use_gunzip() ? "display/gz-fits" : "application/x-fits",
 						fov, fov, PATCHLEVEL);
@@ -2076,6 +2076,7 @@ eso_fits()
 	sockfd = httpGET (host, buf, msg);
 	if (sockfd < 0) {
 	    xe_msg (msg, 1);
+	    stopd_down();
 	    watch_cursor (0);
 	    return;
 	}
@@ -2192,6 +2193,7 @@ stsci_fits()
 	sockfd = httpGET (host, buf, msg);
 	if (sockfd < 0) {
 	    xe_msg (msg, 1);
+	    stopd_down();
 	    watch_cursor (0);
 	    return;
 	}
@@ -2293,10 +2295,8 @@ XtInputId *id;
 	XmUpdateDisplay (toplevel_w);
 
 	/* keep going if expecting more */
-	if (fip->nbytes < fip->totbytes) {
-	    watch_cursor (0);
+	if (fip->nbytes < fip->totbytes)
 	    return;
-	}
 
 	/* finished reading */
 	stopd_down();
@@ -2597,4 +2597,4 @@ double *mjdp;
 }
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: skyfits.c,v $ $Date: 1999/03/14 05:06:00 $ $Revision: 1.8 $ $Name:  $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: skyfits.c,v $ $Date: 1999/10/25 21:09:17 $ $Revision: 1.11 $ $Name:  $"};
