@@ -15,7 +15,7 @@
 #include <Xm/Separator.h>
 #include <Xm/Scale.h>
 #include <Xm/SelectioB.h>
-#include <Xm/Text.h>
+#include <Xm/TextF.h>
 #include <Xm/ToggleB.h>
 #include <Xm/PushB.h>
 
@@ -46,6 +46,7 @@ extern void fs_sexa P_((char *out, double a, int w, int fracbase));
 extern void fs_time P_((char out[], double t));
 extern void get_something P_((Widget w, char *resource, XtArgVal value));
 extern void get_xmstring P_((Widget w, char *resource, char **txtp));
+extern void hlp_dialog P_((char *tag, char *deflt[], int ndeflt));
 extern void prompt_map_cb P_((Widget w, XtPointer client, XtPointer call));
 extern void query P_((Widget tw, char *msg, char *label1, char *label2,
     char *label3, void (*func1)(), void (*func2)(), void (*func3)()));
@@ -55,14 +56,24 @@ extern void xe_msg P_((char *msg, int app_modal));
 extern void watch_cursor P_((int want));
 extern void wtip P_((Widget w, char *tip));
 
-
-static Widget list_w;	/* object list dialog */
 static void sv_create_list_w P_((void));
-static void sv_listok_cb P_((Widget w, XtPointer client, XtPointer call));
-static void listok_append_cb P_((void));
-static void listok_overwrite_cb P_((void));
-static void make_list P_((char *name, char *how));
-static void write_list P_((FILE *fp));
+static void sv_txt_cb P_((Widget w, XtPointer client, XtPointer call));
+static void sv_edb_cb P_((Widget w, XtPointer client, XtPointer call));
+static void sv_listclose_cb P_((Widget w, XtPointer client, XtPointer call));
+static void sv_listhelp_cb P_((Widget w, XtPointer client, XtPointer call));
+static void txt_append_cb P_((void));
+static void txt_overwrite_cb P_((void));
+static void make_txt P_((char *name, char *how));
+static void write_txt P_((FILE *fp));
+static void edb_append_cb P_((void));
+static void edb_overwrite_cb P_((void));
+static void make_edb P_((char *name, char *how));
+static void write_edb P_((FILE *fp));
+
+static Widget list_w;		/* object list dialog */
+static Widget txtfn_w;		/* text-format file name */
+static Widget edbfn_w;		/* edb-format file name */
+
 
 /* callback from List control button. */
 /* ARGSUSED */
@@ -85,101 +96,250 @@ XtPointer call;
 static void
 sv_create_list_w()
 {
-	char fname[1024];
+	Widget lbl_w, sep_w;
+	Widget txt_w, edb_w;
+	Widget close_w, help_w;
 	Arg args[20];
 	int n;
 
-	(void) sprintf (fname, "%s/skylist.txt", getXRes("PrivateDir","work"));
+	/* create form */
 
 	n = 0;
+	XtSetArg (args[n], XmNautoUnmanage, False); n++;
+	XtSetArg (args[n], XmNdefaultPosition, False); n++;
 	XtSetArg (args[n], XmNcolormap, xe_cm); n++;
-	XtSetArg(args[n], XmNdefaultPosition, False); n++;
-	XtSetArg(args[n], XmNdialogStyle, XmDIALOG_APPLICATION_MODAL);  n++;
-	XtSetArg(args[n], XmNmarginWidth, 10);  n++;
-	XtSetArg(args[n], XmNmarginHeight, 10);  n++;
-	list_w = XmCreatePromptDialog (toplevel_w, "SkyList", args,n);
+	XtSetArg (args[n], XmNhorizontalSpacing, 10); n++;
+	XtSetArg (args[n], XmNverticalSpacing, 10); n++;
+	XtSetArg (args[n], XmNmarginHeight, 10); n++;
+	XtSetArg (args[n], XmNmarginWidth, 10); n++;
+	list_w = XmCreateFormDialog (toplevel_w, "SkyList", args, n);
+	XtAddCallback (list_w, XmNhelpCallback, sv_listhelp_cb, 0);
 	set_something (list_w, XmNcolormap, (XtArgVal)xe_cm);
-	set_xmstring (list_w, XmNdialogTitle, "xephem Sky View list");
-	set_xmstring (list_w, XmNselectionLabelString, "File name:");
-	set_xmstring (list_w, XmNtextString, fname);
-	XtUnmanageChild (XmSelectionBoxGetChild(list_w, XmDIALOG_HELP_BUTTON));
-	XtAddCallback (list_w, XmNokCallback, sv_listok_cb, NULL);
-	XtAddCallback (list_w, XmNmapCallback, prompt_map_cb, NULL);
+
+	/* set some stuff in the parent DialogShell.
+	 * setting XmNdialogTitle in the Form didn't work..
+	 */
+	n = 0;
+	XtSetArg (args[n], XmNtitle, "Sky list"); n++;
+	XtSetValues (XtParent(list_w), args, n);
+
+	/* instruction */
+
+	n = 0;
+	XtSetArg (args[n], XmNtopAttachment, XmATTACH_FORM); n++;
+	XtSetArg (args[n], XmNleftAttachment, XmATTACH_FORM); n++;
+	XtSetArg (args[n], XmNrightAttachment, XmATTACH_FORM); n++;
+	XtSetArg (args[n], XmNalignment, XmALIGNMENT_CENTER); n++;
+	lbl_w = XmCreateLabel (list_w, "TTB", args, n);
+	set_xmstring (lbl_w, XmNlabelString, "Save Sky View objects to disk");
+	XtManageChild (lbl_w);
+
+
+	/* .txt file option */
+
+	n = 0;
+	XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
+	XtSetArg (args[n], XmNtopWidget, lbl_w); n++;
+	XtSetArg (args[n], XmNleftAttachment, XmATTACH_FORM); n++;
+	txt_w = XmCreatePushButton (list_w, "TPB", args, n);
+	set_xmstring (txt_w, XmNlabelString, "Save as text:");
+	XtAddCallback (txt_w, XmNactivateCallback, sv_txt_cb, NULL);
+	XtManageChild (txt_w);
+
+	n = 0;
+	XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
+	XtSetArg (args[n], XmNtopWidget, lbl_w); n++;
+	XtSetArg (args[n], XmNleftAttachment, XmATTACH_WIDGET); n++;
+	XtSetArg (args[n], XmNleftWidget, txt_w); n++;
+	XtSetArg (args[n], XmNrightAttachment, XmATTACH_FORM); n++;
+	XtSetArg (args[n], XmNcolumns, 30); n++;
+	txtfn_w = XmCreateTextField (list_w, "TextFilename", args, n);
+	XtManageChild (txtfn_w);
+
+	/* .edb file option */
+
+	n = 0;
+	XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
+	XtSetArg (args[n], XmNtopWidget, txtfn_w); n++;
+	XtSetArg (args[n], XmNleftAttachment, XmATTACH_FORM); n++;
+	edb_w = XmCreatePushButton (list_w, "EPB", args, n);
+	XtAddCallback (edb_w, XmNactivateCallback, sv_edb_cb, NULL);
+	set_xmstring (edb_w, XmNlabelString, "Save as .edb:");
+	XtManageChild (edb_w);
+
+	n = 0;
+	XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
+	XtSetArg (args[n], XmNtopWidget, txtfn_w); n++;
+	XtSetArg (args[n], XmNleftAttachment, XmATTACH_WIDGET); n++;
+	XtSetArg (args[n], XmNleftWidget, edb_w); n++;
+	XtSetArg (args[n], XmNrightAttachment, XmATTACH_FORM); n++;
+	XtSetArg (args[n], XmNcolumns, 30); n++;
+	edbfn_w = XmCreateTextField (list_w, "EdbFilename", args, n);
+	XtManageChild (edbfn_w);
+
+	/* bottom controls */
+
+	n = 0;
+	XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
+	XtSetArg (args[n], XmNtopWidget, edbfn_w); n++;
+	XtSetArg (args[n], XmNleftAttachment, XmATTACH_FORM); n++;
+	XtSetArg (args[n], XmNrightAttachment, XmATTACH_FORM); n++;
+	sep_w = XmCreateSeparator (list_w, "CSEP", args, n);
+	XtManageChild (sep_w);
+
+	n = 0;
+	XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
+	XtSetArg (args[n], XmNtopWidget, sep_w); n++;
+	XtSetArg (args[n], XmNbottomAttachment, XmATTACH_FORM); n++;
+	XtSetArg (args[n], XmNleftAttachment, XmATTACH_POSITION); n++;
+	XtSetArg (args[n], XmNleftPosition, 20); n++;
+	XtSetArg (args[n], XmNrightAttachment, XmATTACH_POSITION); n++;
+	XtSetArg (args[n], XmNrightPosition, 40); n++;
+	close_w = XmCreatePushButton (list_w, "Close", args, n);
+	XtAddCallback (close_w, XmNactivateCallback, sv_listclose_cb, NULL);
+	XtManageChild (close_w);
+
+	n = 0;
+	XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
+	XtSetArg (args[n], XmNtopWidget, sep_w); n++;
+	XtSetArg (args[n], XmNbottomAttachment, XmATTACH_FORM); n++;
+	XtSetArg (args[n], XmNleftAttachment, XmATTACH_POSITION); n++;
+	XtSetArg (args[n], XmNleftPosition, 60); n++;
+	XtSetArg (args[n], XmNrightAttachment, XmATTACH_POSITION); n++;
+	XtSetArg (args[n], XmNrightPosition, 80); n++;
+	help_w = XmCreatePushButton (list_w, "Help", args, n);
+	XtAddCallback (help_w, XmNactivateCallback, sv_listhelp_cb, NULL);
+	XtManageChild (help_w);
 }
 
-/* called when the Ok button is hit in the file list prompt */
+/* called when the Close button is hit in the file list prompt */
 /* ARGSUSED */
 static void
-sv_listok_cb (w, client, call)
+sv_listclose_cb (w, client, call)
 Widget w;
 XtPointer client;
 XtPointer call;
 {
-	char buf[1024];
-	char *name;
+	XtUnmanageChild (list_w);
+}
 
-	get_xmstring(w, XmNtextString, &name);
+/* called when the help button is hit in the file list prompt */
+/* ARGSUSED */
+static void
+sv_listhelp_cb (w, client, call)
+Widget w;
+XtPointer client;
+XtPointer call;
+{
+	static char *msg[] = {
+	    "Save Sky View objects to files in two formats."
+	};
 
-	if (strlen(name) == 0) {
-	    xe_msg ("Please enter a Sky View list file name.", 1);
-	    XtFree (name);
+	hlp_dialog ("Sky View - list", msg, sizeof(msg)/sizeof(msg[0]));
+
+}
+
+/* called when the Text-format button is hit */
+/* ARGSUSED */
+static void
+sv_txt_cb (w, client, call)
+Widget w;
+XtPointer client;
+XtPointer call;
+{
+	char *fn;
+
+	/* gather filename */
+	fn = XmTextFieldGetString (txtfn_w);
+	if (strlen(fn) == 0) {
+	    xe_msg ("Please enter a text list file name.", 1);
+	    XtFree (fn);
 	    return;
 	}
 
-	if (existsh (name) == 0 && confirm()) {
-	    (void) sprintf (buf, "%s exists: Append or Overwrite?", name);
+	/* go */
+	if (existsh (fn) == 0 && confirm()) {
+	    char buf[1024];
+	    (void) sprintf (buf, "%s exists..\nAppend or Overwrite?", fn);
 	    query (toplevel_w, buf, "Append", "Overwrite", "Cancel",
-				listok_append_cb, listok_overwrite_cb, NULL);
+				txt_append_cb, txt_overwrite_cb, NULL);
 	} else
-	    listok_overwrite_cb();
+	    txt_overwrite_cb();
 
-	XtFree (name);
+	XtFree (fn);
 }
 
-/* called when we want to append to a list file */
+/* called when the edb-format button is hit */
+/* ARGSUSED */
 static void
-listok_append_cb ()
+sv_edb_cb (w, client, call)
+Widget w;
+XtPointer client;
+XtPointer call;
 {
-	char *name;
+	char *fn;
 
-	get_xmstring (list_w, XmNtextString, &name);
-	make_list (name, "a");
-	XtFree (name);
+	/* gather filename */
+	fn = XmTextFieldGetString (edbfn_w);
+	if (strlen(fn) == 0) {
+	    xe_msg ("Please enter a edb list file name.", 1);
+	    XtFree (fn);
+	    return;
+	}
+
+	/* go */
+	if (existsh (fn) == 0 && confirm()) {
+	    char buf[1024];
+	    (void) sprintf (buf, "%s exists..\nAppend or Overwrite?", fn);
+	    query (toplevel_w, buf, "Append", "Overwrite", "Cancel",
+				edb_append_cb, edb_overwrite_cb, NULL);
+	} else
+	    edb_overwrite_cb();
+
+	XtFree (fn);
 }
 
-/* called when we want to ceate a new list file */
+/* called when we want to append to a text-format file */
 static void
-listok_overwrite_cb ()
+txt_append_cb ()
 {
-	char *name;
-
-	get_xmstring (list_w, XmNtextString, &name);
-	make_list (name, "w");
-	XtFree (name);
+	char *fn = XmTextFieldGetString (txtfn_w);
+	make_txt (fn, "a");
+	XtFree (fn);
 }
 
-/* open the named list file "a" or "w" and fill it in. */
+/* called when we want to ceate a new text-format file */
 static void
-make_list (name, how)
+txt_overwrite_cb ()
+{
+	char *fn = XmTextFieldGetString (txtfn_w);
+	make_txt (fn, "w");
+	XtFree (fn);
+}
+
+/* open the named text-format file "a" or "w" and fill it in. */
+static void
+make_txt (name, how)
 char *name;
 char *how;
 {
 	FILE *fp = fopenh (name, how);
+	char buf[1024];
 
 	if (fp) {
-	    write_list (fp);
+	    write_txt (fp);
 	    (void) fclose (fp);
+	    sprintf(buf, "%s %s ok.", name, how[0]=='a'?"appended":"written");
+	    xe_msg (buf, 1);
 	} else {
-	    char buf[1024];
-
 	    (void) sprintf (buf, "Can not open %s: %s", name, syserrstr());
 	    xe_msg (buf, 1);
 	}
 }
 
-/* write out all objects currently on sky view display */
+/* write out all objects currently on sky view display in text-format */
 static void
-write_list (fp)
+write_txt (fp)
 FILE *fp;
 {
 	Now *np = mm_get_now();
@@ -196,25 +356,25 @@ FILE *fp;
 
 	/* line to summarize the current circumstances */
 	sv_getcenter (&aamode, &fov, &alt, &az, &ra, &dec);
-	(void) fprintf (fp, "Sky List ");
+	(void) fprintf (fp, "Sky List at ");
 	fs_time (buf, mjd_hr(mjd));
 	(void) fprintf (fp, " %s", buf);
 	fs_date (buf, mjd_day(mjd));
-	(void) fprintf (fp, " %s UT:", buf);
-	(void) fprintf (fp, " FOV: %g", raddeg(fov));
+	(void) fprintf (fp, " %s UTC:", buf);
+	(void) fprintf (fp, " FOV %g;", raddeg(fov));
 
 	if (aamode) {
 	    /* alt/az mode */
 	    fs_pangle (buf, alt);
-	    (void) fprintf (fp, " Alt: %s", buf);
+	    (void) fprintf (fp, " Alt %s;", buf);
 	    fs_pangle (buf, az);
-	    (void) fprintf (fp, " Az: %s", buf);
+	    (void) fprintf (fp, " Az %s;", buf);
 	} else {
 	    /* ra/dec mode */
 	    fs_ra (buf, ra);
-	    (void) fprintf (fp, " RA: %s", buf);
+	    (void) fprintf (fp, " RA %s;", buf);
 	    fs_prdec (buf, dec);
-	    (void) fprintf (fp, " Dec: %s", buf);
+	    (void) fprintf (fp, " Dec %s;", buf);
 	}
 
 	if (epoch == EOD)
@@ -222,24 +382,24 @@ FILE *fp;
 	else
 	    tmp = epoch;
 	mjd_year (tmp, &tmp);
-	(void) fprintf (fp, " Ep: %7.2f", tmp);
+	(void) fprintf (fp, " Ep %7.2f;", tmp);
 
 	(void) fprintf (fp, "\n");
 
 	/* column headings */
 
-	(void) fprintf (fp, "Name.........");
-	(void) fprintf (fp, pref_get(PREF_DPYPREC) == PREF_LOPREC ? " RA....."
-							   : " RA........");
-	(void) fprintf (fp, pref_get(PREF_DPYPREC) == PREF_LOPREC ? " Dec..."
-							   : " Dec......");
-	(void) fprintf (fp, pref_get(PREF_DPYPREC) == PREF_LOPREC ? " Alt..."
-							   : " Alt......");
-	(void) fprintf (fp, pref_get(PREF_DPYPREC) == PREF_LOPREC ? " Az...."
-							   : " Az.......");
-	(void) fprintf (fp, " Mag...");
+	(void) fprintf (fp, "____Name_____");
+	(void) fprintf (fp, pref_get(PREF_DPYPREC) == PREF_LOPREC ? " __RA___"
+							   : " ____RA_____");
+	(void) fprintf (fp, pref_get(PREF_DPYPREC) == PREF_LOPREC ? " _Dec__"
+							   : " ____Dec____");
+	(void) fprintf (fp, pref_get(PREF_DPYPREC) == PREF_LOPREC ? " _Alt__"
+							   : " ___Alt___");
+	(void) fprintf (fp, pref_get(PREF_DPYPREC) == PREF_LOPREC ? " __Az__"
+							   : " ___Az____");
+	(void) fprintf (fp, " _Mag__");
 	(void) fprintf (fp, " Sp");
-	(void) fprintf (fp, " Size.");
+	(void) fprintf (fp, " Size");
 	(void) fprintf (fp, " Class");
 
 	(void) fprintf (fp, "\n");
@@ -286,6 +446,71 @@ FILE *fp;
 
 	watch_cursor(0);
 }
+
+/* called when we want to append to a edb-format file */
+static void
+edb_append_cb ()
+{
+	char *fn = XmTextFieldGetString (edbfn_w);
+	make_edb (fn, "a");
+	XtFree (fn);
+}
+
+/* called when we want to ceate a new edb-format file */
+static void
+edb_overwrite_cb ()
+{
+	char *fn = XmTextFieldGetString (edbfn_w);
+	make_edb (fn, "w");
+	XtFree (fn);
+}
+
+/* open the named edb-format file "a" or "w" and fill it in. */
+static void
+make_edb (name, how)
+char *name;
+char *how;
+{
+	FILE *fp = fopenh (name, how);
+	char buf[1024];
+
+	if (fp) {
+	    write_edb (fp);
+	    (void) fclose (fp);
+	    sprintf(buf, "%s %s ok.", name, how[0]=='a'?"appended":"written");
+	    xe_msg (buf, 1);
+	} else {
+	    (void) sprintf (buf, "Can not open %s: %s", name, syserrstr());
+	    xe_msg (buf, 1);
+	}
+}
+
+/* write out all objects currently on sky view display in edb-format */
+static void
+write_edb (fp)
+FILE *fp;
+{
+	char buf[1024];
+	DBScan dbs;
+	ObjF *fs;
+	int nfs;
+	Obj *op;
+
+	watch_cursor(1);
+
+	/* scan db for all objects on Sky screen, including any field stars */
+	sv_getfldstars (&fs, &nfs);
+	for (db_scaninit(&dbs, ALLM, fs, nfs); (op = db_scan(&dbs)) != NULL; ) {
+
+	    if (!(op->o_flags & OBJF_ONSCREEN))
+		continue;
+
+	    db_write_line (op, buf);
+	    fprintf (fp, "%s\n", buf);
+	}
+
+	watch_cursor(0);
+}
 
 /* stuff for the eyepiece size dialog */
 
@@ -699,4 +924,4 @@ se_rmall()
 }
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: skylist.c,v $ $Date: 1999/02/15 23:21:12 $ $Revision: 1.2 $ $Name:  $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: skylist.c,v $ $Date: 1999/10/07 06:01:35 $ $Revision: 1.4 $ $Name:  $"};
