@@ -143,7 +143,7 @@ static TrState trstate = {
     TRLR_5, TRI_DAY, TRF_DATE, TRR_DAY, TRO_UPR, TRS_MEDIUM, 30
 };
 
-enum {DRAGTOO, ALLOBJ, TRAILS, ECLIPTIC, LEGS, LABELS, STEREO};
+enum {DRAGTOO, ALLOBJ, TRAILS, ECLIPTIC, BLEGS, DBLEGS, LABELS, STEREO};
 
 #define	WANTLBL		FUSER2	/* mark object to be labeled */
 
@@ -162,7 +162,8 @@ static int dragtoo;
 static int trails;
 static Widget trails_w;		/* trails TB, so we can turn on automatically*/
 static int ecliptic;
-static int legs;
+static int blegs;
+static int dblegs;
 static int nametags;
 static int stereo;
 static int parallax;		/* current value of desired parallax */
@@ -364,10 +365,12 @@ ss_create_form()
 	    	"Display trails, if currently defined"},
 	    {"Ecliptic", "Ecliptic", ECLIPTIC, &ecliptic, NULL, 
 	    	"Display sun-centered circles to mark the ecliptic plane"},
-	    {"Labels",   "Labels",   LABELS,    &nametags, NULL, 
+	    {"Labels",   "Labels",   LABELS,   &nametags, NULL, 
 	    	"Display names near the dots denoting the Objects"},
-	    {"Legs",     "Legs",     LEGS,     &legs,     NULL,
-	    	"Connect each object to the ecliptic to depict height"},
+	    {"MLegs",    "Basic Legs",BLEGS,    &blegs,    NULL,
+	    	"Connect planets and ObjXYZ objects to the ecliptic to depict height"},
+	    {"DBLegs",   "DB Legs",  DBLEGS,   &dblegs,   NULL,
+	    	"Connect other Database objects to the ecliptic to depict height"},
 	};
 	Widget mb_w, pd_w, cb_w;
 	Widget w;
@@ -450,7 +453,7 @@ ss_create_form()
 	    XtSetArg (args[n], XmNvisibleWhenOff, True); n++;
 	    XtSetArg (args[n], XmNmarginHeight, 0); n++;
 	    XtSetArg (args[n], XmNindicatorType, XmN_OF_MANY); n++;
-	    w = XmCreateToggleButton (pd_w, "LiveDragging", args, n);
+	    w = XmCreateToggleButton (pd_w, "LiveDrag", args, n);
 	    XtAddCallback (w, XmNvalueChangedCallback, ss_activate_cb,
 							(XtPointer)DRAGTOO);
 	    wtip(w,"Update scene while dragging scales, not just when release");
@@ -817,8 +820,12 @@ XtPointer call;
 	    ecliptic = XmToggleButtonGetState(w);
 	    ss_all ();
 	    break;
-	case LEGS:
-	    legs = XmToggleButtonGetState(w);
+	case DBLEGS:
+	    dblegs = XmToggleButtonGetState(w);
+	    ss_all ();
+	    break;
+	case BLEGS:
+	    blegs = XmToggleButtonGetState(w);
 	    ss_all ();
 	    break;
 	case LABELS:
@@ -1173,7 +1180,7 @@ XtPointer call;
 	    /* turn off gravity so we get expose events for either shrink or
 	     * expand.
 	     */
-	    static before;
+	    static int before;
 	    XExposeEvent *e = &c->event->xexpose;
 
 	    if (!before) {
@@ -1386,7 +1393,7 @@ XtPointer call;
 	    /* turn off gravity so we get expose events for either shrink or
 	     * expand.
 	     */
-	    static before;
+	    static int before;
 	    XExposeEvent *e = &c->event->xexpose;
 
 	    if (!before) {
@@ -1864,7 +1871,7 @@ ss_ss_all()
 		    ss_loc (hp, scale, selt, celt, selg, celg, ss_nx, ss_ny);
 
 		    /* draw leg down to ecliptic if desired */
-		    if (legs) {
+		    if (blegs) {
 			leghl = *hp;
 			leghl.z = 0;
 			ss_loc (&leghl, scale, selt, celt, selg, celg,
@@ -2052,7 +2059,7 @@ ss_st_all()
 		    ss_loc (hp, scale, selt, celt, selg, celg, st_nx, st_ny);
 
 		    /* draw leg down to ecliptic if desired */
-		    if (legs) {
+		    if (blegs) {
 			leghl = *hp;
 			leghl.z = 0;
 			ss_loc (&leghl, scale, selt, celt, selg, celg,
@@ -2157,7 +2164,7 @@ unsigned nx, ny;
 	    /* draw object, possibly with a leg to the ecliptic.
 	     * draw as a blob if want legs, else just a point
 	     */
-	    if (legs) {
+	    if (dblegs) {
 		HLoc leghl;
 
 		/* the blob */
@@ -2545,3 +2552,6 @@ XtPointer call;
 	dm_newobj (dbidx);
 	dm_update (mm_get_now(), 1);
 }
+
+/* For RCS Only -- Do Not Edit */
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: solsysmenu.c,v $ $Date: 1999/02/17 05:49:57 $ $Revision: 1.5 $ $Name:  $"};
