@@ -751,7 +751,7 @@ Widget w;
 XtPointer client;
 XtPointer call;
 {
-	int whether = XmToggleButtonGetState(w);;
+	int whether = XmToggleButtonGetState(w);
 
 	/* don't use our own result to srch with */
 	srch_self_selection_mode = 1;
@@ -1078,4 +1078,4 @@ double *tmincp;
 }
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: srchmenu.c,v $ $Date: 1998/07/12 02:33:52 $ $Revision: 1.2 $ $Name:  $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: srchmenu.c,v $ $Date: 1999/10/25 21:01:55 $ $Revision: 1.3 $ $Name:  $"};
