@@ -34,6 +34,7 @@
 extern Widget toplevel_w;
 extern Colormap xe_cm;
 
+extern XFontStruct * getXResFont P_((char *rn));
 extern Now *mm_get_now P_((void));
 extern char *getXRes P_((char *name, char *def));
 extern void f_scansex P_((double o, char bp[], double *np));
@@ -157,7 +158,6 @@ static void unmap_cb P_((Widget w, XtPointer client, XtPointer call));
 static void destroy_cb P_((Widget w, XtPointer client, XtPointer call));
 static void close_cb P_((Widget w, XtPointer client, XtPointer call));
 static void help_cb P_((Widget w, XtPointer client, XtPointer call));
-static void tr_setfont P_((Display *dsp));
 static void draw_stamp P_((Display *dsp, Drawable win, GC gc, TrTS *tp,
     TrState *sp, int ticklen, int lx, int ly, int x, int y));
 static int draw_tickmark P_((int ticklen, int x1, int y1, int x2, int y2,
@@ -1095,7 +1095,7 @@ int x, y;
 
 	/* make sure the fonts are ready */
 	if (!tr_fs)
-	    tr_setfont(dsp);
+	    tr_fs = getXResFont (fontxr);
 	XPSRegisterFont (tr_fs->fid, psfont);
 
 	/* establish character size */
@@ -1208,15 +1208,5 @@ int x, y;
 	XPSRotDrawAlignedString (dsp, tr_fs, a, mag, win, gc, x, y, bp, align);
 }
 
-/* set tr_fs from fontxr */
-static void
-tr_setfont(dsp)
-Display *dsp;
-{
-	tr_fs = XLoadQueryFont (dsp, getXRes (fontxr, "fixed"));
-
-	if (!tr_fs) {
-	    printf ("Trails: no \"fixed\" font ?!?\n");
-	    exit (1);
-	}
-}
+/* For RCS Only -- Do Not Edit */
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: trailmenu.c,v $ $Date: 1999/02/25 06:56:27 $ $Revision: 1.2 $ $Name:  $"};
