@@ -45,22 +45,22 @@ static void drawPlanet P_((Display *dsp, Window win, GC gc, int sx, int sy,
 static void v_define_fgc P_((void));
 
 static char *msg[] = {
-"XEphem - An Interactive Astronomical Ephemeris Program for X",
+"XEphem - An Interactive Astronomical Ephemeris Program for X Windows",
 NULL,	/* filled in dynamically */
 "",
 "Copyright (c) 1990-1999 by Elwood Charles Downey",
 "ecdowney@ClearSkyInstitute.com",
 "",
-"Permission is granted to use XEphem for personal non-commercial purposes only",
-"and to redistribute this program in its entirely and without modifications",
-"free of charge, except for small handling and media charges. All other rights",
-"reserved. Contact the author before using XEphem for any other purposes,",
-"including using any of the source code in your own projects.",
+"Permission is granted to use XEphem and its source code for personal",
+"non-profit non-commercial purposes only, provided this notice is prominently",
+"displayed. All other rights reserved. Contact the author before using XEphem",
+"for any other purposes.",
 "",
 "No representation is made about the suitability of this software for any",
 "purpose. It is provided \"as is\" without express or implied warranty.",
 "",
-"http://www.ClearSkyInstitute.com",
+"Stay in touch with the latest XEphem developments at",
+"http://www.ClearSkyInstitute.com/xephem",
 "",
 };
 
@@ -502,4 +502,4 @@ v_define_fgc()
 }
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: versionmenu.c,v $ $Date: 1999/02/22 05:20:36 $ $Revision: 1.4 $ $Name:  $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: versionmenu.c,v $ $Date: 1999/10/08 15:45:48 $ $Revision: 1.6 $ $Name:  $"};
