@@ -350,14 +350,14 @@ double *ypos;
       dect = dec0;
       if ((l==0.0) && (m==0.0)) break;
       dz = 4.0 - l*l/(4.0*geo1*geo1) - ((m+geo3)/geo2)*((m+geo3)/geo2) ;
-      if ((dz>4.0) || (dz<2.0)) return 1;;
+      if ((dz>4.0) || (dz<2.0)) return 1;
       dz = 0.5 * sqrt (dz);
       dd = (m+geo3) * dz / geo2;
-      if (fabs(dd)>1.0) return 1;;
+      if (fabs(dd)>1.0) return 1;
       dd = asin (dd);
-      if (fabs(cos(dd))<deps) return 1;;
+      if (fabs(cos(dd))<deps) return 1;
       da = l * dz / (2.0 * geo1 * cos(dd));
-      if (fabs(da)>1.0) return 1;;
+      if (fabs(da)>1.0) return 1;
       da = asin (da);
       rat = ra0 + 2.0 * da;
       dect = dd;
@@ -581,4 +581,4 @@ double *ypix;
 }  /* end xypix */
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: wcs.c,v $ $Date: 1997/01/28 19:49:03 $ $Revision: 1.1 $ $Name:  $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: wcs.c,v $ $Date: 1999/10/25 21:01:55 $ $Revision: 1.2 $ $Name:  $"};
