@@ -1,5 +1,5 @@
 /* main() for xephem.
- * Copyright (c) 1990-1998 by Elwood Charles Downey
+ * Copyright (c) 1990-1999 by Elwood Charles Downey
  * Permission is granted to make and distribute copies of this program free of
  * charge, provided the copyright notice and this permission notice are
  * preserved on all copies.  All other rights reserved.  No representation is
@@ -11,6 +11,8 @@
 #include <signal.h>
 #if defined(__STDC__)
 #include <stdlib.h>
+#else
+extern char *malloc();
 #endif
 
 #include <X11/Xlib.h>
@@ -36,6 +38,7 @@
 #include <Xm/Separator.h>
 #include <Xm/RowColumn.h>
 #include <Xm/ToggleB.h>
+#include <Xm/Label.h>
 
 #if XmVersion >= 1002
 #include <Xm/RepType.h>
@@ -48,11 +51,17 @@
 extern String fallbacks[];
 extern char Version_resource[];
 
-#define	NMINCOL	120	/* min colors we want for the main colormap */
+#define	NMINCOL	150	/* min colors we want for the main colormap */
 
 extern Colormap checkCM P_((Colormap cm, int nwant));
+extern FILE *fopenh P_((char *name, char *how));
+extern char *getShareDir P_((void));
 extern char *getXRes P_((char *name, char *def));
+extern char *syserrstr P_((void));
 extern int confirm P_((void));
+extern int explodeGIF P_((unsigned char *rawpix, int nrawpix, int *wp,
+    int *hp, unsigned char *pixap[], unsigned char ra[], unsigned char ga[],
+    unsigned char ba[], char errmsg[]));
 extern void addXPath P_((void));
 extern void c_manage P_((void));
 extern void db_manage P_((void));
@@ -60,6 +69,7 @@ extern void dm_create_form P_((void));
 extern void dm_manage P_((void));
 extern void e_manage P_((void));
 extern void fs_manage P_((void));
+extern void get_something P_((Widget w, char *resource, XtArgVal value));
 extern void hlp_dialog P_((char *tag, char *deflt[], int ndeflt));
 extern void jm_manage P_((void));
 extern void lst_manage P_((void));
@@ -70,6 +80,8 @@ extern void mm_create P_((Widget mainrc));
 extern void mm_go_cb P_((Widget w, XtPointer client, XtPointer call));
 extern void mm_reset P_((void));
 extern void msg_manage P_((void));
+extern void net_create P_((void));
+extern void net_manage P_((void));
 extern void obj_manage P_((void));
 extern void plot_manage P_((void));
 extern void pref_create_pulldown P_((Widget mb_w));
@@ -80,6 +92,7 @@ extern void pm_manage P_((void));
 extern void set_something P_((Widget w, char *resource, XtArgVal value));
 extern void set_xmstring P_((Widget w, char *resource, char *txt));
 extern void sm_manage P_((void));
+extern void um_manage P_((void));
 extern void srch_manage P_((void));
 extern void ss_manage P_((void));
 extern void sv_manage P_((void));
@@ -130,8 +143,8 @@ static void x_quit P_((void));
 /* client arg to m_activate_cb().
  */
 enum {
-    PROGRESS, QUIT, XRESET, MSGTXT, EXTIN,
-    DATA, MOON, EARTH, MARS, JUPMOON, SATMOON, SKYVIEW, SOLARSYS,
+    PROGRESS, QUIT, XRESET, MSGTXT, NETSETUP, EXTIN,
+    DATA, MOON, EARTH, MARS, JUPMOON, SATMOON, UMOON, SKYVIEW, SOLARSYS,
     PLOT, LIST, SEARCH,
     DB, OBJS, FIELDSTARS, CLOSEOBJS, 
     ABOUT, REFERENCES, INTRO, MAINMENU, FILEHLP, VIEWHLP, TOOLSHLP, OBJHLP,
@@ -232,6 +245,9 @@ char *argv[];
 	/* make the main menu bar and form (other stuff is in mainmenu.c) */
 	make_main_window ();
 
+	/* set up networking, but don't manage it here */
+	net_create();
+
 	/* define the data table, but don't manage it.
 	 * we do this up front to avoid the delay on its first use later.
 	 */
@@ -300,10 +316,180 @@ set_title()
 {
 	char title[100];
 
-	(void) sprintf (title, "xephem %s", PATCHLEVEL);
+	(void) sprintf (title, "XEphem %s", PATCHLEVEL);
 	set_something (toplevel_w, XmNtitle, (XtArgVal) title);
 }
 
+/* create an XImage of size wXh.
+ * return XImage * if ok else NULL and xe_msg().
+ */
+static XImage *
+create_xim (w, h)
+int w, h;
+{
+	Display *dsp = XtDisplay(toplevel_w);
+	XImage *xip;
+	int mdepth;
+	int mbpp;
+	int nbytes;
+	char *data;
+
+	/* establish depth and bits per pixel */
+	get_something (toplevel_w, XmNdepth, (XtArgVal)&mdepth);
+	if (mdepth < 8) {
+	    fprintf (stderr, "Require at least 8 bit pixel depth\n");
+	    return (NULL);
+	}
+	mbpp = mdepth>=17 ? 32 : (mdepth >= 9 ? 16 : 8);
+	nbytes = w*h*mbpp/8;
+
+	/* get memory for image pixels.  */
+	data = malloc (nbytes);
+	if (!data) {
+	    fprintf(stderr,"Can not get %d bytes for logo pixels", nbytes);
+	    return (NULL);
+	}
+
+	/* create the XImage */
+	xip = XCreateImage (dsp, DefaultVisual (dsp, DefaultScreen(dsp)),
+	    /* depth */         mdepth,
+	    /* format */        ZPixmap,
+	    /* offset */        0,
+	    /* data */          data,
+	    /* width */         w,
+	    /* height */        h,
+	    /* pad */           mbpp,
+	    /* bpl */           0);
+	if (!xip) {
+	    fprintf (stderr, "Can not create logo XImage\n");
+	    free ((void *)data);
+	    return (NULL);
+	}
+
+        xip->bitmap_bit_order = LSBFirst;
+	xip->byte_order = LSBFirst;
+
+	/* ok */
+	return (xip);
+}
+
+/* connect up logo.gif */
+static void
+make_logo (rc)
+Widget rc;
+{
+	Display *dsp = XtDisplay(toplevel_w);
+	Window win = RootWindow(dsp, DefaultScreen(dsp));
+	char fn[1024];
+	unsigned char gif[200000];
+	char buf[1024];
+	Arg args[20];
+	unsigned char *gifpix;
+	unsigned char gifr[256], gifg[256], gifb[256];
+	unsigned long xpix[256];
+	Widget f_w, l_w;
+	XImage *xip;
+	Pixmap pm;
+	GC gc;
+	FILE *fp;
+	int w, h;
+	int ngif;
+	int i, n;
+	int x, y;
+
+	/* open and explode the gif */
+	(void) sprintf (fn, "%s/auxil/logo.gif",  getShareDir());
+	fp = fopenh (fn, "rb");
+	if (!fp) {
+	    (void) fprintf (stderr, "%s: %s\n", fn, syserrstr());
+	    return; /* darn */
+	}
+	ngif = fread (gif, 1, sizeof(gif), fp);
+	fclose (fp);
+	if (ngif < 0) {
+	    (void) fprintf (stderr, "%s: %s\n", fn, syserrstr());
+	    return; /* darn again */
+	}
+	if (ngif == sizeof(gif)) {
+	    (void) fprintf (stderr, "%s: Max size = %d\n", fn, sizeof(gif));
+	    return; /* darn again */
+	}
+	n = explodeGIF(gif, ngif, &w, &h, &gifpix, gifr, gifg, gifb, buf);
+	if (n < 0) {
+	    (void) fprintf (stderr, "%s: %s\n", fn, buf);
+	    return; /* darn again */
+	}
+
+	/* N.B. now must free gifpix */
+
+	/* allocate colors -- don't be too fussy */
+	for (i = 0; i < 256; i++) {
+	    XColor xc;
+	    xc.red   = ((gifr[i] & 0xf8) << 8) | 0x7ff;
+	    xc.green = ((gifg[i] & 0xf8) << 8) | 0x7ff;
+	    xc.blue  = ((gifb[i] & 0xf8) << 8) | 0x7ff;
+	    if (XAllocColor (dsp, xe_cm, &xc))
+		xpix[i] = xc.pixel;
+	    else {
+		fprintf (stderr, "Can not get all logo map colors\n");
+		free ((void *)gifpix);
+		if (i > 0)
+		    XFreeColors (dsp, xe_cm, xpix, i, 0);
+		return; /* darn again */
+	    }
+	}
+
+	/* create XImage */
+	xip = create_xim (w, h);
+	if (!xip) {
+	    XFreeColors (dsp, xe_cm, xpix, 256, 0);
+	    free ((void *)gifpix);
+	    return; /* darn again */
+	}
+
+	/* N.B. now must free xip */
+
+	/* fill XImage with logo */
+	for (y = 0; y < h; y++) {
+	    int yrow = y*w;
+	    for (x = 0; x < w; x++) {
+		int gp = (int)gifpix[x + yrow];
+		unsigned long p = xpix[gp];
+		XPutPixel (xip, x, y, p);
+	    }
+	}
+
+	/* create pixmap and fill with logo */
+	pm = XCreatePixmap (dsp, win, w, h, xip->depth);
+	gc = DefaultGC (dsp, DefaultScreen(dsp));
+	XPutImage (dsp, pm, gc, xip, 0, 0, 0, 0, w, h);
+
+	/* put pm in a label and let it handle it from now on.
+	 * put label in a form so it stretches clear across the rc
+	 */
+	n = 0;
+	f_w = XmCreateForm (rc, "LogoForm", args, n);
+	XtManageChild (f_w);
+
+	n = 0;
+	XtSetArg (args[n], XmNtopAttachment, XmATTACH_FORM); n++;
+	XtSetArg (args[n], XmNbottomAttachment, XmATTACH_FORM); n++;
+	XtSetArg (args[n], XmNleftAttachment, XmATTACH_FORM); n++;
+	XtSetArg (args[n], XmNrightAttachment, XmATTACH_FORM); n++;
+	XtSetArg (args[n], XmNlabelType, XmPIXMAP); n++;
+	XtSetArg (args[n], XmNlabelPixmap, pm); n++;
+	XtSetArg (args[n], XmNalignment, XmALIGNMENT_CENTER); n++;
+	l_w = XmCreateLabel (f_w, "LogoLabel", args, n);
+	wtip (l_w, "The file <XEphem.ShareDir>/auxil/logo.gif");
+	XtManageChild (l_w);
+
+	/* free with gifpix and xip */
+	free ((void *)gifpix);
+	free ((void *)xip->data);
+	xip->data = NULL;
+	XDestroyImage (xip);
+}
+
 /* put together the menu bar, the main form, and fill in the form with the
  * initial xephem buttons.
  */
@@ -317,6 +503,8 @@ make_main_window ()
 	    {"Display a dialog containing supporting informational messages",
 	        "Messages", "Messages...", 0, 0, 'M', m_activate_cb,
 							    (XtPointer)MSGTXT},
+	    {"Setup networking options", "Net", "Network setup...", 0, 0,
+				    'N', m_activate_cb, (XtPointer)NETSETUP},
 	    {"Set up to run xephem Time and Location from an external file",
 		"ExtIn", "External Time/Loc...", 0, 0, 'E', m_activate_cb,
 							    (XtPointer)EXTIN},
@@ -348,6 +536,9 @@ make_main_window ()
 	    {"Display schematic of Saturn, its rings and moons, and other info",
 		"Saturn", "Saturn...", 0, 0, 'a', m_activate_cb,
 							(XtPointer)SATMOON},
+	    {"Display schematic of Uranus, its moons, and other info",
+		"Uranus", "Uranus...", 0, 0, 'U', m_activate_cb,
+							(XtPointer)UMOON},
 	    {NULL, SEPARATOR_N},
 	    {"Display a full-featured map of the night sky",
 		"SkyV", "Sky View...", 0, 0, 'V', m_activate_cb,
@@ -374,8 +565,8 @@ make_main_window ()
 	    {"Search memory for an object, view definitions, assign ObjXYZ",
 		"ObjX_Y", "Search memory and define ObjX,Y,Z...", 0, 0,'S',
 					    m_activate_cb, (XtPointer)OBJS},
-	    {"Define location of catalogs and set network options",
-		"FieldStars", "Setup field stars and networking...", 0, 0,'F',
+	    {"Setup field star options and catalog locations",
+		"FieldStars", "Setup field stars...", 0, 0, 'F',
 					m_activate_cb, (XtPointer)FIELDSTARS},
 	    {"Find all pairs of close objects in memory",
 		"CloseObjs", "Find close pairs of objects...", 0, 0, 'C',
@@ -417,7 +608,7 @@ make_main_window ()
 							(XtPointer)REFERENCES},
 	    {"A few supporting issues",
 		"Notes", "Notes...", 0, 0, 'N', m_activate_cb,(XtPointer)NOTES},
-	    {"Version, copyright, logo",
+	    {"Version, copyright, fun graphic",
 		"About", "About...", 0, 0, 'A', m_activate_cb, (XtPointer)ABOUT}
 	};
 	static PullDownMenu file_pd =
@@ -470,6 +661,9 @@ make_main_window ()
 	    XtSetArg (args[n], XmNmenuHelpWidget, cb_w);  n++;
 	    XtSetValues (mb_w, args, n);
 
+	/* make a spot for the logo */
+	make_logo (mainrc);
+
 	/* add the remainder of the main window */
 
 	mm_create (mainrc);
@@ -590,6 +784,7 @@ XtPointer call;
 	switch (code) {
 	case XRESET:	mm_reset(); break;
 	case MSGTXT:	msg_manage(); break;
+	case NETSETUP:	net_manage(); break;
 	case EXTIN:	mm_external(); break;
 	case PROGRESS:	pm_manage(); break;
 	case QUIT:	x_quit(); break;
@@ -599,6 +794,7 @@ XtPointer call;
 	case MARS:	mars_manage(); break;
 	case JUPMOON:	jm_manage(); break;
 	case SATMOON:	sm_manage(); break;
+	case UMOON:	um_manage(); break;
 	case SKYVIEW:	sv_manage(); break;
 	case SOLARSYS:	ss_manage(); break;
 	case PLOT:	plot_manage(); break;
@@ -716,3 +912,6 @@ x_quit()
 
 	/* if this function returns, we resume */
 }
+
+/* For RCS Only -- Do Not Edit */
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: xephem.c,v $ $Date: 1999/02/28 05:05:38 $ $Revision: 1.9 $ $Name:  $"};
