@@ -34,12 +34,21 @@ static void crack_year P_((char *bp, PrefDateFormat pref, double *p));
 static int db_get_field P_((Obj *op, int id, char *bp));
 
 /* crack the given .edb database line into op.
- * return 0 if ok else return -1.
+ * if ok
+ *   return 0
+ * else
+ *   if whynot
+ *     if not even a candidate
+ *       set whynot[0] = '\0'
+ *     else
+ *       fill whynot with reason message.
+ *   return -1
  */
 int
-db_crack_line (s, op)
+db_crack_line (s, op, whynot)
 char s[];
 Obj *op;
+char whynot[];
 {
 	char *flds[MAXFLDS];	/* point to each field for easy reference */
 	char *sflds[MAXFLDS];	/* point to each sub field for easy reference */
@@ -48,8 +57,11 @@ Obj *op;
 	int i;
 
 	/* basic initial check */
-	if (line_candidate (s) < 0)
+	if (line_candidate (s) < 0) {
+	    if (whynot)
+		whynot[0] = '\0';
 	    return (-1);
+	}
 
 	/* do all the parsing on a copy */
 	(void) strcpy (copy, s);
@@ -61,20 +73,29 @@ Obj *op;
 	nf = get_fields (copy, FLDSEP, flds);
 
 	/* need at least 2: name and type */
-	if (nf < 2)
+	if (nf < 2) {
+	    if (whynot)
+		sprintf (whynot, "Found only %d fields", nf);
 	    return (-1);
+	}
 
 	/* switch out on type of object - the second field */
 	switch (flds[1][0]) {
 	case 'f': {
 	    static int ids[] = {F_RA, F_DEC, F_MAG};
-	    if (nf < 5 || nf > 7)
+	    if (nf < 5 || nf > 7) {
+		if (whynot)
+		    sprintf (whynot, "f needs 5-7 fields: %d", nf);
 		return (-1);
+	    }
 	    zero_mem ((void *)op, sizeof(ObjF));
 	    op->o_type = FIXED;
 	    nsf = get_fields(flds[1], SUBFLD, sflds);
-	    if (nsf > 1 && db_set_field (sflds[1], F_CLASS, PREF_MDY, op) < 0)
+	    if (nsf > 1 && db_set_field (sflds[1], F_CLASS, PREF_MDY, op) < 0) {
+		if (whynot)
+		    sprintf (whynot, "Bad f class: %c", sflds[1][0]);
 		return (-1);
+	    }
 	    if (nsf > 2)
 		(void) db_set_field (sflds[2], F_SPECT, PREF_MDY, op);
 	    for (i = 2; i < ASIZ(ids)+2; i++)
@@ -90,8 +111,11 @@ Obj *op;
 	    static int ids[] = {E_INC, E_LAN, E_AOP, E_A, E_N, E_E, E_M,
 						E_CEPOCH, E_EPOCH, E_M1, E_M2
 	    };
-	    if (nf != 13 && nf != 14)
+	    if (nf != 13 && nf != 14) {
+		if (whynot)
+		    sprintf (whynot, "e needs 13 or 14 fields: %d", nf);
 		return (-1);
+	    }
 	    zero_mem ((void *)op, sizeof(ObjE));
 	    op->o_type = ELLIPTICAL;
 	    for (i = 2; i < ASIZ(ids)+2; i++)
@@ -103,8 +127,11 @@ Obj *op;
 
 	case 'h': {
 	    static int ids[]= {H_EP,H_INC,H_LAN,H_AOP,H_E,H_QP,H_EPOCH,H_G,H_K};
-	    if (nf != 11 && nf != 12)
+	    if (nf != 11 && nf != 12) {
+		if (whynot)
+		    sprintf (whynot, "h needs 11 or 12 fields: %d", nf);
 		return (-1);
+	    }
 	    zero_mem ((void *)op, sizeof(ObjH));
 	    op->o_type = HYPERBOLIC;
 	    for (i = 2; i < ASIZ(ids)+2; i++)
@@ -116,8 +143,11 @@ Obj *op;
 
 	case 'p': {
 	    static int ids[] = {P_EP,P_INC,P_AOP,P_QP,P_LAN,P_EPOCH,P_G,P_K};
-	    if (nf != 10 && nf != 11)
+	    if (nf != 10 && nf != 11) {
+		if (whynot)
+		    sprintf (whynot, "p needs 10 or 11 fields: %d", nf);
 		return (-1);
+	    }
 	    zero_mem ((void *)op, sizeof(ObjP));
 	    op->o_type = PARABOLIC;
 	    for (i = 2; i < ASIZ(ids)+2; i++)
@@ -130,8 +160,11 @@ Obj *op;
 	case 'E': {
 	    static int ids[] = {ES_EPOCH,ES_INC,ES_RAAN,ES_E,ES_AP,ES_M,ES_N,
 							    ES_DECAY,ES_ORBIT};
-	    if (nf != 11)
+	    if (nf != 11) {
+		if (whynot)
+		    sprintf (whynot, "E needs 11 fields: %d", nf);
 		return (-1);
+	    }
 	    zero_mem ((void *)op, sizeof(ObjES));
 	    op->o_type = EARTHSAT;
 	    for (i = 2; i < ASIZ(ids)+2; i++)
@@ -141,13 +174,20 @@ Obj *op;
 
 	case 'P':
 	    /* allow, though ignore, anything after the P */
-	    return (db_chk_planet (flds[0], op));	/* does o_name too */
+	    i = db_chk_planet (flds[0], op);	/* does o_name too */
+	    if (i < 0) {
+		if (whynot)
+		    sprintf (whynot, "Bad planet: %s", flds[0]);
+	    }
+	    return (i);
 
 	default:
+	    if (whynot)
+		sprintf (whynot, "Unknown type: %c", flds[1][0]);
 	    return (-1);
 	}
 
-	/* load up name */
+	/* load up o_name */
 	(void) db_set_field (flds[0], O_NAME, PREF_MDY, op);
 
 	return (0);
@@ -277,7 +317,7 @@ Obj *op;
 	    set_fmag (op, atod(bp));
 	    break;
 	case F_SIZE:
-	    op->f_size = (short)floor(atod(bp) + 0.5);
+	    op->f_size = atod(bp);
 	    {
 		/* galaxies can have minor axis and position angle subfields */
 		char *sflds[MAXFLDS];
@@ -508,6 +548,7 @@ db_chk_planet (name, op)
 char name[];
 Obj *op;
 {
+	char namecpy[256];
 	int i;
 
 	/* these must match the order in astro.h */
@@ -516,8 +557,16 @@ Obj *op;
 	    "Uranus", "Neptune", "Pluto", "Sun", "Moon",
 	};
 
+	/* make a copy to match our case -- strcasecmp() not entirely portable*/
+	strcpy (namecpy, name);
+	if (islower(namecpy[0]))
+	    namecpy[0] = toupper(namecpy[0]);
+	for (i = 1; namecpy[i]; i++)
+	    if (isupper(namecpy[i]))
+		namecpy[i] = tolower(namecpy[i]);
+
 	for (i = MERCURY; i <= MOON; i++) {
-	    if (strcmp (name, planet_names[i]) == 0) {
+	    if (strcmp (namecpy, planet_names[i]) == 0) {
 		zero_mem ((void *)op, sizeof(ObjPl));
 		op->o_type = PLANET;
 		(void) strcpy (op->o_name, planet_names[i]);
@@ -538,7 +587,7 @@ char *buf;
 {
 	char c = buf[0];
 
-	return (isalpha(c) || isdigit(c) ? 0 : -1);
+	return (c == '#' || c == '!' || isspace(c) ? -1 : 0);
 }
 
 /* given either a decimal year (xxxx[.xxx]) or a calendar (x/x/x)
@@ -588,7 +637,7 @@ char *bp;
 	    break;
 	case F_EPOCH:
 	    mjd_year (op->f_epoch, &tmp);
-	    sprintf (bp, ",%.7g", tmp);
+	    sprintf (bp, ",%.6g", tmp); /* %.7g gives 2000.001 */
 	    bp += strlen(bp);
 	    break;
 	case F_MAG:
@@ -596,7 +645,7 @@ char *bp;
 	    bp += strlen(bp);
 	    break;
 	case F_SIZE:
-	    sprintf (bp, ",%d", op->f_size);
+	    sprintf (bp, ",%.7g", op->f_size);
 	    bp += strlen(bp);
 	    if (op->f_ratio || op->f_pa) {
 		sprintf (bp,"|%g|%g", op->f_size*get_ratio(op),
@@ -815,3 +864,6 @@ char *bp;
 
 	return (bp - bpsave);
 }
+
+/* For RCS Only -- Do Not Edit */
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: dbfmt.c,v $ $Date: 1999/02/15 21:42:18 $ $Revision: 1.7 $ $Name:  $"};
